<?php
/** 
 * EXAMPLE CODE FOR SDKMS PHP SDK
 * - Login to SDKMS using app API key
 * - Batch Encryption
 * - Batch Decryption
 * - Batch Sign
 * - Batch Verify
*/
require_once(__DIR__ . '/autoload.php');
class Example1
{
	public function example()
	{
		// SDKMS API endpoint 
		$apiEndpoint = "https://sdkms.fortanix.com";
		// SDKMS App API Key
		$appApiKey = "<SDKMS-API-KEY>";
		// SDKMS AES-128 key UUID for batch encryption decryption
		$encryptDecryptKid = "02da35de-c8b8-433b-b390-b9417d9eb364";
		// SDKMS RSA-2048 key UUID for batch sign verify
		$signVerfyKid = "57dd8490-90a3-42b7-b6a5-7d9f0b9334cb";
		
		$parts = explode(":", base64_decode($appApiKey));
		$config = new SdkmsClient\Configuration();
		$config->setHost($apiEndpoint); 
		$config->setUsername($parts[0]); 
		$config->setPassword($parts[1]);
		$client = new SdkmsClient\ApiClient($config);
				
		// authenticate
		$authInstance = new SdkmsClient\Api\AuthenticationApi($client);
		$auth = $authInstance->authorize();
		// set access token
		$config->setApiKey("Authorization", $auth['access_token']);
		$config->setApiKeyPrefix("Authorization", "Bearer"); 
		echo "App Auth.....\n";

		// Batch encryption with AES KEY 128
		$objType = new SdkmsClient\Model\ObjectType();
		$cryptMode = new SdkmsClient\Model\CryptMode();
		$plain = str_repeat("j", 64).str_repeat("i", 128);
		$encryptReqestBody = array('alg' => $objType::AES, 'mode' => $cryptMode::CBC, 'plain' => $plain);
		$encryptRequest = new SdkmsClient\Model\EncryptRequest($encryptReqestBody);
        	$batchEncryptReqestInnerBody = array('kid' => $encryptDecryptKid, 'request' => $encryptRequest);
        	$batchEncryptRequestInner = new SdkmsClient\Model\BatchDecryptRequestInner($batchEncryptReqestInnerBody);
        	// array of BatchDecryptRequestInner
        	$batchEncryptRequest = array($batchEncryptRequestInner);
        	$encryptDecryptApi = new SdkmsClient\Api\EncryptionAndDecryptionApi($client);
        	$batchEncryptResponse = $encryptDecryptApi->batchEncrypt($batchEncryptRequest);
        	echo "Batch Encryption...\n";
        	print_r($batchEncryptResponse);

		// Batch Dcryption
        	$decryptRequestBody = array('alg' => $objType::AES, 'mode' => $cryptMode::CBC, 'cipher' =>      		$batchEncryptResponse[0]->getBody()->getCipher(), 'iv' => $batchEncryptResponse[0]->getBody()->getIv());
		$decryptRequest = new SdkmsClient\Model\DecryptRequest($decryptRequestBody);
		$batchDecryptReqestInnerBody = array('kid' => $encryptDecryptKid, 'request' => $decryptRequest);
	    	$batchDecryptRequestInner = new SdkmsClient\Model\BatchDecryptRequestInner($batchDecryptReqestInnerBody);
        	$batchDecryptRequestInner = new SdkmsClient\Model\BatchDecryptRequestInner($batchDecryptReqestInnerBody);

        	$batchDecryptRequest = array($batchDecryptRequestInner);
        	$batchDecryptResponse = $encryptDecryptApi->batchDecrypt($batchDecryptRequest);
        	echo "Batch Decryption...\n";
        	print_r($batchDecryptResponse);

        	// Batch Sign with RSA key 2048 
		$data = '82C9E4C7A87C35FB14777145405C535C0FBF6BB77145405C535C0FBF6BB7';
		$hash_alg = new SdkmsClient\Model\DigestAlgorithm();
		$sobjectDescriptorBody = array('kid'=> $signVerfyKid);
        	$sobjectDescriptor = new SdkmsClient\Model\SobjectDescriptor($sobjectDescriptorBody);
        	$sobjectDescriptor = new SdkmsClient\Model\SobjectDescriptor($sobjectDescriptorBody);
		$signRequestExBody = array('key' => $sobjectDescriptor, 'hash_alg' => $hash_alg::SHA1, 'data' => $data);
		$signRequestEx = new SdkmsClient\Model\SignRequestEx($signRequestExBody);
        	// array of SignRequestEx
        	$batchSignRequest = array($signRequestEx);
        	$signVerifyApi = new SdkmsClient\Api\SignAndVerifyApi($client);
        	$batchSignResponse = $signVerifyApi->batchSign($batchSignRequest);
        	echo "Batch Sign...\n";
        	print_r($batchSignResponse);

        	// Batch Verify 
        	$verifyRequestExBody = array('key' => $sobjectDescriptorBody, 'hash_alg' => $hash_alg::SHA1, 'data' => $data, 'signature' => $batchSignResponse[0]->getBody()->getSignature());
        	$verifyRequestEx = new SdkmsClient\Model\VerifyRequestEx($verifyRequestExBody);
        	// array of BatchVerifyRequestInner
        	$batchVerifyRquest = array($verifyRequestEx);
        	$batchVerifyResponse = $signVerifyApi->batchVerify($batchVerifyRquest);
        	echo "Batch Verify...\n";
        	print_r($batchVerifyResponse);
	}
}

$obj = new Example1();
$obj->example();
?>
