<?php
/** 
 * EXAMPLE CODE FOR SDKMS PHP SDK
 * - Login to SDKMS using app API key
 * - Create Key
 * - Encryption
 * - Decryption
 * - Wrap Key
 * - Delete Key
*/
require_once(__DIR__ . '/autoload.php');
class Example2
{
	public function example()
	{
		// SDKMS API endpoint 
		$apiEndpoint = "https://sdkms.fortanix.com";
		// SDKMS App API Key
		$appApiKey = "<SDKMS-API-KEY>";
		// Name of the key to be created in SDKMS
		$aesKey = "AES-128-Key";
		// The key UUID of the SDKMS key being wrapped.
		$wrappingKeyKid = "57dd8490-90a3-42b7-b6a5-7d9f0b9334cb";
		// The key UUID of the SDKMS key to be wrapped.
		$wrappedKeyKid = "36de908d-0ef9-424f-98e6-446d16d221bd";
		
		$parts = explode(":", base64_decode($appApiKey));
		$config = new SdkmsClient\Configuration();
		$config->setHost($apiEndpoint); 
		$config->setUsername($parts[0]); 
		$config->setPassword($parts[1]);
		$client = new SdkmsClient\ApiClient($config);
				
		// authenticate
		$authInstance = new SdkmsClient\Api\AuthenticationApi($client);
		$auth = $authInstance->authorize();
		// set access token
		$config->setApiKey("Authorization", $auth['access_token']);
		$config->setApiKeyPrefix("Authorization", "Bearer"); 
		echo "App Auth.....\n";

		// Create AES KEY 128
		$securityObjectApi = new SdkmsClient\Api\SecurityObjectsApi($client);
		$objectType = new SdkmsClient\Model\ObjectType();
		$keyObject = array('name' => $aesKey, 'key_size' => 128, 'obj_type' => $objectType::AES);
		$securityObjectResponse = $securityObjectApi->generateSecurityObject($keyObject);
		echo "Creating AES Key...\n";

		// Encryption
		$plain = str_repeat("j", 64).str_repeat("i", 128);
		$cryptMode = new SdkmsClient\Model\CryptMode();
		$encryptRequestBody = array('alg' => $objectType::AES, 'mode' => $cryptMode::CBC, 'plain' => $plain);
		$encryptRequest = new SdkmsClient\Model\EncryptRequest($encryptRequestBody);
		$encryptDecryptApi = new SdkmsClient\Api\EncryptionAndDecryptionApi($client);
		$encryptResponse = $encryptDecryptApi->encrypt($securityObjectResponse["kid"], $encryptRequest);
		echo "Encrypting AES Key...\n";

		// Decryption
		$decryptReqestBody = array('alg' => $objectType::AES, 'mode' => $cryptMode::CBC, 'cipher' => $encryptResponse['cipher'], 'iv' => $encryptResponse['iv']);
		$decryptReqest = new SdkmsClient\Model\DecryptRequest($decryptReqestBody);
		$decryptResponse = $encryptDecryptApi->decrypt($securityObjectResponse["kid"], $decryptReqest);
		echo "Decrypted...\n";

		// Wrap Key
		$wrapKeyRequestBody = array('alg' => $objectType::AES, 'mode' => $cryptMode::CBC, 'kid' => $wrappingKeyKid);
		$wrapKeyRequest = new SdkmsClient\Model\WrapKeyRequest($wrapKeyRequestBody);
		$wrapppingAndUnrappingApi = new SdkmsClient\Api\WrappingAndUnwrappingApi($client);
		$wrapKeyResponse = $wrapppingAndUnrappingApi->wrapKey($wrappedKeyKid, $wrapKeyRequest);
		echo "Wraped Key...\n";

		// Delete Key
		$securityObjectResponse->deleteSecurityObject($securityObjectResponse["kid"]);
		echo "Deleting AES Key...\n";
	}
}

$obj = new Example2();
$obj->example();
?>

