# SdkmsClient\AppsApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createApp**](AppsApi.md#createApp) | **POST** /sys/v1/apps | Create a new application
[**deleteApp**](AppsApi.md#deleteApp) | **DELETE** /sys/v1/apps/{app-id} | Delete application
[**getApp**](AppsApi.md#getApp) | **GET** /sys/v1/apps/{app-id} | Get a specific application
[**getApps**](AppsApi.md#getApps) | **GET** /sys/v1/apps | Get all applications
[**getCredential**](AppsApi.md#getCredential) | **GET** /sys/v1/apps/{app-id}/credential | Get a specific application&#39;s credential
[**regenerateApiKey**](AppsApi.md#regenerateApiKey) | **POST** /sys/v1/apps/{app-id}/reset_secret | Regenerate API key
[**updateApp**](AppsApi.md#updateApp) | **PATCH** /sys/v1/apps/{app-id} | Update an application


# **createApp**
> \SdkmsClient\Model\App createApp($body)

Create a new application

Create a new application with the specified properties.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\AppsApi();
$body = new \SdkmsClient\Model\AppRequest(); // \SdkmsClient\Model\AppRequest | Properties of application to create

try {
    $result = $api_instance->createApp($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling AppsApi->createApp: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\AppRequest**](../Model/AppRequest.md)| Properties of application to create |

### Return type

[**\SdkmsClient\Model\App**](../Model/App.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **deleteApp**
> deleteApp($app_id)

Delete application

Remove an application from SDKMS.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\AppsApi();
$app_id = "app_id_example"; // string | Application Identifier

try {
    $api_instance->deleteApp($app_id);
} catch (Exception $e) {
    echo 'Exception when calling AppsApi->deleteApp: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **string**| Application Identifier |

### Return type

void (empty response body)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getApp**
> \SdkmsClient\Model\App getApp($app_id)

Get a specific application

Look up an application by application ID.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\AppsApi();
$app_id = "app_id_example"; // string | Application Identifier

try {
    $result = $api_instance->getApp($app_id);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling AppsApi->getApp: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **string**| Application Identifier |

### Return type

[**\SdkmsClient\Model\App**](../Model/App.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getApps**
> \SdkmsClient\Model\App[] getApps($group_id, $sort, $start, $limit, $offset)

Get all applications

Get details of all applications the current user has access to.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\AppsApi();
$group_id = "group_id_example"; // string | Only retrieve applications in the specified group.
$sort = "sort_example"; // string | This specifies the property (`app_id` only, for now) and order (ascending or descending) with which to sort the apps. By default, apps are sorted by `app_id` in ascending order. The syntax is \"<property>:[asc|desc]\" (e.g. \"app_id:desc\") or just \"<property>\" (ascending order by default).
$start = "start_example"; // string | If provided, this must be a value of the property specified in `sort`. Returned apps will begin just above or just below this value (for asc/desc order resp.).
$limit = 56; // int | Maximum number of apps to return. If not provided, the limit is 100.
$offset = 56; // int | Number of apps past `start` to skip.

try {
    $result = $api_instance->getApps($group_id, $sort, $start, $limit, $offset);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling AppsApi->getApps: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **group_id** | **string**| Only retrieve applications in the specified group. | [optional]
 **sort** | **string**| This specifies the property (&#x60;app_id&#x60; only, for now) and order (ascending or descending) with which to sort the apps. By default, apps are sorted by &#x60;app_id&#x60; in ascending order. The syntax is \&quot;&lt;property&gt;:[asc|desc]\&quot; (e.g. \&quot;app_id:desc\&quot;) or just \&quot;&lt;property&gt;\&quot; (ascending order by default). | [optional]
 **start** | **string**| If provided, this must be a value of the property specified in &#x60;sort&#x60;. Returned apps will begin just above or just below this value (for asc/desc order resp.). | [optional]
 **limit** | **int**| Maximum number of apps to return. If not provided, the limit is 100. | [optional]
 **offset** | **int**| Number of apps past &#x60;start&#x60; to skip. | [optional]

### Return type

[**\SdkmsClient\Model\App[]**](../Model/App.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getCredential**
> \SdkmsClient\Model\AppCredentialResponse getCredential($app_id)

Get a specific application's credential

Retrieve the authentication credential (API key or certificate) for a particular application. Only users who are an administrator of at least one of the application's groups can retrieve the credential.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\AppsApi();
$app_id = "app_id_example"; // string | Application Identifier

try {
    $result = $api_instance->getCredential($app_id);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling AppsApi->getCredential: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **string**| Application Identifier |

### Return type

[**\SdkmsClient\Model\AppCredentialResponse**](../Model/AppCredentialResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **regenerateApiKey**
> \SdkmsClient\Model\App regenerateApiKey($app_id, $body)

Regenerate API key

Create a new API key for an application. An application may only have one valid API key at a time, so performing this action will invalidate all old API keys. This does not invalidate existing sessions, so any applications with an existing open session will be able to continue operating with their old session until those sessions expire.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\AppsApi();
$app_id = "app_id_example"; // string | Application Identifier
$body = new \SdkmsClient\Model\AppResetSecretRequest(); // \SdkmsClient\Model\AppResetSecretRequest | Decryption request

try {
    $result = $api_instance->regenerateApiKey($app_id, $body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling AppsApi->regenerateApiKey: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **string**| Application Identifier |
 **body** | [**\SdkmsClient\Model\AppResetSecretRequest**](../Model/AppResetSecretRequest.md)| Decryption request |

### Return type

[**\SdkmsClient\Model\App**](../Model/App.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **updateApp**
> \SdkmsClient\Model\App updateApp($app_id, $body)

Update an application

Change an application's properties, such as name, description, or group membership.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\AppsApi();
$app_id = "app_id_example"; // string | Application Identifier
$body = new \SdkmsClient\Model\AppRequest(); // \SdkmsClient\Model\AppRequest | Properties of application to create

try {
    $result = $api_instance->updateApp($app_id, $body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling AppsApi->updateApp: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **string**| Application Identifier |
 **body** | [**\SdkmsClient\Model\AppRequest**](../Model/AppRequest.md)| Properties of application to create |

### Return type

[**\SdkmsClient\Model\App**](../Model/App.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

