# SdkmsClient\DigestApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**batchMac**](DigestApi.md#batchMac) | **POST** /crypto/v1/keys/batch/mac | Batch MAC with one or more keys
[**batchMacVerify**](DigestApi.md#batchMacVerify) | **POST** /crypto/v1/keys/batch/macverify | Batch MAC Verify with one or more keys
[**computeDigest**](DigestApi.md#computeDigest) | **POST** /crypto/v1/digest | Compute a message digest of data
[**computeMac**](DigestApi.md#computeMac) | **POST** /crypto/v1/keys/{key-id}/mac | Compute MAC using a key
[**computeMacEx**](DigestApi.md#computeMacEx) | **POST** /crypto/v1/mac | Compute MAC using a key
[**verifyMac**](DigestApi.md#verifyMac) | **POST** /crypto/v1/keys/{key-id}/macverify | Verify MAC using a key
[**verifyMacEx**](DigestApi.md#verifyMacEx) | **POST** /crypto/v1/macverify | Verify MAC using a key


# **batchMac**
> \SdkmsClient\Model\BatchMacResponse batchMac($body)

Batch MAC with one or more keys

Message to compute a cryptographic Message Authentication Code and the key ids to be used are provided in the request body. The MAC is returned in the response body. The ordering of the body matches the ordering of the request. An individual status code is returned for each batch item. Maximum size of the entire batch request is 512 KB.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\DigestApi();
$body = new \SdkmsClient\Model\BatchMacRequest(); // \SdkmsClient\Model\BatchMacRequest | Batch MAC request

try {
    $result = $api_instance->batchMac($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DigestApi->batchMac: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\BatchMacRequest**](../Model/BatchMacRequest.md)| Batch MAC request |

### Return type

[**\SdkmsClient\Model\BatchMacResponse**](../Model/BatchMacResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **batchMacVerify**
> \SdkmsClient\Model\BatchVerifyResponse batchMacVerify($body)

Batch MAC Verify with one or more keys

The data to be MACed, the algorithm, a pre-computed MAC are provided in the request body, and the key id to be used are provided in the request body. The MAC is returned in the response body. The ordering of the body matches the ordering of the request. An individual status code is returned for each batch item. Maximum size of the entire batch request is 512 KB.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\DigestApi();
$body = new \SdkmsClient\Model\BatchMacVerifyRequest(); // \SdkmsClient\Model\BatchMacVerifyRequest | Batch MAC verify request

try {
    $result = $api_instance->batchMacVerify($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DigestApi->batchMacVerify: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\BatchMacVerifyRequest**](../Model/BatchMacVerifyRequest.md)| Batch MAC verify request |

### Return type

[**\SdkmsClient\Model\BatchVerifyResponse**](../Model/BatchVerifyResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **computeDigest**
> \SdkmsClient\Model\DigestResponse computeDigest($body)

Compute a message digest of data

This returns the digest of data provided in request body using the algorithm specified in request body. Maximum size of request body supported is 512KB.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\DigestApi();
$body = new \SdkmsClient\Model\DigestRequest(); // \SdkmsClient\Model\DigestRequest | Digest request

try {
    $result = $api_instance->computeDigest($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DigestApi->computeDigest: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\DigestRequest**](../Model/DigestRequest.md)| Digest request |

### Return type

[**\SdkmsClient\Model\DigestResponse**](../Model/DigestResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **computeMac**
> \SdkmsClient\Model\MacGenerateResponse computeMac($key_id, $body)

Compute MAC using a key

Compute a cryptographic Message Authentication Code on a message using a symmetric key. The key must have the MACGenerate operation enabled. Asymmetric keys may not be used to generate MACs. They can be used with the sign and verify operations.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\DigestApi();
$key_id = "key_id_example"; // string | kid of security object
$body = new \SdkmsClient\Model\MacGenerateRequest(); // \SdkmsClient\Model\MacGenerateRequest | MAC generation request

try {
    $result = $api_instance->computeMac($key_id, $body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DigestApi->computeMac: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |
 **body** | [**\SdkmsClient\Model\MacGenerateRequest**](../Model/MacGenerateRequest.md)| MAC generation request |

### Return type

[**\SdkmsClient\Model\MacGenerateResponse**](../Model/MacGenerateResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **computeMacEx**
> \SdkmsClient\Model\MacGenerateResponse computeMacEx($body)

Compute MAC using a key

Compute a cryptographic Message Authentication Code on a message using a symmetric key. The key must have the MACGenerate operation enabled. Asymmetric keys may not be used to generate MACs. They can be used with the sign and verify operations.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\DigestApi();
$body = new \SdkmsClient\Model\MacGenerateRequestEx(); // \SdkmsClient\Model\MacGenerateRequestEx | MAC generation request

try {
    $result = $api_instance->computeMacEx($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DigestApi->computeMacEx: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\MacGenerateRequestEx**](../Model/MacGenerateRequestEx.md)| MAC generation request |

### Return type

[**\SdkmsClient\Model\MacGenerateResponse**](../Model/MacGenerateResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **verifyMac**
> \SdkmsClient\Model\MacVerifyResponse verifyMac($key_id, $body)

Verify MAC using a key

The data to be MACed, the algorithm, and a pre-computed MAC are provided in the request body, and the key id is provided in the URL. SDKMS computes the MAC of the data and compares it with the specified MAC, and returns the outcome of the MAC verification in the response body. Maximum size of request body supported is 512KB. Supported digest algorithms are - SHA1, SHA256, SHA384, and SHA512.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\DigestApi();
$key_id = "key_id_example"; // string | kid of security object
$body = new \SdkmsClient\Model\MacVerifyRequest(); // \SdkmsClient\Model\MacVerifyRequest | MAC Verify request

try {
    $result = $api_instance->verifyMac($key_id, $body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DigestApi->verifyMac: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |
 **body** | [**\SdkmsClient\Model\MacVerifyRequest**](../Model/MacVerifyRequest.md)| MAC Verify request |

### Return type

[**\SdkmsClient\Model\MacVerifyResponse**](../Model/MacVerifyResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **verifyMacEx**
> \SdkmsClient\Model\MacVerifyResponse verifyMacEx($body)

Verify MAC using a key

The data to be MACed, the algorithm, and a pre-computed MAC are provided in the request body, and the key id is provided in the URL. SDKMS computes the MAC of the data and compares it with the specified MAC, and returns the outcome of the MAC verification in the response body. Maximum size of request body supported is 512KB. Supported digest algorithms are - SHA1, SHA256, SHA384, and SHA512.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\DigestApi();
$body = new \SdkmsClient\Model\MacVerifyRequestEx(); // \SdkmsClient\Model\MacVerifyRequestEx | MAC Verify request

try {
    $result = $api_instance->verifyMacEx($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DigestApi->verifyMacEx: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\MacVerifyRequestEx**](../Model/MacVerifyRequestEx.md)| MAC Verify request |

### Return type

[**\SdkmsClient\Model\MacVerifyResponse**](../Model/MacVerifyResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

