# SdkmsClient\TwoFactorAuthenticationApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**authorizeRecoveryCode**](TwoFactorAuthenticationApi.md#authorizeRecoveryCode) | **POST** /sys/v1/session/auth/2fa/recovery_code | Use a backup recovery code to complete authentication
[**authorizeU2F**](TwoFactorAuthenticationApi.md#authorizeU2F) | **POST** /sys/v1/session/auth/2fa/u2f | Use a U2F key to complete authentication
[**generateRecoveryCodes**](TwoFactorAuthenticationApi.md#generateRecoveryCodes) | **POST** /sys/v1/users/generate_recovery_code | Generate backup recovery codes for the current user
[**generateU2FChallenge**](TwoFactorAuthenticationApi.md#generateU2FChallenge) | **POST** /sys/v1/session/config_2fa/new_challenge | Generate a new challenge for registering a U2F devices
[**lock2F**](TwoFactorAuthenticationApi.md#lock2F) | **POST** /sys/v1/session/config_2fa/terminate | Lock two factor configuration


# **authorizeRecoveryCode**
> authorizeRecoveryCode()

Use a backup recovery code to complete authentication

Complete two factor authentication with a backup recovery code. The caller needs to provide a bearer token for the session in the request body. Each recovery code may only be used once, so users should update their two factor configuration after using this API.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\TwoFactorAuthenticationApi();

try {
    $api_instance->authorizeRecoveryCode();
} catch (Exception $e) {
    echo 'Exception when calling TwoFactorAuthenticationApi->authorizeRecoveryCode: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

void (empty response body)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **authorizeU2F**
> authorizeU2F()

Use a U2F key to complete authentication

Complete two factor authentication with a U2F authentication token to authenticate to SDKMS. The response body contains a bearer authentication token which needs to be provided by subsequent calls for the duration of the session.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure HTTP basic authorization: basicAuth
SdkmsClient\Configuration::getDefaultConfiguration()->setUsername('YOUR_USERNAME');
SdkmsClient\Configuration::getDefaultConfiguration()->setPassword('YOUR_PASSWORD');

$api_instance = new SdkmsClient\Api\TwoFactorAuthenticationApi();

try {
    $api_instance->authorizeU2F();
} catch (Exception $e) {
    echo 'Exception when calling TwoFactorAuthenticationApi->authorizeU2F: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

void (empty response body)

### Authorization

[basicAuth](../../README.md#basicAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **generateRecoveryCodes**
> \SdkmsClient\Model\RecoveryCodes generateRecoveryCodes()

Generate backup recovery codes for the current user

Generate backup recovery codes that may be used to complete complete two factor authentication. The caller needs to provide a bearer token for the session in the request body. Two factor configuration must be unlocked to use this API.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\TwoFactorAuthenticationApi();

try {
    $result = $api_instance->generateRecoveryCodes();
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling TwoFactorAuthenticationApi->generateRecoveryCodes: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**\SdkmsClient\Model\RecoveryCodes**](../Model/RecoveryCodes.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **generateU2FChallenge**
> \SdkmsClient\Model\MfaChallenge generateU2FChallenge()

Generate a new challenge for registering a U2F devices

Generate a new challenge that may be used to register U2F devices. The caller needs to provide a bearer token for the session in the request body.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\TwoFactorAuthenticationApi();

try {
    $result = $api_instance->generateU2FChallenge();
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling TwoFactorAuthenticationApi->generateU2FChallenge: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**\SdkmsClient\Model\MfaChallenge**](../Model/MfaChallenge.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **lock2F**
> lock2F()

Lock two factor configuration

Lock two factor configuration after completing two factor reconfiguration. The caller needs to provide a bearer token for the session in the request body. If this API is not called, two factor configuration will be locked automatically after ten minutes.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\TwoFactorAuthenticationApi();

try {
    $api_instance->lock2F();
} catch (Exception $e) {
    echo 'Exception when calling TwoFactorAuthenticationApi->lock2F: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

void (empty response body)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

