# SdkmsClient\WrappingAndUnwrappingApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**unwrapKey**](WrappingAndUnwrappingApi.md#unwrapKey) | **POST** /crypto/v1/keys/{key-id}/unwrapkey | Unwrap a security object with a key
[**unwrapKeyEx**](WrappingAndUnwrappingApi.md#unwrapKeyEx) | **POST** /crypto/v1/unwrapkey | Unwrap a security object with a key
[**wrapKey**](WrappingAndUnwrappingApi.md#wrapKey) | **POST** /crypto/v1/keys/{key-id}/wrapkey | Wrap a security object with a key
[**wrapKeyEx**](WrappingAndUnwrappingApi.md#wrapKeyEx) | **POST** /crypto/v1/wrapkey | Wrap a security object with a key


# **unwrapKey**
> \SdkmsClient\Model\KeyObject unwrapKey($key_id, $body)

Unwrap a security object with a key

Unwrap (decrypt) a wrapped key and import it into SDKMS. This allows securely importing into SDKMS security objects that were previously wrapped by SDKMS or another key management system. A new security object will be created in SDKMS with the unwrapped data. <br> The key-id parameter in the URL specifies the key that will be used to unwrap the other security object. This key must have the unwrapkey operation enabled. <br> The alg and mode parameters specify the encryption algorithm and cipher mode being used by the unwrapping key. The obj_type parameter specifies the object type of the security object being unwrapped. The size or elliptic curve of the object being unwrapped does not need to be specified.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\WrappingAndUnwrappingApi();
$key_id = "key_id_example"; // string | kid of security object
$body = new \SdkmsClient\Model\UnwrapKeyRequest(); // \SdkmsClient\Model\UnwrapKeyRequest | Unwrap key request

try {
    $result = $api_instance->unwrapKey($key_id, $body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling WrappingAndUnwrappingApi->unwrapKey: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |
 **body** | [**\SdkmsClient\Model\UnwrapKeyRequest**](../Model/UnwrapKeyRequest.md)| Unwrap key request |

### Return type

[**\SdkmsClient\Model\KeyObject**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **unwrapKeyEx**
> \SdkmsClient\Model\KeyObject unwrapKeyEx($body)

Unwrap a security object with a key

Unwrap (decrypt) a wrapped key and import it into SDKMS. This allows securely importing into SDKMS security objects that were previously wrapped by SDKMS or another key management system. A new security object will be created in SDKMS with the unwrapped data. <br> The key-id parameter in the URL specifies the key that will be used to unwrap the other security object. This key must have the unwrapkey operation enabled. <br> The alg and mode parameters specify the encryption algorithm and cipher mode being used by the unwrapping key. The obj_type parameter specifies the object type of the security object being unwrapped. The size or elliptic curve of the object being unwrapped does not need to be specified.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\WrappingAndUnwrappingApi();
$body = new \SdkmsClient\Model\UnwrapKeyRequestEx(); // \SdkmsClient\Model\UnwrapKeyRequestEx | Unwrap key request

try {
    $result = $api_instance->unwrapKeyEx($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling WrappingAndUnwrappingApi->unwrapKeyEx: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\UnwrapKeyRequestEx**](../Model/UnwrapKeyRequestEx.md)| Unwrap key request |

### Return type

[**\SdkmsClient\Model\KeyObject**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **wrapKey**
> \SdkmsClient\Model\WrapKeyResponse wrapKey($key_id, $body)

Wrap a security object with a key

Wrap (encrypt) an existing security object with a key. This allows keys to be securely exported from SDKMS so they can be later imported into SDKMS or another key management system. <br> The key-id parameter in the URL specifies the key that will be used to wrap the other security object. The security object being wrapped is specified inside of the request body. <br> The alg and mode parameters specify the encryption algorithm and cipher mode being used for the wrapping key. The algorithm of the key being wrapped is not provided to this API call. <br> The key being wrapped must have the export operation enabled. The wrapping key must have the wrapkey operation enabled. <br> The following wrapping operations are supported:   * Symmetric keys, HMAC keys, opaque objects, and secret objects may be wrapped with symmetric or asymmetric keys.   * Asymmetric keys may be wrapped with symmetric keys. Wrapping an asymmetric key with an asymmetric key is not supported.  When wrapping with an asymmetric key, the wrapped object size must fit as plaintext for the wrapping key size and algorithm.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\WrappingAndUnwrappingApi();
$key_id = "key_id_example"; // string | kid of security object
$body = new \SdkmsClient\Model\WrapKeyRequest(); // \SdkmsClient\Model\WrapKeyRequest | Wrap key request

try {
    $result = $api_instance->wrapKey($key_id, $body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling WrappingAndUnwrappingApi->wrapKey: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |
 **body** | [**\SdkmsClient\Model\WrapKeyRequest**](../Model/WrapKeyRequest.md)| Wrap key request |

### Return type

[**\SdkmsClient\Model\WrapKeyResponse**](../Model/WrapKeyResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **wrapKeyEx**
> \SdkmsClient\Model\WrapKeyResponse wrapKeyEx($body)

Wrap a security object with a key

Wrap (encrypt) an existing security object with a key. This allows keys to be securely exported from SDKMS so they can be later imported into SDKMS or another key management system. <br> The key-id parameter in the URL specifies the key that will be used to wrap the other security object. The security object being wrapped is specified inside of the request body. <br> The alg and mode parameters specify the encryption algorithm and cipher mode being used for the wrapping key. The algorithm of the key being wrapped is not provided to this API call. <br> The key being wrapped must have the export operation enabled. The wrapping key must have the wrapkey operation enabled. <br> The following wrapping operations are supported:   * Symmetric keys, HMAC keys, opaque objects, and secret objects may be wrapped with symmetric or asymmetric keys.   * Asymmetric keys may be wrapped with symmetric keys. Wrapping an asymmetric key with an asymmetric key is not supported.  When wrapping with an asymmetric key, the wrapped object size must fit as plaintext for the wrapping key size and algorithm.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\WrappingAndUnwrappingApi();
$body = new \SdkmsClient\Model\WrapKeyRequestEx(); // \SdkmsClient\Model\WrapKeyRequestEx | Wrap key request

try {
    $result = $api_instance->wrapKeyEx($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling WrappingAndUnwrappingApi->wrapKeyEx: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\WrapKeyRequestEx**](../Model/WrapKeyRequestEx.md)| Wrap key request |

### Return type

[**\SdkmsClient\Model\WrapKeyResponse**](../Model/WrapKeyResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

