<?php
/**
 * AWSApi
 * PHP version 5
 *
 * @category Class
 * @package  SdkmsClient
 * @author   Swagger Codegen team
 * @link     https://github.com/swagger-api/swagger-codegen
 */

/**
 * Fortanix SDKMS REST API
 *
 * This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations.
 *
 * OpenAPI spec version: 1.0.0-20200608
 * Contact: support@fortanix.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 */

/**
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen
 * Do not edit the class manually.
 */

namespace SdkmsClient\Api;

use \SdkmsClient\ApiClient;
use \SdkmsClient\ApiException;
use \SdkmsClient\Configuration;
use \SdkmsClient\ObjectSerializer;

/**
 * AWSApi Class Doc Comment
 *
 * @category Class
 * @package  SdkmsClient
 * @author   Swagger Codegen team
 * @link     https://github.com/swagger-api/swagger-codegen
 */
class AWSApi
{
    /**
     * API Client
     *
     * @var \SdkmsClient\ApiClient instance of the ApiClient
     */
    protected $apiClient;

    /**
     * Constructor
     *
     * @param \SdkmsClient\ApiClient|null $apiClient The api client to use
     */
    public function __construct(\SdkmsClient\ApiClient $apiClient = null)
    {
        if ($apiClient === null) {
            $apiClient = new ApiClient();
        }

        $this->apiClient = $apiClient;
    }

    /**
     * Get API client
     *
     * @return \SdkmsClient\ApiClient get the API client
     */
    public function getApiClient()
    {
        return $this->apiClient;
    }

    /**
     * Set the API client
     *
     * @param \SdkmsClient\ApiClient $apiClient set the API client
     *
     * @return AWSApi
     */
    public function setApiClient(\SdkmsClient\ApiClient $apiClient)
    {
        $this->apiClient = $apiClient;
        return $this;
    }

    /**
     * Operation cancelDeletion
     *
     * Cancel scheduled deletion of an AWS KMS key
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function cancelDeletion($key_id)
    {
        list($response) = $this->cancelDeletionWithHttpInfo($key_id);
        return $response;
    }

    /**
     * Operation cancelDeletionWithHttpInfo
     *
     * Cancel scheduled deletion of an AWS KMS key
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function cancelDeletionWithHttpInfo($key_id)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling cancelDeletion');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/{key-id}/cancel_deletion";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/keys/{key-id}/cancel_deletion'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation deleteKeyMaterial
     *
     * Delete the key material of an AWS KMS key
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function deleteKeyMaterial($key_id)
    {
        list($response) = $this->deleteKeyMaterialWithHttpInfo($key_id);
        return $response;
    }

    /**
     * Operation deleteKeyMaterialWithHttpInfo
     *
     * Delete the key material of an AWS KMS key
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function deleteKeyMaterialWithHttpInfo($key_id)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling deleteKeyMaterial');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/{key-id}/delete_key_material";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/keys/{key-id}/delete_key_material'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation restore
     *
     * Restore an AWS KMS key from its source key material
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function restore($key_id)
    {
        list($response) = $this->restoreWithHttpInfo($key_id);
        return $response;
    }

    /**
     * Operation restoreWithHttpInfo
     *
     * Restore an AWS KMS key from its source key material
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function restoreWithHttpInfo($key_id)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling restore');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/{key-id}/restore";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/keys/{key-id}/restore'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation scheduleDeletion
     *
     * Schedule an AWS KMS key for deletion
     *
     * @param string $key_id kid of security object (required)
     * @param \SdkmsClient\Model\ScheduleDeletionRequest $body Request to schedule deletion for an AWS KMS key (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function scheduleDeletion($key_id, $body)
    {
        list($response) = $this->scheduleDeletionWithHttpInfo($key_id, $body);
        return $response;
    }

    /**
     * Operation scheduleDeletionWithHttpInfo
     *
     * Schedule an AWS KMS key for deletion
     *
     * @param string $key_id kid of security object (required)
     * @param \SdkmsClient\Model\ScheduleDeletionRequest $body Request to schedule deletion for an AWS KMS key (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function scheduleDeletionWithHttpInfo($key_id, $body)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling scheduleDeletion');
        }
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling scheduleDeletion');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/{key-id}/schedule_deletion";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }
        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/keys/{key-id}/schedule_deletion'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }
}
