<?php
/**
 * SecurityObjectsApi
 * PHP version 5
 *
 * @category Class
 * @package  SdkmsClient
 * @author   Swagger Codegen team
 * @link     https://github.com/swagger-api/swagger-codegen
 */

/**
 * Fortanix SDKMS REST API
 *
 * This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations.
 *
 * OpenAPI spec version: 1.0.0-20200608
 * Contact: support@fortanix.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 */

/**
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen
 * Do not edit the class manually.
 */

namespace SdkmsClient\Api;

use \SdkmsClient\ApiClient;
use \SdkmsClient\ApiException;
use \SdkmsClient\Configuration;
use \SdkmsClient\ObjectSerializer;

/**
 * SecurityObjectsApi Class Doc Comment
 *
 * @category Class
 * @package  SdkmsClient
 * @author   Swagger Codegen team
 * @link     https://github.com/swagger-api/swagger-codegen
 */
class SecurityObjectsApi
{
    /**
     * API Client
     *
     * @var \SdkmsClient\ApiClient instance of the ApiClient
     */
    protected $apiClient;

    /**
     * Constructor
     *
     * @param \SdkmsClient\ApiClient|null $apiClient The api client to use
     */
    public function __construct(\SdkmsClient\ApiClient $apiClient = null)
    {
        if ($apiClient === null) {
            $apiClient = new ApiClient();
        }

        $this->apiClient = $apiClient;
    }

    /**
     * Get API client
     *
     * @return \SdkmsClient\ApiClient get the API client
     */
    public function getApiClient()
    {
        return $this->apiClient;
    }

    /**
     * Set the API client
     *
     * @param \SdkmsClient\ApiClient $apiClient set the API client
     *
     * @return SecurityObjectsApi
     */
    public function setApiClient(\SdkmsClient\ApiClient $apiClient)
    {
        $this->apiClient = $apiClient;
        return $this;
    }

    /**
     * Operation activateSecurityObject
     *
     * Transitions immediately a security object to Active state
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return void
     */
    public function activateSecurityObject($key_id)
    {
        list($response) = $this->activateSecurityObjectWithHttpInfo($key_id);
        return $response;
    }

    /**
     * Operation activateSecurityObjectWithHttpInfo
     *
     * Transitions immediately a security object to Active state
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of null, HTTP status code, HTTP response headers (array of strings)
     */
    public function activateSecurityObjectWithHttpInfo($key_id)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling activateSecurityObject');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/{key-id}/activate";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                null,
                '/crypto/v1/keys/{key-id}/activate'
            );

            return [null, $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation agreeKey
     *
     * Agree on a key from two other keys
     *
     * @param \SdkmsClient\Model\AgreeKeyRequest $body Template of the agreed-upon security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function agreeKey($body)
    {
        list($response) = $this->agreeKeyWithHttpInfo($body);
        return $response;
    }

    /**
     * Operation agreeKeyWithHttpInfo
     *
     * Agree on a key from two other keys
     *
     * @param \SdkmsClient\Model\AgreeKeyRequest $body Template of the agreed-upon security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function agreeKeyWithHttpInfo($body)
    {
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling agreeKey');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/agree";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/agree'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 201:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation deletePrivateKey
     *
     * Remove / Destroy private half of the asymmetric key
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return void
     */
    public function deletePrivateKey($key_id)
    {
        list($response) = $this->deletePrivateKeyWithHttpInfo($key_id);
        return $response;
    }

    /**
     * Operation deletePrivateKeyWithHttpInfo
     *
     * Remove / Destroy private half of the asymmetric key
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of null, HTTP status code, HTTP response headers (array of strings)
     */
    public function deletePrivateKeyWithHttpInfo($key_id)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling deletePrivateKey');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/{key-id}/private";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'DELETE',
                $queryParams,
                $httpBody,
                $headerParams,
                null,
                '/crypto/v1/keys/{key-id}/private'
            );

            return [null, $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation deleteSecurityObject
     *
     * Delete a security object
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return void
     */
    public function deleteSecurityObject($key_id)
    {
        list($response) = $this->deleteSecurityObjectWithHttpInfo($key_id);
        return $response;
    }

    /**
     * Operation deleteSecurityObjectWithHttpInfo
     *
     * Delete a security object
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of null, HTTP status code, HTTP response headers (array of strings)
     */
    public function deleteSecurityObjectWithHttpInfo($key_id)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling deleteSecurityObject');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/{key-id}";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'DELETE',
                $queryParams,
                $httpBody,
                $headerParams,
                null,
                '/crypto/v1/keys/{key-id}'
            );

            return [null, $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation deriveKey
     *
     * Derive a key from another key
     *
     * @param string $key_id kid of security object (required)
     * @param \SdkmsClient\Model\DeriveKeyRequest $body Name of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function deriveKey($key_id, $body)
    {
        list($response) = $this->deriveKeyWithHttpInfo($key_id, $body);
        return $response;
    }

    /**
     * Operation deriveKeyWithHttpInfo
     *
     * Derive a key from another key
     *
     * @param string $key_id kid of security object (required)
     * @param \SdkmsClient\Model\DeriveKeyRequest $body Name of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function deriveKeyWithHttpInfo($key_id, $body)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling deriveKey');
        }
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling deriveKey');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/{key-id}/derive";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }
        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/keys/{key-id}/derive'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 201:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation deriveKeyEx
     *
     * Derive a key from another key
     *
     * @param \SdkmsClient\Model\DeriveKeyRequestEx $body Name of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function deriveKeyEx($body)
    {
        list($response) = $this->deriveKeyExWithHttpInfo($body);
        return $response;
    }

    /**
     * Operation deriveKeyExWithHttpInfo
     *
     * Derive a key from another key
     *
     * @param \SdkmsClient\Model\DeriveKeyRequestEx $body Name of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function deriveKeyExWithHttpInfo($body)
    {
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling deriveKeyEx');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/derive";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/derive'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 201:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation destroySecurityObject
     *
     * Destroys a security object, leaving its metadata in place
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return void
     */
    public function destroySecurityObject($key_id)
    {
        list($response) = $this->destroySecurityObjectWithHttpInfo($key_id);
        return $response;
    }

    /**
     * Operation destroySecurityObjectWithHttpInfo
     *
     * Destroys a security object, leaving its metadata in place
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of null, HTTP status code, HTTP response headers (array of strings)
     */
    public function destroySecurityObjectWithHttpInfo($key_id)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling destroySecurityObject');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/{key-id}/destroy";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                null,
                '/crypto/v1/keys/{key-id}/destroy'
            );

            return [null, $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation exportSobjectComponents
     *
     * export key components
     *
     * @param \SdkmsClient\Model\ExportSobjectComponentsRequest $body Request to export a security object components (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\ExportComponentsResponse
     */
    public function exportSobjectComponents($body)
    {
        list($response) = $this->exportSobjectComponentsWithHttpInfo($body);
        return $response;
    }

    /**
     * Operation exportSobjectComponentsWithHttpInfo
     *
     * export key components
     *
     * @param \SdkmsClient\Model\ExportSobjectComponentsRequest $body Request to export a security object components (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\ExportComponentsResponse, HTTP status code, HTTP response headers (array of strings)
     */
    public function exportSobjectComponentsWithHttpInfo($body)
    {
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling exportSobjectComponents');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/components/export";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\ExportComponentsResponse',
                '/crypto/v1/keys/components/export'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\ExportComponentsResponse', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\ExportComponentsResponse', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation generateSecurityObject
     *
     * Generate a new security object
     *
     * @param \SdkmsClient\Model\SobjectRequest $body Request to create, update, or import security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function generateSecurityObject($body)
    {
        list($response) = $this->generateSecurityObjectWithHttpInfo($body);
        return $response;
    }

    /**
     * Operation generateSecurityObjectWithHttpInfo
     *
     * Generate a new security object
     *
     * @param \SdkmsClient\Model\SobjectRequest $body Request to create, update, or import security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function generateSecurityObjectWithHttpInfo($body)
    {
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling generateSecurityObject');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/keys'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 201:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation getSecurityObject
     *
     * Get a specific security object
     *
     * @param string $key_id kid of security object (required)
     * @param string $view The encoding the value of an opaque object or certificate (optional, default to json)
     * @param bool $show_destroyed Whether security objects in the &#x60;Destroyed&#x60; state should be returned (optional, default to false)
     * @param bool $show_deleted Whether security objects in the &#x60;Deleted&#x60; state should be returned (optional)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function getSecurityObject($key_id, $view = 'json', $show_destroyed = 'false', $show_deleted = null)
    {
        list($response) = $this->getSecurityObjectWithHttpInfo($key_id, $view, $show_destroyed, $show_deleted);
        return $response;
    }

    /**
     * Operation getSecurityObjectWithHttpInfo
     *
     * Get a specific security object
     *
     * @param string $key_id kid of security object (required)
     * @param string $view The encoding the value of an opaque object or certificate (optional, default to json)
     * @param bool $show_destroyed Whether security objects in the &#x60;Destroyed&#x60; state should be returned (optional, default to false)
     * @param bool $show_deleted Whether security objects in the &#x60;Deleted&#x60; state should be returned (optional)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function getSecurityObjectWithHttpInfo($key_id, $view = 'json', $show_destroyed = 'false', $show_deleted = null)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling getSecurityObject');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/{key-id}";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // query params
        if ($view !== null) {
            $queryParams['view'] = $this->apiClient->getSerializer()->toQueryValue($view);
        }
        // query params
        if ($show_destroyed !== null) {
            $queryParams['show_destroyed'] = $this->apiClient->getSerializer()->toQueryValue($show_destroyed);
        }
        // query params
        if ($show_deleted !== null) {
            $queryParams['show_deleted'] = $this->apiClient->getSerializer()->toQueryValue($show_deleted);
        }
        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'GET',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/keys/{key-id}'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation getSecurityObjectDigest
     *
     * Retrieve the digest (hash) of the value of an exportable security object
     *
     * @param \SdkmsClient\Model\ObjectDigestRequest $body Object digest request (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\DigestResponse
     */
    public function getSecurityObjectDigest($body)
    {
        list($response) = $this->getSecurityObjectDigestWithHttpInfo($body);
        return $response;
    }

    /**
     * Operation getSecurityObjectDigestWithHttpInfo
     *
     * Retrieve the digest (hash) of the value of an exportable security object
     *
     * @param \SdkmsClient\Model\ObjectDigestRequest $body Object digest request (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\DigestResponse, HTTP status code, HTTP response headers (array of strings)
     */
    public function getSecurityObjectDigestWithHttpInfo($body)
    {
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling getSecurityObjectDigest');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/digest";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\DigestResponse',
                '/crypto/v1/keys/digest'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\DigestResponse', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\DigestResponse', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation getSecurityObjectKcv
     *
     * Get the key check value (KCV) of a symmetric key
     *
     * @param \SdkmsClient\Model\SobjectDescriptor $body Request to export a security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyCheckValueResponse
     */
    public function getSecurityObjectKcv($body)
    {
        list($response) = $this->getSecurityObjectKcvWithHttpInfo($body);
        return $response;
    }

    /**
     * Operation getSecurityObjectKcvWithHttpInfo
     *
     * Get the key check value (KCV) of a symmetric key
     *
     * @param \SdkmsClient\Model\SobjectDescriptor $body Request to export a security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyCheckValueResponse, HTTP status code, HTTP response headers (array of strings)
     */
    public function getSecurityObjectKcvWithHttpInfo($body)
    {
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling getSecurityObjectKcv');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/kcv";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyCheckValueResponse',
                '/crypto/v1/keys/kcv'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyCheckValueResponse', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyCheckValueResponse', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation getSecurityObjectValue
     *
     * Retrieve the value of an exportable security object
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function getSecurityObjectValue($key_id)
    {
        list($response) = $this->getSecurityObjectValueWithHttpInfo($key_id);
        return $response;
    }

    /**
     * Operation getSecurityObjectValueWithHttpInfo
     *
     * Retrieve the value of an exportable security object
     *
     * @param string $key_id kid of security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function getSecurityObjectValueWithHttpInfo($key_id)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling getSecurityObjectValue');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/{key-id}/export";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'GET',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/keys/{key-id}/export'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation getSecurityObjectValueEx
     *
     * Retrieve the value of an exportable security object
     *
     * @param \SdkmsClient\Model\SobjectDescriptor $body Request to export a security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function getSecurityObjectValueEx($body)
    {
        list($response) = $this->getSecurityObjectValueExWithHttpInfo($body);
        return $response;
    }

    /**
     * Operation getSecurityObjectValueExWithHttpInfo
     *
     * Retrieve the value of an exportable security object
     *
     * @param \SdkmsClient\Model\SobjectDescriptor $body Request to export a security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function getSecurityObjectValueExWithHttpInfo($body)
    {
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling getSecurityObjectValueEx');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/export";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/keys/export'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation getSecurityObjects
     *
     * Get all security objects
     *
     * @param string $name Only retrieve the security object with this name. (optional)
     * @param string $group_id Only retrieve security objects in the specified group. (optional)
     * @param string $creator Only retrieve security objects created by the user or application with the specified id. (optional)
     * @param string $sort This specifies the property (&#x60;kid&#x60; or &#x60;name&#x60;) and order (ascending or descending) with which to sort the security objects. By default, security objects are sorted by &#x60;kid&#x60; in ascending order. The syntax is \&quot;&lt;property&gt;:[asc|desc]\&quot; (e.g. \&quot;kid:desc\&quot;) or just \&quot;&lt;property&gt;\&quot; (ascending order by default). (optional)
     * @param bool $compliant_with_policies Whether this security object is compliant with cryptographic policies or not. (optional)
     * @param string $start If provided, this must be a value of the property specified in &#x60;sort&#x60;. Returned security objects will begin just above or just below this value (for asc/desc order resp.). (optional)
     * @param int $limit Maximum number of security objects to return. If not provided, the limit is 100. (optional)
     * @param int $offset Number of security objects past &#x60;start&#x60; to skip. (optional)
     * @param bool $show_destroyed Whether security objects in the &#x60;Destroyed&#x60; state should be returned (optional)
     * @param bool $show_deleted Whether security objects in the &#x60;Deleted&#x60; state should be returned (optional)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject[]
     */
    public function getSecurityObjects($name = null, $group_id = null, $creator = null, $sort = null, $compliant_with_policies = null, $start = null, $limit = null, $offset = null, $show_destroyed = null, $show_deleted = null)
    {
        list($response) = $this->getSecurityObjectsWithHttpInfo($name, $group_id, $creator, $sort, $compliant_with_policies, $start, $limit, $offset, $show_destroyed, $show_deleted);
        return $response;
    }

    /**
     * Operation getSecurityObjectsWithHttpInfo
     *
     * Get all security objects
     *
     * @param string $name Only retrieve the security object with this name. (optional)
     * @param string $group_id Only retrieve security objects in the specified group. (optional)
     * @param string $creator Only retrieve security objects created by the user or application with the specified id. (optional)
     * @param string $sort This specifies the property (&#x60;kid&#x60; or &#x60;name&#x60;) and order (ascending or descending) with which to sort the security objects. By default, security objects are sorted by &#x60;kid&#x60; in ascending order. The syntax is \&quot;&lt;property&gt;:[asc|desc]\&quot; (e.g. \&quot;kid:desc\&quot;) or just \&quot;&lt;property&gt;\&quot; (ascending order by default). (optional)
     * @param bool $compliant_with_policies Whether this security object is compliant with cryptographic policies or not. (optional)
     * @param string $start If provided, this must be a value of the property specified in &#x60;sort&#x60;. Returned security objects will begin just above or just below this value (for asc/desc order resp.). (optional)
     * @param int $limit Maximum number of security objects to return. If not provided, the limit is 100. (optional)
     * @param int $offset Number of security objects past &#x60;start&#x60; to skip. (optional)
     * @param bool $show_destroyed Whether security objects in the &#x60;Destroyed&#x60; state should be returned (optional)
     * @param bool $show_deleted Whether security objects in the &#x60;Deleted&#x60; state should be returned (optional)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject[], HTTP status code, HTTP response headers (array of strings)
     */
    public function getSecurityObjectsWithHttpInfo($name = null, $group_id = null, $creator = null, $sort = null, $compliant_with_policies = null, $start = null, $limit = null, $offset = null, $show_destroyed = null, $show_deleted = null)
    {
        // parse inputs
        $resourcePath = "/crypto/v1/keys";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // query params
        if ($name !== null) {
            $queryParams['name'] = $this->apiClient->getSerializer()->toQueryValue($name);
        }
        // query params
        if ($group_id !== null) {
            $queryParams['group_id'] = $this->apiClient->getSerializer()->toQueryValue($group_id);
        }
        // query params
        if ($creator !== null) {
            $queryParams['creator'] = $this->apiClient->getSerializer()->toQueryValue($creator);
        }
        // query params
        if ($sort !== null) {
            $queryParams['sort'] = $this->apiClient->getSerializer()->toQueryValue($sort);
        }
        // query params
        if ($compliant_with_policies !== null) {
            $queryParams['compliant_with_policies'] = $this->apiClient->getSerializer()->toQueryValue($compliant_with_policies);
        }
        // query params
        if ($start !== null) {
            $queryParams['start'] = $this->apiClient->getSerializer()->toQueryValue($start);
        }
        // query params
        if ($limit !== null) {
            $queryParams['limit'] = $this->apiClient->getSerializer()->toQueryValue($limit);
        }
        // query params
        if ($offset !== null) {
            $queryParams['offset'] = $this->apiClient->getSerializer()->toQueryValue($offset);
        }
        // query params
        if ($show_destroyed !== null) {
            $queryParams['show_destroyed'] = $this->apiClient->getSerializer()->toQueryValue($show_destroyed);
        }
        // query params
        if ($show_deleted !== null) {
            $queryParams['show_deleted'] = $this->apiClient->getSerializer()->toQueryValue($show_deleted);
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'GET',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject[]',
                '/crypto/v1/keys'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject[]', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject[]', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation importSecurityObject
     *
     * Import a security object
     *
     * @param \SdkmsClient\Model\SobjectRequest $body Request to create, update, or import security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function importSecurityObject($body)
    {
        list($response) = $this->importSecurityObjectWithHttpInfo($body);
        return $response;
    }

    /**
     * Operation importSecurityObjectWithHttpInfo
     *
     * Import a security object
     *
     * @param \SdkmsClient\Model\SobjectRequest $body Request to create, update, or import security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function importSecurityObjectWithHttpInfo($body)
    {
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling importSecurityObject');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'PUT',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/keys'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 201:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation importSobjectComponents
     *
     * import key components
     *
     * @param \SdkmsClient\Model\ImportSobjectComponentsRequest $body Request to import a security object components (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function importSobjectComponents($body)
    {
        list($response) = $this->importSobjectComponentsWithHttpInfo($body);
        return $response;
    }

    /**
     * Operation importSobjectComponentsWithHttpInfo
     *
     * import key components
     *
     * @param \SdkmsClient\Model\ImportSobjectComponentsRequest $body Request to import a security object components (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function importSobjectComponentsWithHttpInfo($body)
    {
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling importSobjectComponents');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/components/import";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/keys/components/import'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation persistSecurityObject
     *
     * Persist a transient key.
     *
     * @param \SdkmsClient\Model\PersistTransientKeyRequest $body Persist transient key request (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function persistSecurityObject($body)
    {
        list($response) = $this->persistSecurityObjectWithHttpInfo($body);
        return $response;
    }

    /**
     * Operation persistSecurityObjectWithHttpInfo
     *
     * Persist a transient key.
     *
     * @param \SdkmsClient\Model\PersistTransientKeyRequest $body Persist transient key request (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function persistSecurityObjectWithHttpInfo($body)
    {
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling persistSecurityObject');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/persist";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/keys/persist'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 201:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation revertHistoryItem
     *
     * Reverts a security object to a previous state
     *
     * @param string $key_id kid of security object (required)
     * @param \SdkmsClient\Model\SobjectRequest $body Request to create, update, or import security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return void
     */
    public function revertHistoryItem($key_id, $body)
    {
        list($response) = $this->revertHistoryItemWithHttpInfo($key_id, $body);
        return $response;
    }

    /**
     * Operation revertHistoryItemWithHttpInfo
     *
     * Reverts a security object to a previous state
     *
     * @param string $key_id kid of security object (required)
     * @param \SdkmsClient\Model\SobjectRequest $body Request to create, update, or import security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of null, HTTP status code, HTTP response headers (array of strings)
     */
    public function revertHistoryItemWithHttpInfo($key_id, $body)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling revertHistoryItem');
        }
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling revertHistoryItem');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/{key-id}/revert";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }
        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'PUT',
                $queryParams,
                $httpBody,
                $headerParams,
                null,
                '/crypto/v1/keys/{key-id}/revert'
            );

            return [null, $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation revokeSecurityObject
     *
     * Transitions immediately a security object to Deactivated or Compromised state
     *
     * @param string $key_id kid of security object (required)
     * @param \SdkmsClient\Model\RevocationReason $body Reason to revoke a security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return void
     */
    public function revokeSecurityObject($key_id, $body)
    {
        list($response) = $this->revokeSecurityObjectWithHttpInfo($key_id, $body);
        return $response;
    }

    /**
     * Operation revokeSecurityObjectWithHttpInfo
     *
     * Transitions immediately a security object to Deactivated or Compromised state
     *
     * @param string $key_id kid of security object (required)
     * @param \SdkmsClient\Model\RevocationReason $body Reason to revoke a security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of null, HTTP status code, HTTP response headers (array of strings)
     */
    public function revokeSecurityObjectWithHttpInfo($key_id, $body)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling revokeSecurityObject');
        }
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling revokeSecurityObject');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/{key-id}/revoke";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }
        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                null,
                '/crypto/v1/keys/{key-id}/revoke'
            );

            return [null, $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation rotateSecurityObject
     *
     * Rotate a key.
     *
     * @param \SdkmsClient\Model\SobjectRequest $body Request to create, update, or import security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function rotateSecurityObject($body)
    {
        list($response) = $this->rotateSecurityObjectWithHttpInfo($body);
        return $response;
    }

    /**
     * Operation rotateSecurityObjectWithHttpInfo
     *
     * Rotate a key.
     *
     * @param \SdkmsClient\Model\SobjectRequest $body Request to create, update, or import security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function rotateSecurityObjectWithHttpInfo($body)
    {
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling rotateSecurityObject');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/rekey";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/keys/rekey'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 201:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation updateSecurityObject
     *
     * Update a security object
     *
     * @param string $key_id kid of security object (required)
     * @param \SdkmsClient\Model\SobjectRequest $body Request to create, update, or import security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\KeyObject
     */
    public function updateSecurityObject($key_id, $body)
    {
        list($response) = $this->updateSecurityObjectWithHttpInfo($key_id, $body);
        return $response;
    }

    /**
     * Operation updateSecurityObjectWithHttpInfo
     *
     * Update a security object
     *
     * @param string $key_id kid of security object (required)
     * @param \SdkmsClient\Model\SobjectRequest $body Request to create, update, or import security object (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\KeyObject, HTTP status code, HTTP response headers (array of strings)
     */
    public function updateSecurityObjectWithHttpInfo($key_id, $body)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling updateSecurityObject');
        }
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling updateSecurityObject');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/{key-id}";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }
        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'PATCH',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\KeyObject',
                '/crypto/v1/keys/{key-id}'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\KeyObject', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\KeyObject', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation verifyKcv
     *
     * Verify that the KCV of the provided key material matches the provided KCV
     *
     * @param \SdkmsClient\Model\VerifyKcvRequest $body Verify KCV request (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\VerifyKcvResponse
     */
    public function verifyKcv($body)
    {
        list($response) = $this->verifyKcvWithHttpInfo($body);
        return $response;
    }

    /**
     * Operation verifyKcvWithHttpInfo
     *
     * Verify that the KCV of the provided key material matches the provided KCV
     *
     * @param \SdkmsClient\Model\VerifyKcvRequest $body Verify KCV request (required)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\VerifyKcvResponse, HTTP status code, HTTP response headers (array of strings)
     */
    public function verifyKcvWithHttpInfo($body)
    {
        // verify the required parameter 'body' is set
        if ($body === null) {
            throw new \InvalidArgumentException('Missing the required parameter $body when calling verifyKcv');
        }
        // parse inputs
        $resourcePath = "/crypto/v1/keys/kcv/verify";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // body params
        $_tempBody = null;
        if (isset($body)) {
            $_tempBody = $body;
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'POST',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\VerifyKcvResponse',
                '/crypto/v1/keys/kcv/verify'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\VerifyKcvResponse', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\VerifyKcvResponse', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }
}
