# SwaggerClient-php
This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations.

This PHP package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0-20200608
- Build package: io.swagger.codegen.languages.PhpClientCodegen
For more information, please visit [https://support.fortanix.com/sdkms](https://support.fortanix.com/sdkms)

## Requirements

PHP 5.4.0 and later

## Installation & Usage
### Composer

To install the bindings via [Composer](http://getcomposer.org/), add the following to `composer.json`:

```
{
  "repositories": [
    {
      "type": "git",
      "url": "https://github.com/GIT_USER_ID/GIT_REPO_ID.git"
    }
  ],
  "require": {
    "GIT_USER_ID/GIT_REPO_ID": "*@dev"
  }
}
```

Then run `composer install`

### Manual Installation

Download the files and include `autoload.php`:

```php
    require_once('/path/to/SwaggerClient-php/autoload.php');
```

## Tests

To run the unit tests:

```
composer install
./vendor/bin/phpunit
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\AWSApi();
$key_id = "key_id_example"; // string | kid of security object

try {
    $result = $api_instance->cancelDeletion($key_id);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling AWSApi->cancelDeletion: ', $e->getMessage(), PHP_EOL;
}

?>
```

## Documentation for API Endpoints

All URIs are relative to *https://apps.smartkey.io*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AWSApi* | [**cancelDeletion**](docs/Api/AWSApi.md#canceldeletion) | **POST** /crypto/v1/keys/{key-id}/cancel_deletion | Cancel scheduled deletion of an AWS KMS key
*AWSApi* | [**deleteKeyMaterial**](docs/Api/AWSApi.md#deletekeymaterial) | **POST** /crypto/v1/keys/{key-id}/delete_key_material | Delete the key material of an AWS KMS key
*AWSApi* | [**restore**](docs/Api/AWSApi.md#restore) | **POST** /crypto/v1/keys/{key-id}/restore | Restore an AWS KMS key from its source key material
*AWSApi* | [**scheduleDeletion**](docs/Api/AWSApi.md#scheduledeletion) | **POST** /crypto/v1/keys/{key-id}/schedule_deletion | Schedule an AWS KMS key for deletion
*AccountsApi* | [**createAccount**](docs/Api/AccountsApi.md#createaccount) | **POST** /sys/v1/accounts | Create a new account
*AccountsApi* | [**deleteAccount**](docs/Api/AccountsApi.md#deleteaccount) | **DELETE** /sys/v1/accounts/{account-id} | Delete account
*AccountsApi* | [**getAccount**](docs/Api/AccountsApi.md#getaccount) | **GET** /sys/v1/accounts/{account-id} | Get a specific account
*AccountsApi* | [**getAccounts**](docs/Api/AccountsApi.md#getaccounts) | **GET** /sys/v1/accounts | Get all accounts
*AccountsApi* | [**updateAccount**](docs/Api/AccountsApi.md#updateaccount) | **PATCH** /sys/v1/accounts/{account-id} | Update account
*ApprovalRequestsApi* | [**approve**](docs/Api/ApprovalRequestsApi.md#approve) | **POST** /sys/v1/approval_requests/{request-id}/approve | Approve a request.
*ApprovalRequestsApi* | [**createApprovalRequest**](docs/Api/ApprovalRequestsApi.md#createapprovalrequest) | **POST** /sys/v1/approval_requests | Create approval request
*ApprovalRequestsApi* | [**deleteApprovalRequest**](docs/Api/ApprovalRequestsApi.md#deleteapprovalrequest) | **DELETE** /sys/v1/approval_requests/{request-id} | Delete an approval request.
*ApprovalRequestsApi* | [**deny**](docs/Api/ApprovalRequestsApi.md#deny) | **POST** /sys/v1/approval_requests/{request-id}/deny | Deny a request.
*ApprovalRequestsApi* | [**getApprovalRequest**](docs/Api/ApprovalRequestsApi.md#getapprovalrequest) | **GET** /sys/v1/approval_requests/{request-id} | Get an approval request.
*ApprovalRequestsApi* | [**getApprovalRequests**](docs/Api/ApprovalRequestsApi.md#getapprovalrequests) | **GET** /sys/v1/approval_requests | Get all approval requests
*ApprovalRequestsApi* | [**getResult**](docs/Api/ApprovalRequestsApi.md#getresult) | **POST** /sys/v1/approval_requests/{request-id}/result | Get the result for an approved or failed request.
*AppsApi* | [**createApp**](docs/Api/AppsApi.md#createapp) | **POST** /sys/v1/apps | Create a new application
*AppsApi* | [**deleteApp**](docs/Api/AppsApi.md#deleteapp) | **DELETE** /sys/v1/apps/{app-id} | Delete application
*AppsApi* | [**getApp**](docs/Api/AppsApi.md#getapp) | **GET** /sys/v1/apps/{app-id} | Get a specific application
*AppsApi* | [**getApps**](docs/Api/AppsApi.md#getapps) | **GET** /sys/v1/apps | Get all applications
*AppsApi* | [**getCredential**](docs/Api/AppsApi.md#getcredential) | **GET** /sys/v1/apps/{app-id}/credential | Get a specific application&#39;s credential
*AppsApi* | [**regenerateApiKey**](docs/Api/AppsApi.md#regenerateapikey) | **POST** /sys/v1/apps/{app-id}/reset_secret | Regenerate API key
*AppsApi* | [**updateApp**](docs/Api/AppsApi.md#updateapp) | **PATCH** /sys/v1/apps/{app-id} | Update an application
*AuthenticationApi* | [**authorize**](docs/Api/AuthenticationApi.md#authorize) | **POST** /sys/v1/session/auth | Create a session for a user or an app
*AuthenticationApi* | [**checkHealth**](docs/Api/AuthenticationApi.md#checkhealth) | **GET** /sys/v1/health | Check whether the server is handling requests
*AuthenticationApi* | [**getServerVersion**](docs/Api/AuthenticationApi.md#getserverversion) | **GET** /sys/v1/version | Get SDKMS version information
*AuthenticationApi* | [**reAuth**](docs/Api/AuthenticationApi.md#reauth) | **POST** /sys/v1/session/reauth | Create a new session for a user or an app using an existing session bearer token.
*AuthenticationApi* | [**refresh**](docs/Api/AuthenticationApi.md#refresh) | **POST** /sys/v1/session/refresh | Refreshes existing user or app session.
*AuthenticationApi* | [**selectAccount**](docs/Api/AuthenticationApi.md#selectaccount) | **POST** /sys/v1/session/select_account | Select a user&#39;s account to work on
*AuthenticationApi* | [**terminate**](docs/Api/AuthenticationApi.md#terminate) | **POST** /sys/v1/session/terminate | Terminate a session
*AuthenticationApi* | [**unlock2F**](docs/Api/AuthenticationApi.md#unlock2f) | **POST** /sys/v1/session/config_2fa/auth | Unlock two factor configuration
*ChildAccountUsersApi* | [**createChildAccountUser**](docs/Api/ChildAccountUsersApi.md#createchildaccountuser) | **POST** /sys/v1/users/child_account | Create a new user user in a child account
*ChildAccountUsersApi* | [**deleteChildAccountUser**](docs/Api/ChildAccountUsersApi.md#deletechildaccountuser) | **DELETE** /sys/v1/users/child_account/{user-id} | Completely delete a user in child account
*ChildAccountUsersApi* | [**getAllChildAccountUsers**](docs/Api/ChildAccountUsersApi.md#getallchildaccountusers) | **GET** /sys/v1/users/child_account/{account-id}/all | Get all users in a child account
*ChildAccountUsersApi* | [**getChildAccountUser**](docs/Api/ChildAccountUsersApi.md#getchildaccountuser) | **GET** /sys/v1/users/child_account/{user-id} | Get a specific child account user
*ChildAccountUsersApi* | [**updateChildAccountUser**](docs/Api/ChildAccountUsersApi.md#updatechildaccountuser) | **PATCH** /sys/v1/users/child_account/{user-id} | Update a child account user
*ChildAccountsApi* | [**createChildAccount**](docs/Api/ChildAccountsApi.md#createchildaccount) | **POST** /sys/v1/accounts/child | Create a new child account
*ChildAccountsApi* | [**getChildAccounts**](docs/Api/ChildAccountsApi.md#getchildaccounts) | **GET** /sys/v1/accounts/{account-id}/child | Get all child accounts of the given account
*DigestApi* | [**batchMac**](docs/Api/DigestApi.md#batchmac) | **POST** /crypto/v1/keys/batch/mac | Batch MAC with one or more keys
*DigestApi* | [**batchMacVerify**](docs/Api/DigestApi.md#batchmacverify) | **POST** /crypto/v1/keys/batch/macverify | Batch MAC Verify with one or more keys
*DigestApi* | [**computeDigest**](docs/Api/DigestApi.md#computedigest) | **POST** /crypto/v1/digest | Compute a message digest of data
*DigestApi* | [**computeMac**](docs/Api/DigestApi.md#computemac) | **POST** /crypto/v1/keys/{key-id}/mac | Compute MAC using a key
*DigestApi* | [**computeMacEx**](docs/Api/DigestApi.md#computemacex) | **POST** /crypto/v1/mac | Compute MAC using a key
*DigestApi* | [**verifyMac**](docs/Api/DigestApi.md#verifymac) | **POST** /crypto/v1/keys/{key-id}/macverify | Verify MAC using a key
*DigestApi* | [**verifyMacEx**](docs/Api/DigestApi.md#verifymacex) | **POST** /crypto/v1/macverify | Verify MAC using a key
*EncryptionAndDecryptionApi* | [**batchDecrypt**](docs/Api/EncryptionAndDecryptionApi.md#batchdecrypt) | **POST** /crypto/v1/keys/batch/decrypt | Batch decrypt with one or more keys
*EncryptionAndDecryptionApi* | [**batchEncrypt**](docs/Api/EncryptionAndDecryptionApi.md#batchencrypt) | **POST** /crypto/v1/keys/batch/encrypt | Batch encrypt with one or more keys
*EncryptionAndDecryptionApi* | [**decrypt**](docs/Api/EncryptionAndDecryptionApi.md#decrypt) | **POST** /crypto/v1/keys/{key-id}/decrypt | Decrypt data
*EncryptionAndDecryptionApi* | [**decryptEx**](docs/Api/EncryptionAndDecryptionApi.md#decryptex) | **POST** /crypto/v1/decrypt | Decrypt data
*EncryptionAndDecryptionApi* | [**decryptFinal**](docs/Api/EncryptionAndDecryptionApi.md#decryptfinal) | **POST** /crypto/v1/keys/{key-id}/decrypt/final | Conclude multi-part decryption
*EncryptionAndDecryptionApi* | [**decryptFinalEx**](docs/Api/EncryptionAndDecryptionApi.md#decryptfinalex) | **POST** /crypto/v1/decrypt/final | Conclude multi-part decryption
*EncryptionAndDecryptionApi* | [**decryptInit**](docs/Api/EncryptionAndDecryptionApi.md#decryptinit) | **POST** /crypto/v1/keys/{key-id}/decrypt/init | Begin multi-part decryption
*EncryptionAndDecryptionApi* | [**decryptInitEx**](docs/Api/EncryptionAndDecryptionApi.md#decryptinitex) | **POST** /crypto/v1/decrypt/init | Begin multi-part decryption
*EncryptionAndDecryptionApi* | [**decryptUpdate**](docs/Api/EncryptionAndDecryptionApi.md#decryptupdate) | **POST** /crypto/v1/keys/{key-id}/decrypt/update | Continue multi-part decryption
*EncryptionAndDecryptionApi* | [**decryptUpdateEx**](docs/Api/EncryptionAndDecryptionApi.md#decryptupdateex) | **POST** /crypto/v1/decrypt/update | Continue multi-part decryption
*EncryptionAndDecryptionApi* | [**encrypt**](docs/Api/EncryptionAndDecryptionApi.md#encrypt) | **POST** /crypto/v1/keys/{key-id}/encrypt | Encrypt data
*EncryptionAndDecryptionApi* | [**encryptEx**](docs/Api/EncryptionAndDecryptionApi.md#encryptex) | **POST** /crypto/v1/encrypt | Encrypt data
*EncryptionAndDecryptionApi* | [**encryptFinal**](docs/Api/EncryptionAndDecryptionApi.md#encryptfinal) | **POST** /crypto/v1/keys/{key-id}/encrypt/final | Conclude multi-part encryption
*EncryptionAndDecryptionApi* | [**encryptFinalEx**](docs/Api/EncryptionAndDecryptionApi.md#encryptfinalex) | **POST** /crypto/v1/encrypt/final | Conclude multi-part encryption
*EncryptionAndDecryptionApi* | [**encryptInit**](docs/Api/EncryptionAndDecryptionApi.md#encryptinit) | **POST** /crypto/v1/keys/{key-id}/encrypt/init | Begin multi-part encryption
*EncryptionAndDecryptionApi* | [**encryptInitEx**](docs/Api/EncryptionAndDecryptionApi.md#encryptinitex) | **POST** /crypto/v1/encrypt/init | Begin multi-part encryption
*EncryptionAndDecryptionApi* | [**encryptUpdate**](docs/Api/EncryptionAndDecryptionApi.md#encryptupdate) | **POST** /crypto/v1/keys/{key-id}/encrypt/update | Continue multi-part encryption
*EncryptionAndDecryptionApi* | [**encryptUpdateEx**](docs/Api/EncryptionAndDecryptionApi.md#encryptupdateex) | **POST** /crypto/v1/encrypt/update | Continue multi-part encryption
*GroupsApi* | [**createGroup**](docs/Api/GroupsApi.md#creategroup) | **POST** /sys/v1/groups | Create new group
*GroupsApi* | [**deleteGroup**](docs/Api/GroupsApi.md#deletegroup) | **DELETE** /sys/v1/groups/{group-id} | Delete group
*GroupsApi* | [**getGroup**](docs/Api/GroupsApi.md#getgroup) | **GET** /sys/v1/groups/{group-id} | Get a specific group
*GroupsApi* | [**getGroups**](docs/Api/GroupsApi.md#getgroups) | **GET** /sys/v1/groups | Get all groups
*GroupsApi* | [**updateGroup**](docs/Api/GroupsApi.md#updategroup) | **PATCH** /sys/v1/groups/{group-id} | Update group
*LogsApi* | [**getAuditLogs**](docs/Api/LogsApi.md#getauditlogs) | **GET** /sys/v1/logs | Get audit logs
*PluginsApi* | [**createPlugin**](docs/Api/PluginsApi.md#createplugin) | **POST** /sys/v1/plugins | Create a new plugin
*PluginsApi* | [**deletePlugin**](docs/Api/PluginsApi.md#deleteplugin) | **DELETE** /sys/v1/plugins/{plugin-id} | Delete plugin
*PluginsApi* | [**getPlugin**](docs/Api/PluginsApi.md#getplugin) | **GET** /sys/v1/plugins/{plugin-id} | Get a specific plugin
*PluginsApi* | [**getPlugins**](docs/Api/PluginsApi.md#getplugins) | **GET** /sys/v1/plugins | Get all plugins
*PluginsApi* | [**invokePlugin**](docs/Api/PluginsApi.md#invokeplugin) | **POST** /sys/v1/plugins/{plugin-id} | Invoke a plugin
*PluginsApi* | [**sysV1PluginsInvokePluginIdGet**](docs/Api/PluginsApi.md#sysv1pluginsinvokepluginidget) | **GET** /sys/v1/plugins/invoke/{plugin-id} | Invoke a plugin using GET.
*PluginsApi* | [**updatePlugin**](docs/Api/PluginsApi.md#updateplugin) | **PATCH** /sys/v1/plugins/{plugin-id} | Update a plugin
*SecurityObjectsApi* | [**activateSecurityObject**](docs/Api/SecurityObjectsApi.md#activatesecurityobject) | **POST** /crypto/v1/keys/{key-id}/activate | Transitions immediately a security object to Active state
*SecurityObjectsApi* | [**agreeKey**](docs/Api/SecurityObjectsApi.md#agreekey) | **POST** /crypto/v1/agree | Agree on a key from two other keys
*SecurityObjectsApi* | [**deletePrivateKey**](docs/Api/SecurityObjectsApi.md#deleteprivatekey) | **DELETE** /crypto/v1/keys/{key-id}/private | Remove / Destroy private half of the asymmetric key
*SecurityObjectsApi* | [**deleteSecurityObject**](docs/Api/SecurityObjectsApi.md#deletesecurityobject) | **DELETE** /crypto/v1/keys/{key-id} | Delete a security object
*SecurityObjectsApi* | [**deriveKey**](docs/Api/SecurityObjectsApi.md#derivekey) | **POST** /crypto/v1/keys/{key-id}/derive | Derive a key from another key
*SecurityObjectsApi* | [**deriveKeyEx**](docs/Api/SecurityObjectsApi.md#derivekeyex) | **POST** /crypto/v1/derive | Derive a key from another key
*SecurityObjectsApi* | [**destroySecurityObject**](docs/Api/SecurityObjectsApi.md#destroysecurityobject) | **POST** /crypto/v1/keys/{key-id}/destroy | Destroys a security object, leaving its metadata in place
*SecurityObjectsApi* | [**exportSobjectComponents**](docs/Api/SecurityObjectsApi.md#exportsobjectcomponents) | **POST** /crypto/v1/keys/components/export | export key components
*SecurityObjectsApi* | [**generateSecurityObject**](docs/Api/SecurityObjectsApi.md#generatesecurityobject) | **POST** /crypto/v1/keys | Generate a new security object
*SecurityObjectsApi* | [**getSecurityObject**](docs/Api/SecurityObjectsApi.md#getsecurityobject) | **GET** /crypto/v1/keys/{key-id} | Get a specific security object
*SecurityObjectsApi* | [**getSecurityObjectDigest**](docs/Api/SecurityObjectsApi.md#getsecurityobjectdigest) | **POST** /crypto/v1/keys/digest | Retrieve the digest (hash) of the value of an exportable security object
*SecurityObjectsApi* | [**getSecurityObjectKcv**](docs/Api/SecurityObjectsApi.md#getsecurityobjectkcv) | **POST** /crypto/v1/keys/kcv | Get the key check value (KCV) of a symmetric key
*SecurityObjectsApi* | [**getSecurityObjectValue**](docs/Api/SecurityObjectsApi.md#getsecurityobjectvalue) | **GET** /crypto/v1/keys/{key-id}/export | Retrieve the value of an exportable security object
*SecurityObjectsApi* | [**getSecurityObjectValueEx**](docs/Api/SecurityObjectsApi.md#getsecurityobjectvalueex) | **POST** /crypto/v1/keys/export | Retrieve the value of an exportable security object
*SecurityObjectsApi* | [**getSecurityObjects**](docs/Api/SecurityObjectsApi.md#getsecurityobjects) | **GET** /crypto/v1/keys | Get all security objects
*SecurityObjectsApi* | [**importSecurityObject**](docs/Api/SecurityObjectsApi.md#importsecurityobject) | **PUT** /crypto/v1/keys | Import a security object
*SecurityObjectsApi* | [**importSobjectComponents**](docs/Api/SecurityObjectsApi.md#importsobjectcomponents) | **POST** /crypto/v1/keys/components/import | import key components
*SecurityObjectsApi* | [**persistSecurityObject**](docs/Api/SecurityObjectsApi.md#persistsecurityobject) | **POST** /crypto/v1/keys/persist | Persist a transient key.
*SecurityObjectsApi* | [**revertHistoryItem**](docs/Api/SecurityObjectsApi.md#reverthistoryitem) | **PUT** /crypto/v1/keys/{key-id}/revert | Reverts a security object to a previous state
*SecurityObjectsApi* | [**revokeSecurityObject**](docs/Api/SecurityObjectsApi.md#revokesecurityobject) | **POST** /crypto/v1/keys/{key-id}/revoke | Transitions immediately a security object to Deactivated or Compromised state
*SecurityObjectsApi* | [**rotateSecurityObject**](docs/Api/SecurityObjectsApi.md#rotatesecurityobject) | **POST** /crypto/v1/keys/rekey | Rotate a key.
*SecurityObjectsApi* | [**updateSecurityObject**](docs/Api/SecurityObjectsApi.md#updatesecurityobject) | **PATCH** /crypto/v1/keys/{key-id} | Update a security object
*SecurityObjectsApi* | [**verifyKcv**](docs/Api/SecurityObjectsApi.md#verifykcv) | **POST** /crypto/v1/keys/kcv/verify | Verify that the KCV of the provided key material matches the provided KCV
*SignAndVerifyApi* | [**batchSign**](docs/Api/SignAndVerifyApi.md#batchsign) | **POST** /crypto/v1/keys/batch/sign | Batch sign with one or more private keys
*SignAndVerifyApi* | [**batchVerify**](docs/Api/SignAndVerifyApi.md#batchverify) | **POST** /crypto/v1/keys/batch/verify | Batch verify with one or more private keys
*SignAndVerifyApi* | [**sign**](docs/Api/SignAndVerifyApi.md#sign) | **POST** /crypto/v1/keys/{key-id}/sign | Sign with a private key
*SignAndVerifyApi* | [**signEx**](docs/Api/SignAndVerifyApi.md#signex) | **POST** /crypto/v1/sign | Sign with a private key
*SignAndVerifyApi* | [**verify**](docs/Api/SignAndVerifyApi.md#verify) | **POST** /crypto/v1/keys/{key-id}/verify | Verify a signature with a key
*SignAndVerifyApi* | [**verifyEx**](docs/Api/SignAndVerifyApi.md#verifyex) | **POST** /crypto/v1/verify | Verify a signature with a key
*StatsApi* | [**getAppStats**](docs/Api/StatsApi.md#getappstats) | **GET** /sys/v1/stats/{app-id}/app | Get transaction statistics for a specific application
*StatsApi* | [**getAppsStats**](docs/Api/StatsApi.md#getappsstats) | **GET** /sys/v1/stats/apps | Get app aggregate transaction statistics
*StatsApi* | [**getGroupStats**](docs/Api/StatsApi.md#getgroupstats) | **GET** /sys/v1/stats/{group-id}/group | Get transaction statistics for a specific group
*StatsApi* | [**getGroupsStats**](docs/Api/StatsApi.md#getgroupsstats) | **GET** /sys/v1/stats/groups | Get group aggregate transaction statistics
*StatsApi* | [**getSecurityObjectStats**](docs/Api/StatsApi.md#getsecurityobjectstats) | **GET** /sys/v1/stats/{key-id}/key | Get transaction statistics for a specific security object
*TwoFactorAuthenticationApi* | [**authorizeRecoveryCode**](docs/Api/TwoFactorAuthenticationApi.md#authorizerecoverycode) | **POST** /sys/v1/session/auth/2fa/recovery_code | Use a backup recovery code to complete authentication
*TwoFactorAuthenticationApi* | [**authorizeU2F**](docs/Api/TwoFactorAuthenticationApi.md#authorizeu2f) | **POST** /sys/v1/session/auth/2fa/u2f | Use a U2F key to complete authentication
*TwoFactorAuthenticationApi* | [**generateRecoveryCodes**](docs/Api/TwoFactorAuthenticationApi.md#generaterecoverycodes) | **POST** /sys/v1/users/generate_recovery_code | Generate backup recovery codes for the current user
*TwoFactorAuthenticationApi* | [**generateU2FChallenge**](docs/Api/TwoFactorAuthenticationApi.md#generateu2fchallenge) | **POST** /sys/v1/session/config_2fa/new_challenge | Generate a new challenge for registering a U2F devices
*TwoFactorAuthenticationApi* | [**lock2F**](docs/Api/TwoFactorAuthenticationApi.md#lock2f) | **POST** /sys/v1/session/config_2fa/terminate | Lock two factor configuration
*UsersApi* | [**changePassword**](docs/Api/UsersApi.md#changepassword) | **POST** /sys/v1/users/change_password | Change user password
*UsersApi* | [**confirmEmail**](docs/Api/UsersApi.md#confirmemail) | **POST** /sys/v1/users/{user-id}/confirm_email | Confirms user&#39;s email address
*UsersApi* | [**createUser**](docs/Api/UsersApi.md#createuser) | **POST** /sys/v1/users | Create a new user
*UsersApi* | [**deleteUser**](docs/Api/UsersApi.md#deleteuser) | **DELETE** /sys/v1/users/{user-id}/accounts | Removed user&#39;s association with an account
*UsersApi* | [**deleteUserAccount**](docs/Api/UsersApi.md#deleteuseraccount) | **DELETE** /sys/v1/users | Completely delete a user profile from system
*UsersApi* | [**forgotPassword**](docs/Api/UsersApi.md#forgotpassword) | **POST** /sys/v1/users/forgot_password | Initiate password reset sequence for a user
*UsersApi* | [**getUser**](docs/Api/UsersApi.md#getuser) | **GET** /sys/v1/users/{user-id} | Get a specific user
*UsersApi* | [**getUserAccount**](docs/Api/UsersApi.md#getuseraccount) | **GET** /sys/v1/users/accounts | Get account information for the user
*UsersApi* | [**getUsers**](docs/Api/UsersApi.md#getusers) | **GET** /sys/v1/users | Get all users
*UsersApi* | [**inviteUser**](docs/Api/UsersApi.md#inviteuser) | **POST** /sys/v1/users/invite | Invite a user
*UsersApi* | [**processInvitations**](docs/Api/UsersApi.md#processinvitations) | **POST** /sys/v1/users/process_invite | Process a user&#39;s pending account invitations
*UsersApi* | [**resendConfirmEmail**](docs/Api/UsersApi.md#resendconfirmemail) | **POST** /sys/v1/users/{user-id}/resend_confirm_email | Resend email with link to confirm user&#39;s email address
*UsersApi* | [**resendInvitation**](docs/Api/UsersApi.md#resendinvitation) | **POST** /sys/v1/users/{user-id}/resend_invite | Resend invite to the user to join a specific account
*UsersApi* | [**resetPassword**](docs/Api/UsersApi.md#resetpassword) | **POST** /sys/v1/users/{user-id}/reset_password | Reset a user&#39;s password
*UsersApi* | [**updateUser**](docs/Api/UsersApi.md#updateuser) | **PATCH** /sys/v1/users/{user-id} | Update user
*UsersApi* | [**validatePasswordResetToken**](docs/Api/UsersApi.md#validatepasswordresettoken) | **POST** /sys/v1/users/{user-id}/validate_token | Validates password reset token for the user
*WrappingAndUnwrappingApi* | [**unwrapKey**](docs/Api/WrappingAndUnwrappingApi.md#unwrapkey) | **POST** /crypto/v1/keys/{key-id}/unwrapkey | Unwrap a security object with a key
*WrappingAndUnwrappingApi* | [**unwrapKeyEx**](docs/Api/WrappingAndUnwrappingApi.md#unwrapkeyex) | **POST** /crypto/v1/unwrapkey | Unwrap a security object with a key
*WrappingAndUnwrappingApi* | [**wrapKey**](docs/Api/WrappingAndUnwrappingApi.md#wrapkey) | **POST** /crypto/v1/keys/{key-id}/wrapkey | Wrap a security object with a key
*WrappingAndUnwrappingApi* | [**wrapKeyEx**](docs/Api/WrappingAndUnwrappingApi.md#wrapkeyex) | **POST** /crypto/v1/wrapkey | Wrap a security object with a key


## Documentation For Models

 - [ADDecryptInput](docs/Model/ADDecryptInput.md)
 - [ADEncryptInput](docs/Model/ADEncryptInput.md)
 - [Account](docs/Model/Account.md)
 - [AccountRequest](docs/Model/AccountRequest.md)
 - [AccountState](docs/Model/AccountState.md)
 - [AgreeKeyMechanism](docs/Model/AgreeKeyMechanism.md)
 - [AgreeKeyRequest](docs/Model/AgreeKeyRequest.md)
 - [App](docs/Model/App.md)
 - [AppAuthType](docs/Model/AppAuthType.md)
 - [AppCredential](docs/Model/AppCredential.md)
 - [AppCredentialResponse](docs/Model/AppCredentialResponse.md)
 - [AppCredentialSignedjwt](docs/Model/AppCredentialSignedjwt.md)
 - [AppCredentialSignedjwtSigningKeys](docs/Model/AppCredentialSignedjwtSigningKeys.md)
 - [AppCredentialTrustedca](docs/Model/AppCredentialTrustedca.md)
 - [AppOauthConfig](docs/Model/AppOauthConfig.md)
 - [AppPermissions](docs/Model/AppPermissions.md)
 - [AppRequest](docs/Model/AppRequest.md)
 - [AppResetSecretRequest](docs/Model/AppResetSecretRequest.md)
 - [ApprovableResult](docs/Model/ApprovableResult.md)
 - [ApprovalRequest](docs/Model/ApprovalRequest.md)
 - [ApprovalRequestRequest](docs/Model/ApprovalRequestRequest.md)
 - [ApprovalStatus](docs/Model/ApprovalStatus.md)
 - [ApprovalSubject](docs/Model/ApprovalSubject.md)
 - [ApproveRequest](docs/Model/ApproveRequest.md)
 - [AuditLogResponse](docs/Model/AuditLogResponse.md)
 - [AuthConfig](docs/Model/AuthConfig.md)
 - [AuthConfigPassword](docs/Model/AuthConfigPassword.md)
 - [AuthConfigSignedJWT](docs/Model/AuthConfigSignedJWT.md)
 - [AuthResponse](docs/Model/AuthResponse.md)
 - [AuthType](docs/Model/AuthType.md)
 - [AzureKeyVaultType](docs/Model/AzureKeyVaultType.md)
 - [BatchDecryptRequest](docs/Model/BatchDecryptRequest.md)
 - [BatchDecryptRequestInner](docs/Model/BatchDecryptRequestInner.md)
 - [BatchDecryptResponse](docs/Model/BatchDecryptResponse.md)
 - [BatchDecryptResponseInner](docs/Model/BatchDecryptResponseInner.md)
 - [BatchEncryptRequest](docs/Model/BatchEncryptRequest.md)
 - [BatchEncryptRequestInner](docs/Model/BatchEncryptRequestInner.md)
 - [BatchEncryptResponse](docs/Model/BatchEncryptResponse.md)
 - [BatchEncryptResponseInner](docs/Model/BatchEncryptResponseInner.md)
 - [BatchMacRequest](docs/Model/BatchMacRequest.md)
 - [BatchMacResponse](docs/Model/BatchMacResponse.md)
 - [BatchMacResponseInner](docs/Model/BatchMacResponseInner.md)
 - [BatchMacVerifyRequest](docs/Model/BatchMacVerifyRequest.md)
 - [BatchSignRequest](docs/Model/BatchSignRequest.md)
 - [BatchSignResponse](docs/Model/BatchSignResponse.md)
 - [BatchSignResponseInner](docs/Model/BatchSignResponseInner.md)
 - [BatchVerifyRequest](docs/Model/BatchVerifyRequest.md)
 - [BatchVerifyResponse](docs/Model/BatchVerifyResponse.md)
 - [BatchVerifyResponseInner](docs/Model/BatchVerifyResponseInner.md)
 - [CaConfig](docs/Model/CaConfig.md)
 - [ChildAccountUser](docs/Model/ChildAccountUser.md)
 - [ChildAccountUserRequest](docs/Model/ChildAccountUserRequest.md)
 - [CipherMode](docs/Model/CipherMode.md)
 - [ConfirmEmailRequest](docs/Model/ConfirmEmailRequest.md)
 - [ConfirmEmailResponse](docs/Model/ConfirmEmailResponse.md)
 - [CreatorType](docs/Model/CreatorType.md)
 - [CryptMode](docs/Model/CryptMode.md)
 - [DecryptFinalRequest](docs/Model/DecryptFinalRequest.md)
 - [DecryptFinalRequestEx](docs/Model/DecryptFinalRequestEx.md)
 - [DecryptFinalResponse](docs/Model/DecryptFinalResponse.md)
 - [DecryptInitRequest](docs/Model/DecryptInitRequest.md)
 - [DecryptInitRequestEx](docs/Model/DecryptInitRequestEx.md)
 - [DecryptInitResponse](docs/Model/DecryptInitResponse.md)
 - [DecryptRequest](docs/Model/DecryptRequest.md)
 - [DecryptRequestEx](docs/Model/DecryptRequestEx.md)
 - [DecryptResponse](docs/Model/DecryptResponse.md)
 - [DecryptUpdateRequest](docs/Model/DecryptUpdateRequest.md)
 - [DecryptUpdateRequestEx](docs/Model/DecryptUpdateRequestEx.md)
 - [DecryptUpdateResponse](docs/Model/DecryptUpdateResponse.md)
 - [DeriveKeyMechanism](docs/Model/DeriveKeyMechanism.md)
 - [DeriveKeyRequest](docs/Model/DeriveKeyRequest.md)
 - [DeriveKeyRequestEx](docs/Model/DeriveKeyRequestEx.md)
 - [DigestAlgorithm](docs/Model/DigestAlgorithm.md)
 - [DigestRequest](docs/Model/DigestRequest.md)
 - [DigestResponse](docs/Model/DigestResponse.md)
 - [DsaOptions](docs/Model/DsaOptions.md)
 - [EllipticCurve](docs/Model/EllipticCurve.md)
 - [EncryptFinalRequest](docs/Model/EncryptFinalRequest.md)
 - [EncryptFinalRequestEx](docs/Model/EncryptFinalRequestEx.md)
 - [EncryptFinalResponse](docs/Model/EncryptFinalResponse.md)
 - [EncryptInitRequest](docs/Model/EncryptInitRequest.md)
 - [EncryptInitRequestEx](docs/Model/EncryptInitRequestEx.md)
 - [EncryptInitResponse](docs/Model/EncryptInitResponse.md)
 - [EncryptRequest](docs/Model/EncryptRequest.md)
 - [EncryptRequestEx](docs/Model/EncryptRequestEx.md)
 - [EncryptResponse](docs/Model/EncryptResponse.md)
 - [EncryptUpdateRequest](docs/Model/EncryptUpdateRequest.md)
 - [EncryptUpdateRequestEx](docs/Model/EncryptUpdateRequestEx.md)
 - [EncryptUpdateResponse](docs/Model/EncryptUpdateResponse.md)
 - [Entity](docs/Model/Entity.md)
 - [Error](docs/Model/Error.md)
 - [ExportComponentsResponse](docs/Model/ExportComponentsResponse.md)
 - [ExportSobjectComponentsRequest](docs/Model/ExportSobjectComponentsRequest.md)
 - [ForgotPasswordRequest](docs/Model/ForgotPasswordRequest.md)
 - [FpeCompoundPart](docs/Model/FpeCompoundPart.md)
 - [FpeConstraints](docs/Model/FpeConstraints.md)
 - [FpeConstraintsApplicabilitySubparts](docs/Model/FpeConstraintsApplicabilitySubparts.md)
 - [FpeDataPart](docs/Model/FpeDataPart.md)
 - [FpeDate](docs/Model/FpeDate.md)
 - [FpeDateBound](docs/Model/FpeDateBound.md)
 - [FpeDatePart](docs/Model/FpeDatePart.md)
 - [FpeDateWithBounds](docs/Model/FpeDateWithBounds.md)
 - [FpeEncryptedPart](docs/Model/FpeEncryptedPart.md)
 - [FpeLiteralPart](docs/Model/FpeLiteralPart.md)
 - [FpeOptions](docs/Model/FpeOptions.md)
 - [FpeOptionsAdvanced](docs/Model/FpeOptionsAdvanced.md)
 - [FpeOptionsBasic](docs/Model/FpeOptionsBasic.md)
 - [GoogleServiceAccountKey](docs/Model/GoogleServiceAccountKey.md)
 - [Group](docs/Model/Group.md)
 - [GroupRequest](docs/Model/GroupRequest.md)
 - [HistoryItem](docs/Model/HistoryItem.md)
 - [HistoryItemState](docs/Model/HistoryItemState.md)
 - [HmgConfig](docs/Model/HmgConfig.md)
 - [HmgKind](docs/Model/HmgKind.md)
 - [IVDecryptInput](docs/Model/IVDecryptInput.md)
 - [IVEncryptInput](docs/Model/IVEncryptInput.md)
 - [IVEncryptOutput](docs/Model/IVEncryptOutput.md)
 - [ImportSobjectComponentsRequest](docs/Model/ImportSobjectComponentsRequest.md)
 - [JWTSigningKeyType](docs/Model/JWTSigningKeyType.md)
 - [KeyCheckValueResponse](docs/Model/KeyCheckValueResponse.md)
 - [KeyFormat](docs/Model/KeyFormat.md)
 - [KeyObject](docs/Model/KeyObject.md)
 - [KeyObjectState](docs/Model/KeyObjectState.md)
 - [KeyOperations](docs/Model/KeyOperations.md)
 - [KeyUndoPolicy](docs/Model/KeyUndoPolicy.md)
 - [Language](docs/Model/Language.md)
 - [LoggingConfig](docs/Model/LoggingConfig.md)
 - [LoggingConfigRequest](docs/Model/LoggingConfigRequest.md)
 - [MacGenerateRequest](docs/Model/MacGenerateRequest.md)
 - [MacGenerateRequestEx](docs/Model/MacGenerateRequestEx.md)
 - [MacGenerateResponse](docs/Model/MacGenerateResponse.md)
 - [MacVerifyRequest](docs/Model/MacVerifyRequest.md)
 - [MacVerifyRequestEx](docs/Model/MacVerifyRequestEx.md)
 - [MacVerifyResponse](docs/Model/MacVerifyResponse.md)
 - [MfaChallenge](docs/Model/MfaChallenge.md)
 - [Mgf](docs/Model/Mgf.md)
 - [MgfMgf1](docs/Model/MgfMgf1.md)
 - [NotificationPref](docs/Model/NotificationPref.md)
 - [ObjectDigestRequest](docs/Model/ObjectDigestRequest.md)
 - [ObjectOrigin](docs/Model/ObjectOrigin.md)
 - [ObjectType](docs/Model/ObjectType.md)
 - [PasswordChangeRequest](docs/Model/PasswordChangeRequest.md)
 - [PasswordResetRequest](docs/Model/PasswordResetRequest.md)
 - [PersistTransientKeyRequest](docs/Model/PersistTransientKeyRequest.md)
 - [Plugin](docs/Model/Plugin.md)
 - [PluginInvokeRequest](docs/Model/PluginInvokeRequest.md)
 - [PluginInvokeResponse](docs/Model/PluginInvokeResponse.md)
 - [PluginRequest](docs/Model/PluginRequest.md)
 - [PluginSource](docs/Model/PluginSource.md)
 - [PluginType](docs/Model/PluginType.md)
 - [ProcessInviteRequest](docs/Model/ProcessInviteRequest.md)
 - [RecoveryCodes](docs/Model/RecoveryCodes.md)
 - [RevertRequest](docs/Model/RevertRequest.md)
 - [RevocationReason](docs/Model/RevocationReason.md)
 - [RevocationReasonCode](docs/Model/RevocationReasonCode.md)
 - [RotationInterval](docs/Model/RotationInterval.md)
 - [RotationPolicy](docs/Model/RotationPolicy.md)
 - [RsaEncryptionPadding](docs/Model/RsaEncryptionPadding.md)
 - [RsaEncryptionPaddingOAEP](docs/Model/RsaEncryptionPaddingOAEP.md)
 - [RsaEncryptionPolicy](docs/Model/RsaEncryptionPolicy.md)
 - [RsaEncryptionPolicyPadding](docs/Model/RsaEncryptionPolicyPadding.md)
 - [RsaEncryptionPolicyPaddingOAEP](docs/Model/RsaEncryptionPolicyPaddingOAEP.md)
 - [RsaOptions](docs/Model/RsaOptions.md)
 - [RsaSignaturePadding](docs/Model/RsaSignaturePadding.md)
 - [RsaSignaturePaddingPSS](docs/Model/RsaSignaturePaddingPSS.md)
 - [RsaSignaturePolicy](docs/Model/RsaSignaturePolicy.md)
 - [RsaSignaturePolicyPadding](docs/Model/RsaSignaturePolicyPadding.md)
 - [ScheduleDeletionRequest](docs/Model/ScheduleDeletionRequest.md)
 - [SelectAccountRequest](docs/Model/SelectAccountRequest.md)
 - [SelectAccountResponse](docs/Model/SelectAccountResponse.md)
 - [ServerMode](docs/Model/ServerMode.md)
 - [SignRequest](docs/Model/SignRequest.md)
 - [SignRequestEx](docs/Model/SignRequestEx.md)
 - [SignResponse](docs/Model/SignResponse.md)
 - [SignatureMode](docs/Model/SignatureMode.md)
 - [SignupRequest](docs/Model/SignupRequest.md)
 - [SobjectComponent](docs/Model/SobjectComponent.md)
 - [SobjectDescriptor](docs/Model/SobjectDescriptor.md)
 - [SobjectRequest](docs/Model/SobjectRequest.md)
 - [SplittingMethod](docs/Model/SplittingMethod.md)
 - [SplunkLoggingConfig](docs/Model/SplunkLoggingConfig.md)
 - [SplunkLoggingConfigRequest](docs/Model/SplunkLoggingConfigRequest.md)
 - [StackdriverLoggingConfig](docs/Model/StackdriverLoggingConfig.md)
 - [StackdriverLoggingConfigRequest](docs/Model/StackdriverLoggingConfigRequest.md)
 - [StatsResponse](docs/Model/StatsResponse.md)
 - [SubscriptionChangeRequest](docs/Model/SubscriptionChangeRequest.md)
 - [SubscriptionType](docs/Model/SubscriptionType.md)
 - [TagDecryptInput](docs/Model/TagDecryptInput.md)
 - [TagEncryptOutput](docs/Model/TagEncryptOutput.md)
 - [TagLenEncryptInput](docs/Model/TagLenEncryptInput.md)
 - [TlsConfig](docs/Model/TlsConfig.md)
 - [TlsMode](docs/Model/TlsMode.md)
 - [U2fAddDeviceRequest](docs/Model/U2fAddDeviceRequest.md)
 - [U2fDelDeviceRequest](docs/Model/U2fDelDeviceRequest.md)
 - [U2fDevice](docs/Model/U2fDevice.md)
 - [U2fKey](docs/Model/U2fKey.md)
 - [U2fRenameDeviceRequest](docs/Model/U2fRenameDeviceRequest.md)
 - [UnwrapKeyParams](docs/Model/UnwrapKeyParams.md)
 - [UnwrapKeyRequest](docs/Model/UnwrapKeyRequest.md)
 - [UnwrapKeyRequestEx](docs/Model/UnwrapKeyRequestEx.md)
 - [User](docs/Model/User.md)
 - [UserAccountFlags](docs/Model/UserAccountFlags.md)
 - [UserAccountMap](docs/Model/UserAccountMap.md)
 - [UserGroupFlags](docs/Model/UserGroupFlags.md)
 - [UserGroupMap](docs/Model/UserGroupMap.md)
 - [UserRequest](docs/Model/UserRequest.md)
 - [UserState](docs/Model/UserState.md)
 - [Uuid](docs/Model/Uuid.md)
 - [ValidateTokenRequest](docs/Model/ValidateTokenRequest.md)
 - [ValidateTokenResponse](docs/Model/ValidateTokenResponse.md)
 - [VerifyKcvRequest](docs/Model/VerifyKcvRequest.md)
 - [VerifyKcvResponse](docs/Model/VerifyKcvResponse.md)
 - [VerifyRequest](docs/Model/VerifyRequest.md)
 - [VerifyRequestEx](docs/Model/VerifyRequestEx.md)
 - [VerifyResponse](docs/Model/VerifyResponse.md)
 - [VersionResponse](docs/Model/VersionResponse.md)
 - [WrapKeyParams](docs/Model/WrapKeyParams.md)
 - [WrapKeyRequest](docs/Model/WrapKeyRequest.md)
 - [WrapKeyRequestEx](docs/Model/WrapKeyRequestEx.md)
 - [WrapKeyResponse](docs/Model/WrapKeyResponse.md)


## Documentation For Authorization


## basicAuth

- **Type**: HTTP basic authentication

## bearerToken

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author

support@fortanix.com


