# SdkmsClient\AuthenticationApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**authorize**](AuthenticationApi.md#authorize) | **POST** /sys/v1/session/auth | Create a session for a user or an app
[**checkHealth**](AuthenticationApi.md#checkHealth) | **GET** /sys/v1/health | Check whether the server is handling requests
[**getServerVersion**](AuthenticationApi.md#getServerVersion) | **GET** /sys/v1/version | Get SDKMS version information
[**reAuth**](AuthenticationApi.md#reAuth) | **POST** /sys/v1/session/reauth | Create a new session for a user or an app using an existing session bearer token.
[**refresh**](AuthenticationApi.md#refresh) | **POST** /sys/v1/session/refresh | Refreshes existing user or app session.
[**selectAccount**](AuthenticationApi.md#selectAccount) | **POST** /sys/v1/session/select_account | Select a user&#39;s account to work on
[**terminate**](AuthenticationApi.md#terminate) | **POST** /sys/v1/session/terminate | Terminate a session
[**unlock2F**](AuthenticationApi.md#unlock2F) | **POST** /sys/v1/session/config_2fa/auth | Unlock two factor configuration


# **authorize**
> \SdkmsClient\Model\AuthResponse authorize()

Create a session for a user or an app

Authenticate a user or an app to SDKMS to begin a session. The caller needs to provide a basic authentication token to authenticate to SDKMS. The response body contains a bearer authentication token which needs to be provided by subsequent calls for the duration of the session.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure HTTP basic authorization: basicAuth
SdkmsClient\Configuration::getDefaultConfiguration()->setUsername('YOUR_USERNAME');
SdkmsClient\Configuration::getDefaultConfiguration()->setPassword('YOUR_PASSWORD');

$api_instance = new SdkmsClient\Api\AuthenticationApi();

try {
    $result = $api_instance->authorize();
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling AuthenticationApi->authorize: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**\SdkmsClient\Model\AuthResponse**](../Model/AuthResponse.md)

### Authorization

[basicAuth](../../README.md#basicAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **checkHealth**
> checkHealth()

Check whether the server is handling requests

Returns a 200-class status code if the server is handling requests, or a 500-class status code if the server is having problems.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

$api_instance = new SdkmsClient\Api\AuthenticationApi();

try {
    $api_instance->checkHealth();
} catch (Exception $e) {
    echo 'Exception when calling AuthenticationApi->checkHealth: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

void (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getServerVersion**
> \SdkmsClient\Model\VersionResponse getServerVersion()

Get SDKMS version information

Returns information about the  SDKMS server version and the client API version that it supports.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

$api_instance = new SdkmsClient\Api\AuthenticationApi();

try {
    $result = $api_instance->getServerVersion();
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling AuthenticationApi->getServerVersion: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**\SdkmsClient\Model\VersionResponse**](../Model/VersionResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **reAuth**
> \SdkmsClient\Model\AuthResponse reAuth()

Create a new session for a user or an app using an existing session bearer token.

Authenticate a user or an app to SDKMS using existing session token, to generate a new session.  The caller needs to provide bearer authentication token of an existing valid session. The response body contains a bearer authentication token of the new session created.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\AuthenticationApi();

try {
    $result = $api_instance->reAuth();
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling AuthenticationApi->reAuth: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**\SdkmsClient\Model\AuthResponse**](../Model/AuthResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **refresh**
> refresh()

Refreshes existing user or app session.

Refreshes an existing session, thus extending the expiration time of the existing bearer authentication token. The caller needs to provide bearer token of sesssion need to be refreshed.  The response body is empty.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\AuthenticationApi();

try {
    $api_instance->refresh();
} catch (Exception $e) {
    echo 'Exception when calling AuthenticationApi->refresh: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

void (empty response body)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **selectAccount**
> \SdkmsClient\Model\SelectAccountResponse selectAccount($body)

Select a user's account to work on

Select one of user's account to proceed. This is applicable when a user is associated with more than one account. The caller needs to provide a bearer token for the session in the request body.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\AuthenticationApi();
$body = new \SdkmsClient\Model\SelectAccountRequest(); // \SdkmsClient\Model\SelectAccountRequest | Select Account Request

try {
    $result = $api_instance->selectAccount($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling AuthenticationApi->selectAccount: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\SelectAccountRequest**](../Model/SelectAccountRequest.md)| Select Account Request |

### Return type

[**\SdkmsClient\Model\SelectAccountResponse**](../Model/SelectAccountResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **terminate**
> terminate()

Terminate a session

Terminate an authenticated session. After this call, the provided bearer authentication token will be invalidated and cannot be used to make any further API calls.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\AuthenticationApi();

try {
    $api_instance->terminate();
} catch (Exception $e) {
    echo 'Exception when calling AuthenticationApi->terminate: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

void (empty response body)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **unlock2F**
> unlock2F()

Unlock two factor configuration

Re-authenticate to unlock two factor configuration. Two factor configuration must be unlocked to enable or disable two factor authentication, add or remove two factor devices, or regenerate recovery codes. The caller needs to provide a bearer token for the session in the request body.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\AuthenticationApi();

try {
    $api_instance->unlock2F();
} catch (Exception $e) {
    echo 'Exception when calling AuthenticationApi->unlock2F: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters
This endpoint does not need any parameter.

### Return type

void (empty response body)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

