# SdkmsClient\SecurityObjectsApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**activateSecurityObject**](SecurityObjectsApi.md#activateSecurityObject) | **POST** /crypto/v1/keys/{key-id}/activate | Transitions immediately a security object to Active state
[**agreeKey**](SecurityObjectsApi.md#agreeKey) | **POST** /crypto/v1/agree | Agree on a key from two other keys
[**deletePrivateKey**](SecurityObjectsApi.md#deletePrivateKey) | **DELETE** /crypto/v1/keys/{key-id}/private | Remove / Destroy private half of the asymmetric key
[**deleteSecurityObject**](SecurityObjectsApi.md#deleteSecurityObject) | **DELETE** /crypto/v1/keys/{key-id} | Delete a security object
[**deriveKey**](SecurityObjectsApi.md#deriveKey) | **POST** /crypto/v1/keys/{key-id}/derive | Derive a key from another key
[**deriveKeyEx**](SecurityObjectsApi.md#deriveKeyEx) | **POST** /crypto/v1/derive | Derive a key from another key
[**destroySecurityObject**](SecurityObjectsApi.md#destroySecurityObject) | **POST** /crypto/v1/keys/{key-id}/destroy | Destroys a security object, leaving its metadata in place
[**exportSobjectComponents**](SecurityObjectsApi.md#exportSobjectComponents) | **POST** /crypto/v1/keys/components/export | export key components
[**generateSecurityObject**](SecurityObjectsApi.md#generateSecurityObject) | **POST** /crypto/v1/keys | Generate a new security object
[**getSecurityObject**](SecurityObjectsApi.md#getSecurityObject) | **GET** /crypto/v1/keys/{key-id} | Get a specific security object
[**getSecurityObjectDigest**](SecurityObjectsApi.md#getSecurityObjectDigest) | **POST** /crypto/v1/keys/digest | Retrieve the digest (hash) of the value of an exportable security object
[**getSecurityObjectKcv**](SecurityObjectsApi.md#getSecurityObjectKcv) | **POST** /crypto/v1/keys/kcv | Get the key check value (KCV) of a symmetric key
[**getSecurityObjectValue**](SecurityObjectsApi.md#getSecurityObjectValue) | **GET** /crypto/v1/keys/{key-id}/export | Retrieve the value of an exportable security object
[**getSecurityObjectValueEx**](SecurityObjectsApi.md#getSecurityObjectValueEx) | **POST** /crypto/v1/keys/export | Retrieve the value of an exportable security object
[**getSecurityObjects**](SecurityObjectsApi.md#getSecurityObjects) | **GET** /crypto/v1/keys | Get all security objects
[**importSecurityObject**](SecurityObjectsApi.md#importSecurityObject) | **PUT** /crypto/v1/keys | Import a security object
[**importSobjectComponents**](SecurityObjectsApi.md#importSobjectComponents) | **POST** /crypto/v1/keys/components/import | import key components
[**persistSecurityObject**](SecurityObjectsApi.md#persistSecurityObject) | **POST** /crypto/v1/keys/persist | Persist a transient key.
[**revertHistoryItem**](SecurityObjectsApi.md#revertHistoryItem) | **PUT** /crypto/v1/keys/{key-id}/revert | Reverts a security object to a previous state
[**revokeSecurityObject**](SecurityObjectsApi.md#revokeSecurityObject) | **POST** /crypto/v1/keys/{key-id}/revoke | Transitions immediately a security object to Deactivated or Compromised state
[**rotateSecurityObject**](SecurityObjectsApi.md#rotateSecurityObject) | **POST** /crypto/v1/keys/rekey | Rotate a key.
[**updateSecurityObject**](SecurityObjectsApi.md#updateSecurityObject) | **PATCH** /crypto/v1/keys/{key-id} | Update a security object
[**verifyKcv**](SecurityObjectsApi.md#verifyKcv) | **POST** /crypto/v1/keys/kcv/verify | Verify that the KCV of the provided key material matches the provided KCV


# **activateSecurityObject**
> activateSecurityObject($key_id)

Transitions immediately a security object to Active state

Trigger the transition of a security object to Active state.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$key_id = "key_id_example"; // string | kid of security object

try {
    $api_instance->activateSecurityObject($key_id);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->activateSecurityObject: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |

### Return type

void (empty response body)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **agreeKey**
> \SdkmsClient\Model\KeyObject agreeKey($body)

Agree on a key from two other keys

This does a cryptographic key agreement operation between a public and private key. Both keys must have been generated from the same parameters (e.g. the same elliptic curve). Both keys must allow the AGREEKEY operation. The request body contains the requested properties for the new key as well as the mechanism (e.g. Diffie-Hellman) to be used to produce the key material for the new key. The output of this API should not be used directly as a cryptographic key. The target object type should be HMAC or Secret, and a key derivation procedure should be used to derive the actual key material.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$body = new \SdkmsClient\Model\AgreeKeyRequest(); // \SdkmsClient\Model\AgreeKeyRequest | Template of the agreed-upon security object

try {
    $result = $api_instance->agreeKey($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->agreeKey: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\AgreeKeyRequest**](../Model/AgreeKeyRequest.md)| Template of the agreed-upon security object |

### Return type

[**\SdkmsClient\Model\KeyObject**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **deletePrivateKey**
> deletePrivateKey($key_id)

Remove / Destroy private half of the asymmetric key

Removes the private portion of an asymmetric key from SDKMS. After this operation is performed, operations that require the private key, such as encryption and generating signatures, may no longer be performed.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$key_id = "key_id_example"; // string | kid of security object

try {
    $api_instance->deletePrivateKey($key_id);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->deletePrivateKey: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |

### Return type

void (empty response body)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **deleteSecurityObject**
> deleteSecurityObject($key_id)

Delete a security object

Delete a specified security object.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$key_id = "key_id_example"; // string | kid of security object

try {
    $api_instance->deleteSecurityObject($key_id);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->deleteSecurityObject: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |

### Return type

void (empty response body)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **deriveKey**
> \SdkmsClient\Model\KeyObject deriveKey($key_id, $body)

Derive a key from another key

This derives a key from an existing key and returns the properties of the new key. The request body contains the requested properties for the new as well as the mechanism to be used to produce the key material for the new key.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$key_id = "key_id_example"; // string | kid of security object
$body = new \SdkmsClient\Model\DeriveKeyRequest(); // \SdkmsClient\Model\DeriveKeyRequest | Name of security object

try {
    $result = $api_instance->deriveKey($key_id, $body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->deriveKey: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |
 **body** | [**\SdkmsClient\Model\DeriveKeyRequest**](../Model/DeriveKeyRequest.md)| Name of security object |

### Return type

[**\SdkmsClient\Model\KeyObject**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **deriveKeyEx**
> \SdkmsClient\Model\KeyObject deriveKeyEx($body)

Derive a key from another key

This derives a key from an existing key and returns the properties of the new key. The request body contains the requested properties for the new as well as the mechanism to be used to produce the key material for the new key.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$body = new \SdkmsClient\Model\DeriveKeyRequestEx(); // \SdkmsClient\Model\DeriveKeyRequestEx | Name of security object

try {
    $result = $api_instance->deriveKeyEx($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->deriveKeyEx: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\DeriveKeyRequestEx**](../Model/DeriveKeyRequestEx.md)| Name of security object |

### Return type

[**\SdkmsClient\Model\KeyObject**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **destroySecurityObject**
> destroySecurityObject($key_id)

Destroys a security object, leaving its metadata in place

Destroys a security object. Objects in the `Destroyed` state cannot be used in any cryptographic operation. Their metadata however, remains present.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$key_id = "key_id_example"; // string | kid of security object

try {
    $api_instance->destroySecurityObject($key_id);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->destroySecurityObject: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |

### Return type

void (empty response body)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **exportSobjectComponents**
> \SdkmsClient\Model\ExportComponentsResponse exportSobjectComponents($body)

export key components



### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$body = new \SdkmsClient\Model\ExportSobjectComponentsRequest(); // \SdkmsClient\Model\ExportSobjectComponentsRequest | Request to export a security object components

try {
    $result = $api_instance->exportSobjectComponents($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->exportSobjectComponents: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\ExportSobjectComponentsRequest**](../Model/ExportSobjectComponentsRequest.md)| Request to export a security object components |

### Return type

[**\SdkmsClient\Model\ExportComponentsResponse**](../Model/ExportComponentsResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **generateSecurityObject**
> \SdkmsClient\Model\KeyObject generateSecurityObject($body)

Generate a new security object

Generate a new security object (such as an RSA key pair or an AES key) of the requested size or elliptic curve. <br> By default, all key operations except for Export that are implemented for that type of key will be enabled. These may be overridden by requesting specific operations in the key creation request. <br> Objects of type Opaque may not be generated with this API. They must be imported via the importSecurityObject API.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$body = new \SdkmsClient\Model\SobjectRequest(); // \SdkmsClient\Model\SobjectRequest | Request to create, update, or import security object

try {
    $result = $api_instance->generateSecurityObject($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->generateSecurityObject: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\SobjectRequest**](../Model/SobjectRequest.md)| Request to create, update, or import security object |

### Return type

[**\SdkmsClient\Model\KeyObject**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getSecurityObject**
> \SdkmsClient\Model\KeyObject getSecurityObject($key_id, $view, $show_destroyed, $show_deleted)

Get a specific security object

Get the details of a particular security object.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$key_id = "key_id_example"; // string | kid of security object
$view = "json"; // string | The encoding the value of an opaque object or certificate
$show_destroyed = false; // bool | Whether security objects in the `Destroyed` state should be returned
$show_deleted = true; // bool | Whether security objects in the `Deleted` state should be returned

try {
    $result = $api_instance->getSecurityObject($key_id, $view, $show_destroyed, $show_deleted);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->getSecurityObject: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |
 **view** | **string**| The encoding the value of an opaque object or certificate | [optional] [default to json]
 **show_destroyed** | **bool**| Whether security objects in the &#x60;Destroyed&#x60; state should be returned | [optional] [default to false]
 **show_deleted** | **bool**| Whether security objects in the &#x60;Deleted&#x60; state should be returned | [optional]

### Return type

[**\SdkmsClient\Model\KeyObject**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getSecurityObjectDigest**
> \SdkmsClient\Model\DigestResponse getSecurityObjectDigest($body)

Retrieve the digest (hash) of the value of an exportable security object

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$body = new \SdkmsClient\Model\ObjectDigestRequest(); // \SdkmsClient\Model\ObjectDigestRequest | Object digest request

try {
    $result = $api_instance->getSecurityObjectDigest($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->getSecurityObjectDigest: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\ObjectDigestRequest**](../Model/ObjectDigestRequest.md)| Object digest request |

### Return type

[**\SdkmsClient\Model\DigestResponse**](../Model/DigestResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getSecurityObjectKcv**
> \SdkmsClient\Model\KeyCheckValueResponse getSecurityObjectKcv($body)

Get the key check value (KCV) of a symmetric key

Get the key check value (KCV) of a symmetric key

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$body = new \SdkmsClient\Model\SobjectDescriptor(); // \SdkmsClient\Model\SobjectDescriptor | Request to export a security object

try {
    $result = $api_instance->getSecurityObjectKcv($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->getSecurityObjectKcv: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\SobjectDescriptor**](../Model/SobjectDescriptor.md)| Request to export a security object |

### Return type

[**\SdkmsClient\Model\KeyCheckValueResponse**](../Model/KeyCheckValueResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getSecurityObjectValue**
> \SdkmsClient\Model\KeyObject getSecurityObjectValue($key_id)

Retrieve the value of an exportable security object

Get the details and value of a particular exportable security object.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$key_id = "key_id_example"; // string | kid of security object

try {
    $result = $api_instance->getSecurityObjectValue($key_id);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->getSecurityObjectValue: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |

### Return type

[**\SdkmsClient\Model\KeyObject**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getSecurityObjectValueEx**
> \SdkmsClient\Model\KeyObject getSecurityObjectValueEx($body)

Retrieve the value of an exportable security object

Get the details and value of a particular exportable security object.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$body = new \SdkmsClient\Model\SobjectDescriptor(); // \SdkmsClient\Model\SobjectDescriptor | Request to export a security object

try {
    $result = $api_instance->getSecurityObjectValueEx($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->getSecurityObjectValueEx: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\SobjectDescriptor**](../Model/SobjectDescriptor.md)| Request to export a security object |

### Return type

[**\SdkmsClient\Model\KeyObject**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getSecurityObjects**
> \SdkmsClient\Model\KeyObject[] getSecurityObjects($name, $group_id, $creator, $sort, $compliant_with_policies, $start, $limit, $offset, $show_destroyed, $show_deleted)

Get all security objects

Return detailed information about the security objects stored in Fortanix SDKMS.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$name = "name_example"; // string | Only retrieve the security object with this name.
$group_id = "group_id_example"; // string | Only retrieve security objects in the specified group.
$creator = "creator_example"; // string | Only retrieve security objects created by the user or application with the specified id.
$sort = "sort_example"; // string | This specifies the property (`kid` or `name`) and order (ascending or descending) with which to sort the security objects. By default, security objects are sorted by `kid` in ascending order. The syntax is \"<property>:[asc|desc]\" (e.g. \"kid:desc\") or just \"<property>\" (ascending order by default).
$compliant_with_policies = true; // bool | Whether this security object is compliant with cryptographic policies or not.
$start = "start_example"; // string | If provided, this must be a value of the property specified in `sort`. Returned security objects will begin just above or just below this value (for asc/desc order resp.).
$limit = 56; // int | Maximum number of security objects to return. If not provided, the limit is 100.
$offset = 56; // int | Number of security objects past `start` to skip.
$show_destroyed = true; // bool | Whether security objects in the `Destroyed` state should be returned
$show_deleted = true; // bool | Whether security objects in the `Deleted` state should be returned

try {
    $result = $api_instance->getSecurityObjects($name, $group_id, $creator, $sort, $compliant_with_policies, $start, $limit, $offset, $show_destroyed, $show_deleted);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->getSecurityObjects: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **string**| Only retrieve the security object with this name. | [optional]
 **group_id** | **string**| Only retrieve security objects in the specified group. | [optional]
 **creator** | **string**| Only retrieve security objects created by the user or application with the specified id. | [optional]
 **sort** | **string**| This specifies the property (&#x60;kid&#x60; or &#x60;name&#x60;) and order (ascending or descending) with which to sort the security objects. By default, security objects are sorted by &#x60;kid&#x60; in ascending order. The syntax is \&quot;&lt;property&gt;:[asc|desc]\&quot; (e.g. \&quot;kid:desc\&quot;) or just \&quot;&lt;property&gt;\&quot; (ascending order by default). | [optional]
 **compliant_with_policies** | **bool**| Whether this security object is compliant with cryptographic policies or not. | [optional]
 **start** | **string**| If provided, this must be a value of the property specified in &#x60;sort&#x60;. Returned security objects will begin just above or just below this value (for asc/desc order resp.). | [optional]
 **limit** | **int**| Maximum number of security objects to return. If not provided, the limit is 100. | [optional]
 **offset** | **int**| Number of security objects past &#x60;start&#x60; to skip. | [optional]
 **show_destroyed** | **bool**| Whether security objects in the &#x60;Destroyed&#x60; state should be returned | [optional]
 **show_deleted** | **bool**| Whether security objects in the &#x60;Deleted&#x60; state should be returned | [optional]

### Return type

[**\SdkmsClient\Model\KeyObject[]**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **importSecurityObject**
> \SdkmsClient\Model\KeyObject importSecurityObject($body)

Import a security object

Import a security object into SDKMS. <br> By default, all key operations except that are implemented for that type of key will be enabled. These may be overridden by requesting specific operations in the key import request. <br> For symmetric and asymmetric keys, value is base64-encoding of the key material in DER format.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$body = new \SdkmsClient\Model\SobjectRequest(); // \SdkmsClient\Model\SobjectRequest | Request to create, update, or import security object

try {
    $result = $api_instance->importSecurityObject($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->importSecurityObject: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\SobjectRequest**](../Model/SobjectRequest.md)| Request to create, update, or import security object |

### Return type

[**\SdkmsClient\Model\KeyObject**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **importSobjectComponents**
> \SdkmsClient\Model\KeyObject importSobjectComponents($body)

import key components



### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$body = new \SdkmsClient\Model\ImportSobjectComponentsRequest(); // \SdkmsClient\Model\ImportSobjectComponentsRequest | Request to import a security object components

try {
    $result = $api_instance->importSobjectComponents($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->importSobjectComponents: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\ImportSobjectComponentsRequest**](../Model/ImportSobjectComponentsRequest.md)| Request to import a security object components |

### Return type

[**\SdkmsClient\Model\KeyObject**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **persistSecurityObject**
> \SdkmsClient\Model\KeyObject persistSecurityObject($body)

Persist a transient key.

This API copies a transient key into a persisted security object in SDKMS. If the transient key's origin is \"FortanixHSM\", the origin of the persisted key will be \"Transient\". If the transient key's origin is \"External\", the origin of the persisted key will be \"External\".

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$body = new \SdkmsClient\Model\PersistTransientKeyRequest(); // \SdkmsClient\Model\PersistTransientKeyRequest | Persist transient key request

try {
    $result = $api_instance->persistSecurityObject($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->persistSecurityObject: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\PersistTransientKeyRequest**](../Model/PersistTransientKeyRequest.md)| Persist transient key request |

### Return type

[**\SdkmsClient\Model\KeyObject**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **revertHistoryItem**
> revertHistoryItem($key_id, $body)

Reverts a security object to a previous state

When a Key Undo Policy is in place, security objects maintain a list of history items. Using this API endpoint, clients may revert the security object to a previous (non-expired) history item.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$key_id = "key_id_example"; // string | kid of security object
$body = new \SdkmsClient\Model\SobjectRequest(); // \SdkmsClient\Model\SobjectRequest | Request to create, update, or import security object

try {
    $api_instance->revertHistoryItem($key_id, $body);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->revertHistoryItem: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |
 **body** | [**\SdkmsClient\Model\SobjectRequest**](../Model/SobjectRequest.md)| Request to create, update, or import security object |

### Return type

void (empty response body)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **revokeSecurityObject**
> revokeSecurityObject($key_id, $body)

Transitions immediately a security object to Deactivated or Compromised state

Trigger the transition of a security object to Deactivated or Compromised state depending on the RevocationReason Code.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$key_id = "key_id_example"; // string | kid of security object
$body = new \SdkmsClient\Model\RevocationReason(); // \SdkmsClient\Model\RevocationReason | Reason to revoke a security object

try {
    $api_instance->revokeSecurityObject($key_id, $body);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->revokeSecurityObject: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |
 **body** | [**\SdkmsClient\Model\RevocationReason**](../Model/RevocationReason.md)| Reason to revoke a security object |

### Return type

void (empty response body)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **rotateSecurityObject**
> \SdkmsClient\Model\KeyObject rotateSecurityObject($body)

Rotate a key.

Rotate an existing security object.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$body = new \SdkmsClient\Model\SobjectRequest(); // \SdkmsClient\Model\SobjectRequest | Request to create, update, or import security object

try {
    $result = $api_instance->rotateSecurityObject($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->rotateSecurityObject: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\SobjectRequest**](../Model/SobjectRequest.md)| Request to create, update, or import security object |

### Return type

[**\SdkmsClient\Model\KeyObject**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **updateSecurityObject**
> \SdkmsClient\Model\KeyObject updateSecurityObject($key_id, $body)

Update a security object

Update the properties of a security object.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$key_id = "key_id_example"; // string | kid of security object
$body = new \SdkmsClient\Model\SobjectRequest(); // \SdkmsClient\Model\SobjectRequest | Request to create, update, or import security object

try {
    $result = $api_instance->updateSecurityObject($key_id, $body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->updateSecurityObject: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |
 **body** | [**\SdkmsClient\Model\SobjectRequest**](../Model/SobjectRequest.md)| Request to create, update, or import security object |

### Return type

[**\SdkmsClient\Model\KeyObject**](../Model/KeyObject.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **verifyKcv**
> \SdkmsClient\Model\VerifyKcvResponse verifyKcv($body)

Verify that the KCV of the provided key material matches the provided KCV

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SecurityObjectsApi();
$body = new \SdkmsClient\Model\VerifyKcvRequest(); // \SdkmsClient\Model\VerifyKcvRequest | Verify KCV request

try {
    $result = $api_instance->verifyKcv($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SecurityObjectsApi->verifyKcv: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\VerifyKcvRequest**](../Model/VerifyKcvRequest.md)| Verify KCV request |

### Return type

[**\SdkmsClient\Model\VerifyKcvResponse**](../Model/VerifyKcvResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

