# SdkmsClient\SignAndVerifyApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**batchSign**](SignAndVerifyApi.md#batchSign) | **POST** /crypto/v1/keys/batch/sign | Batch sign with one or more private keys
[**batchVerify**](SignAndVerifyApi.md#batchVerify) | **POST** /crypto/v1/keys/batch/verify | Batch verify with one or more private keys
[**sign**](SignAndVerifyApi.md#sign) | **POST** /crypto/v1/keys/{key-id}/sign | Sign with a private key
[**signEx**](SignAndVerifyApi.md#signEx) | **POST** /crypto/v1/sign | Sign with a private key
[**verify**](SignAndVerifyApi.md#verify) | **POST** /crypto/v1/keys/{key-id}/verify | Verify a signature with a key
[**verifyEx**](SignAndVerifyApi.md#verifyEx) | **POST** /crypto/v1/verify | Verify a signature with a key


# **batchSign**
> \SdkmsClient\Model\BatchSignResponse batchSign($body)

Batch sign with one or more private keys

The data to be signed and the key ids to be used are provided in the request body. The signature is returned in the response body. The ordering of the body matches the ordering of the request. An individual status code is returned for each batch item. Maximum size of the entire batch request is 512 KB.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SignAndVerifyApi();
$body = new \SdkmsClient\Model\BatchSignRequest(); // \SdkmsClient\Model\BatchSignRequest | Batch Sign request

try {
    $result = $api_instance->batchSign($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SignAndVerifyApi->batchSign: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\BatchSignRequest**](../Model/BatchSignRequest.md)| Batch Sign request |

### Return type

[**\SdkmsClient\Model\BatchSignResponse**](../Model/BatchSignResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **batchVerify**
> \SdkmsClient\Model\BatchVerifyResponse batchVerify($body)

Batch verify with one or more private keys

The signature to be verified and the key ids to be used are provided in the request body. The result (true of false) returned in the response body. The ordering of the body matches the ordering of the request. An individual status code is returned for each batch item. Maximum size of the entire batch request is 512 KB.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SignAndVerifyApi();
$body = new \SdkmsClient\Model\BatchVerifyRequest(); // \SdkmsClient\Model\BatchVerifyRequest | Batch Verify request

try {
    $result = $api_instance->batchVerify($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SignAndVerifyApi->batchVerify: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\BatchVerifyRequest**](../Model/BatchVerifyRequest.md)| Batch Verify request |

### Return type

[**\SdkmsClient\Model\BatchVerifyResponse**](../Model/BatchVerifyResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **sign**
> \SdkmsClient\Model\SignResponse sign($key_id, $body)

Sign with a private key

Sign data with a private key. The signing key must be an asymmetric key with the private part present. The sign operation must be enabled for this key. Symmetric keys  may not be used to sign data. They can be used with the computeMac and verifyMac methods. <br> The data must be hashed with a SHA-1 or SHA-2 family hash algorithm.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SignAndVerifyApi();
$key_id = "key_id_example"; // string | kid of security object
$body = new \SdkmsClient\Model\SignRequest(); // \SdkmsClient\Model\SignRequest | Signature request

try {
    $result = $api_instance->sign($key_id, $body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SignAndVerifyApi->sign: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |
 **body** | [**\SdkmsClient\Model\SignRequest**](../Model/SignRequest.md)| Signature request |

### Return type

[**\SdkmsClient\Model\SignResponse**](../Model/SignResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **signEx**
> \SdkmsClient\Model\SignResponse signEx($body)

Sign with a private key

Sign data with a private key. The signing key must be an asymmetric key with the private part present. The sign operation must be enabled for this key. Symmetric keys  may not be used to sign data. They can be used with the computeMac and verifyMac methods. <br> The data must be hashed with a SHA-1 or SHA-2 family hash algorithm.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SignAndVerifyApi();
$body = new \SdkmsClient\Model\SignRequestEx(); // \SdkmsClient\Model\SignRequestEx | Signature request

try {
    $result = $api_instance->signEx($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SignAndVerifyApi->signEx: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\SignRequestEx**](../Model/SignRequestEx.md)| Signature request |

### Return type

[**\SdkmsClient\Model\SignResponse**](../Model/SignResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **verify**
> \SdkmsClient\Model\VerifyResponse verify($key_id, $body)

Verify a signature with a key

Verify a signature with a public key. The verifying key must be an asymmetric key with the verify operation enabled. Symmetric keys may not be used to verify data. They can be used with the computeMac and verifyMac operations. <br> The signature must have been created with a SHA-1 or SHA-2 family hash algorithm.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SignAndVerifyApi();
$key_id = "key_id_example"; // string | kid of security object
$body = new \SdkmsClient\Model\VerifyRequest(); // \SdkmsClient\Model\VerifyRequest | Verification request

try {
    $result = $api_instance->verify($key_id, $body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SignAndVerifyApi->verify: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |
 **body** | [**\SdkmsClient\Model\VerifyRequest**](../Model/VerifyRequest.md)| Verification request |

### Return type

[**\SdkmsClient\Model\VerifyResponse**](../Model/VerifyResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **verifyEx**
> \SdkmsClient\Model\VerifyResponse verifyEx($body)

Verify a signature with a key

Verify a signature with a public key. The verifying key must be an asymmetric key with the verify operation enabled. Symmetric keys may not be used to verify data. They can be used with the computeMac and verifyMac operations. <br> The signature must have been created with a SHA-1 or SHA-2 family hash algorithm.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\SignAndVerifyApi();
$body = new \SdkmsClient\Model\VerifyRequestEx(); // \SdkmsClient\Model\VerifyRequestEx | Verification request

try {
    $result = $api_instance->verifyEx($body);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling SignAndVerifyApi->verifyEx: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**\SdkmsClient\Model\VerifyRequestEx**](../Model/VerifyRequestEx.md)| Verification request |

### Return type

[**\SdkmsClient\Model\VerifyResponse**](../Model/VerifyResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

