# SdkmsClient\StatsApi

All URIs are relative to *https://apps.smartkey.io*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getAppStats**](StatsApi.md#getAppStats) | **GET** /sys/v1/stats/{app-id}/app | Get transaction statistics for a specific application
[**getAppsStats**](StatsApi.md#getAppsStats) | **GET** /sys/v1/stats/apps | Get app aggregate transaction statistics
[**getGroupStats**](StatsApi.md#getGroupStats) | **GET** /sys/v1/stats/{group-id}/group | Get transaction statistics for a specific group
[**getGroupsStats**](StatsApi.md#getGroupsStats) | **GET** /sys/v1/stats/groups | Get group aggregate transaction statistics
[**getSecurityObjectStats**](StatsApi.md#getSecurityObjectStats) | **GET** /sys/v1/stats/{key-id}/key | Get transaction statistics for a specific security object


# **getAppStats**
> \SdkmsClient\Model\StatsResponse getAppStats($app_id, $range_from, $range_to, $num_points)

Get transaction statistics for a specific application

This API is for obtaining transaction statistics for a specific application. API supports query parameters for fetchings stats for specific time period and with number of data points desired.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\StatsApi();
$app_id = "app_id_example"; // string | Application Identifier
$range_from = 56; // int | Starting time for search , this is EPOCH value
$range_to = 56; // int | Ending time for search , this is EPOCH value
$num_points = 56; // int | Number of data points desired

try {
    $result = $api_instance->getAppStats($app_id, $range_from, $range_to, $num_points);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling StatsApi->getAppStats: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **string**| Application Identifier |
 **range_from** | **int**| Starting time for search , this is EPOCH value | [optional]
 **range_to** | **int**| Ending time for search , this is EPOCH value | [optional]
 **num_points** | **int**| Number of data points desired | [optional]

### Return type

[**\SdkmsClient\Model\StatsResponse**](../Model/StatsResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getAppsStats**
> \SdkmsClient\Model\StatsResponse getAppsStats($range_from, $range_to, $top_count, $num_points)

Get app aggregate transaction statistics

This is for obtaining app level aggregate transaction statistics to find top apps by transaction. API supports query parameters for fetchings stats for specific time period, for maximum top count and with number of data points desired.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\StatsApi();
$range_from = 56; // int | Starting time for search , this is EPOCH value
$range_to = 56; // int | Ending time for search , this is EPOCH value
$top_count = 56; // int | Maximum top count for statistics query
$num_points = 56; // int | Number of data points desired

try {
    $result = $api_instance->getAppsStats($range_from, $range_to, $top_count, $num_points);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling StatsApi->getAppsStats: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **range_from** | **int**| Starting time for search , this is EPOCH value | [optional]
 **range_to** | **int**| Ending time for search , this is EPOCH value | [optional]
 **top_count** | **int**| Maximum top count for statistics query | [optional]
 **num_points** | **int**| Number of data points desired | [optional]

### Return type

[**\SdkmsClient\Model\StatsResponse**](../Model/StatsResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getGroupStats**
> \SdkmsClient\Model\StatsResponse getGroupStats($group_id, $range_from, $range_to, $num_points)

Get transaction statistics for a specific group

This API is for obtaining transaction statistics for a specific group. API supports query parameters for fetchings stats for specific time period and with number of data points desired.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\StatsApi();
$group_id = "group_id_example"; // string | Group Identifier
$range_from = 56; // int | Starting time for search , this is EPOCH value
$range_to = 56; // int | Ending time for search , this is EPOCH value
$num_points = 56; // int | Number of data points desired

try {
    $result = $api_instance->getGroupStats($group_id, $range_from, $range_to, $num_points);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling StatsApi->getGroupStats: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **group_id** | **string**| Group Identifier |
 **range_from** | **int**| Starting time for search , this is EPOCH value | [optional]
 **range_to** | **int**| Ending time for search , this is EPOCH value | [optional]
 **num_points** | **int**| Number of data points desired | [optional]

### Return type

[**\SdkmsClient\Model\StatsResponse**](../Model/StatsResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getGroupsStats**
> \SdkmsClient\Model\StatsResponse getGroupsStats($range_from, $range_to, $top_count, $num_points)

Get group aggregate transaction statistics

This is for obtaining group level aggregate transaction statistics to find top groups by transaction. API supports query parameters for fetchings stats for specific time period, for maximum top count and with number of data points desired.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\StatsApi();
$range_from = 56; // int | Starting time for search , this is EPOCH value
$range_to = 56; // int | Ending time for search , this is EPOCH value
$top_count = 56; // int | Maximum top count for statistics query
$num_points = 56; // int | Number of data points desired

try {
    $result = $api_instance->getGroupsStats($range_from, $range_to, $top_count, $num_points);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling StatsApi->getGroupsStats: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **range_from** | **int**| Starting time for search , this is EPOCH value | [optional]
 **range_to** | **int**| Ending time for search , this is EPOCH value | [optional]
 **top_count** | **int**| Maximum top count for statistics query | [optional]
 **num_points** | **int**| Number of data points desired | [optional]

### Return type

[**\SdkmsClient\Model\StatsResponse**](../Model/StatsResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

# **getSecurityObjectStats**
> \SdkmsClient\Model\StatsResponse getSecurityObjectStats($key_id, $range_from, $range_to, $num_points)

Get transaction statistics for a specific security object

This API is for obtaining transaction statistics for a specific security object. API supports query parameters for fetchings stats for specific time period and with number of data points desired.

### Example
```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: bearerToken
SdkmsClient\Configuration::getDefaultConfiguration()->setApiKey('Authorization', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// SdkmsClient\Configuration::getDefaultConfiguration()->setApiKeyPrefix('Authorization', 'Bearer');

$api_instance = new SdkmsClient\Api\StatsApi();
$key_id = "key_id_example"; // string | kid of security object
$range_from = 56; // int | Starting time for search , this is EPOCH value
$range_to = 56; // int | Ending time for search , this is EPOCH value
$num_points = 56; // int | Number of data points desired

try {
    $result = $api_instance->getSecurityObjectStats($key_id, $range_from, $range_to, $num_points);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling StatsApi->getSecurityObjectStats: ', $e->getMessage(), PHP_EOL;
}
?>
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **key_id** | **string**| kid of security object |
 **range_from** | **int**| Starting time for search , this is EPOCH value | [optional]
 **range_to** | **int**| Ending time for search , this is EPOCH value | [optional]
 **num_points** | **int**| Number of data points desired | [optional]

### Return type

[**\SdkmsClient\Model\StatsResponse**](../Model/StatsResponse.md)

### Authorization

[bearerToken](../../README.md#bearerToken)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

[[Back to top]](#) [[Back to API list]](../../README.md#documentation-for-api-endpoints) [[Back to Model list]](../../README.md#documentation-for-models) [[Back to README]](../../README.md)

