<?php
/**
 * StatsApi
 * PHP version 5
 *
 * @category Class
 * @package  SdkmsClient
 * @author   Swagger Codegen team
 * @link     https://github.com/swagger-api/swagger-codegen
 */

/**
 * Fortanix SDKMS REST API
 *
 * This is a set of REST APIs for accessing the Fortanix Self-Defending Key Management System. This includes APIs for managing accounts, and for performing cryptographic and key management operations.
 *
 * OpenAPI spec version: 1.0.0-20200608
 * Contact: support@fortanix.com
 * Generated by: https://github.com/swagger-api/swagger-codegen.git
 *
 */

/**
 * NOTE: This class is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen
 * Do not edit the class manually.
 */

namespace SdkmsClient\Api;

use \SdkmsClient\ApiClient;
use \SdkmsClient\ApiException;
use \SdkmsClient\Configuration;
use \SdkmsClient\ObjectSerializer;

/**
 * StatsApi Class Doc Comment
 *
 * @category Class
 * @package  SdkmsClient
 * @author   Swagger Codegen team
 * @link     https://github.com/swagger-api/swagger-codegen
 */
class StatsApi
{
    /**
     * API Client
     *
     * @var \SdkmsClient\ApiClient instance of the ApiClient
     */
    protected $apiClient;

    /**
     * Constructor
     *
     * @param \SdkmsClient\ApiClient|null $apiClient The api client to use
     */
    public function __construct(\SdkmsClient\ApiClient $apiClient = null)
    {
        if ($apiClient === null) {
            $apiClient = new ApiClient();
        }

        $this->apiClient = $apiClient;
    }

    /**
     * Get API client
     *
     * @return \SdkmsClient\ApiClient get the API client
     */
    public function getApiClient()
    {
        return $this->apiClient;
    }

    /**
     * Set the API client
     *
     * @param \SdkmsClient\ApiClient $apiClient set the API client
     *
     * @return StatsApi
     */
    public function setApiClient(\SdkmsClient\ApiClient $apiClient)
    {
        $this->apiClient = $apiClient;
        return $this;
    }

    /**
     * Operation getAppStats
     *
     * Get transaction statistics for a specific application
     *
     * @param string $app_id Application Identifier (required)
     * @param int $range_from Starting time for search , this is EPOCH value (optional)
     * @param int $range_to Ending time for search , this is EPOCH value (optional)
     * @param int $num_points Number of data points desired (optional)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\StatsResponse
     */
    public function getAppStats($app_id, $range_from = null, $range_to = null, $num_points = null)
    {
        list($response) = $this->getAppStatsWithHttpInfo($app_id, $range_from, $range_to, $num_points);
        return $response;
    }

    /**
     * Operation getAppStatsWithHttpInfo
     *
     * Get transaction statistics for a specific application
     *
     * @param string $app_id Application Identifier (required)
     * @param int $range_from Starting time for search , this is EPOCH value (optional)
     * @param int $range_to Ending time for search , this is EPOCH value (optional)
     * @param int $num_points Number of data points desired (optional)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\StatsResponse, HTTP status code, HTTP response headers (array of strings)
     */
    public function getAppStatsWithHttpInfo($app_id, $range_from = null, $range_to = null, $num_points = null)
    {
        // verify the required parameter 'app_id' is set
        if ($app_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $app_id when calling getAppStats');
        }
        // parse inputs
        $resourcePath = "/sys/v1/stats/{app-id}/app";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // query params
        if ($range_from !== null) {
            $queryParams['range_from'] = $this->apiClient->getSerializer()->toQueryValue($range_from);
        }
        // query params
        if ($range_to !== null) {
            $queryParams['range_to'] = $this->apiClient->getSerializer()->toQueryValue($range_to);
        }
        // query params
        if ($num_points !== null) {
            $queryParams['num_points'] = $this->apiClient->getSerializer()->toQueryValue($num_points);
        }
        // path params
        if ($app_id !== null) {
            $resourcePath = str_replace(
                "{" . "app-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($app_id),
                $resourcePath
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'GET',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\StatsResponse',
                '/sys/v1/stats/{app-id}/app'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\StatsResponse', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\StatsResponse', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation getAppsStats
     *
     * Get app aggregate transaction statistics
     *
     * @param int $range_from Starting time for search , this is EPOCH value (optional)
     * @param int $range_to Ending time for search , this is EPOCH value (optional)
     * @param int $top_count Maximum top count for statistics query (optional)
     * @param int $num_points Number of data points desired (optional)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\StatsResponse
     */
    public function getAppsStats($range_from = null, $range_to = null, $top_count = null, $num_points = null)
    {
        list($response) = $this->getAppsStatsWithHttpInfo($range_from, $range_to, $top_count, $num_points);
        return $response;
    }

    /**
     * Operation getAppsStatsWithHttpInfo
     *
     * Get app aggregate transaction statistics
     *
     * @param int $range_from Starting time for search , this is EPOCH value (optional)
     * @param int $range_to Ending time for search , this is EPOCH value (optional)
     * @param int $top_count Maximum top count for statistics query (optional)
     * @param int $num_points Number of data points desired (optional)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\StatsResponse, HTTP status code, HTTP response headers (array of strings)
     */
    public function getAppsStatsWithHttpInfo($range_from = null, $range_to = null, $top_count = null, $num_points = null)
    {
        // parse inputs
        $resourcePath = "/sys/v1/stats/apps";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // query params
        if ($range_from !== null) {
            $queryParams['range_from'] = $this->apiClient->getSerializer()->toQueryValue($range_from);
        }
        // query params
        if ($range_to !== null) {
            $queryParams['range_to'] = $this->apiClient->getSerializer()->toQueryValue($range_to);
        }
        // query params
        if ($top_count !== null) {
            $queryParams['top_count'] = $this->apiClient->getSerializer()->toQueryValue($top_count);
        }
        // query params
        if ($num_points !== null) {
            $queryParams['num_points'] = $this->apiClient->getSerializer()->toQueryValue($num_points);
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'GET',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\StatsResponse',
                '/sys/v1/stats/apps'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\StatsResponse', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\StatsResponse', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation getGroupStats
     *
     * Get transaction statistics for a specific group
     *
     * @param string $group_id Group Identifier (required)
     * @param int $range_from Starting time for search , this is EPOCH value (optional)
     * @param int $range_to Ending time for search , this is EPOCH value (optional)
     * @param int $num_points Number of data points desired (optional)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\StatsResponse
     */
    public function getGroupStats($group_id, $range_from = null, $range_to = null, $num_points = null)
    {
        list($response) = $this->getGroupStatsWithHttpInfo($group_id, $range_from, $range_to, $num_points);
        return $response;
    }

    /**
     * Operation getGroupStatsWithHttpInfo
     *
     * Get transaction statistics for a specific group
     *
     * @param string $group_id Group Identifier (required)
     * @param int $range_from Starting time for search , this is EPOCH value (optional)
     * @param int $range_to Ending time for search , this is EPOCH value (optional)
     * @param int $num_points Number of data points desired (optional)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\StatsResponse, HTTP status code, HTTP response headers (array of strings)
     */
    public function getGroupStatsWithHttpInfo($group_id, $range_from = null, $range_to = null, $num_points = null)
    {
        // verify the required parameter 'group_id' is set
        if ($group_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $group_id when calling getGroupStats');
        }
        // parse inputs
        $resourcePath = "/sys/v1/stats/{group-id}/group";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // query params
        if ($range_from !== null) {
            $queryParams['range_from'] = $this->apiClient->getSerializer()->toQueryValue($range_from);
        }
        // query params
        if ($range_to !== null) {
            $queryParams['range_to'] = $this->apiClient->getSerializer()->toQueryValue($range_to);
        }
        // query params
        if ($num_points !== null) {
            $queryParams['num_points'] = $this->apiClient->getSerializer()->toQueryValue($num_points);
        }
        // path params
        if ($group_id !== null) {
            $resourcePath = str_replace(
                "{" . "group-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($group_id),
                $resourcePath
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'GET',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\StatsResponse',
                '/sys/v1/stats/{group-id}/group'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\StatsResponse', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\StatsResponse', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation getGroupsStats
     *
     * Get group aggregate transaction statistics
     *
     * @param int $range_from Starting time for search , this is EPOCH value (optional)
     * @param int $range_to Ending time for search , this is EPOCH value (optional)
     * @param int $top_count Maximum top count for statistics query (optional)
     * @param int $num_points Number of data points desired (optional)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\StatsResponse
     */
    public function getGroupsStats($range_from = null, $range_to = null, $top_count = null, $num_points = null)
    {
        list($response) = $this->getGroupsStatsWithHttpInfo($range_from, $range_to, $top_count, $num_points);
        return $response;
    }

    /**
     * Operation getGroupsStatsWithHttpInfo
     *
     * Get group aggregate transaction statistics
     *
     * @param int $range_from Starting time for search , this is EPOCH value (optional)
     * @param int $range_to Ending time for search , this is EPOCH value (optional)
     * @param int $top_count Maximum top count for statistics query (optional)
     * @param int $num_points Number of data points desired (optional)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\StatsResponse, HTTP status code, HTTP response headers (array of strings)
     */
    public function getGroupsStatsWithHttpInfo($range_from = null, $range_to = null, $top_count = null, $num_points = null)
    {
        // parse inputs
        $resourcePath = "/sys/v1/stats/groups";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // query params
        if ($range_from !== null) {
            $queryParams['range_from'] = $this->apiClient->getSerializer()->toQueryValue($range_from);
        }
        // query params
        if ($range_to !== null) {
            $queryParams['range_to'] = $this->apiClient->getSerializer()->toQueryValue($range_to);
        }
        // query params
        if ($top_count !== null) {
            $queryParams['top_count'] = $this->apiClient->getSerializer()->toQueryValue($top_count);
        }
        // query params
        if ($num_points !== null) {
            $queryParams['num_points'] = $this->apiClient->getSerializer()->toQueryValue($num_points);
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'GET',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\StatsResponse',
                '/sys/v1/stats/groups'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\StatsResponse', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\StatsResponse', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }

    /**
     * Operation getSecurityObjectStats
     *
     * Get transaction statistics for a specific security object
     *
     * @param string $key_id kid of security object (required)
     * @param int $range_from Starting time for search , this is EPOCH value (optional)
     * @param int $range_to Ending time for search , this is EPOCH value (optional)
     * @param int $num_points Number of data points desired (optional)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return \SdkmsClient\Model\StatsResponse
     */
    public function getSecurityObjectStats($key_id, $range_from = null, $range_to = null, $num_points = null)
    {
        list($response) = $this->getSecurityObjectStatsWithHttpInfo($key_id, $range_from, $range_to, $num_points);
        return $response;
    }

    /**
     * Operation getSecurityObjectStatsWithHttpInfo
     *
     * Get transaction statistics for a specific security object
     *
     * @param string $key_id kid of security object (required)
     * @param int $range_from Starting time for search , this is EPOCH value (optional)
     * @param int $range_to Ending time for search , this is EPOCH value (optional)
     * @param int $num_points Number of data points desired (optional)
     * @throws \SdkmsClient\ApiException on non-2xx response
     * @return array of \SdkmsClient\Model\StatsResponse, HTTP status code, HTTP response headers (array of strings)
     */
    public function getSecurityObjectStatsWithHttpInfo($key_id, $range_from = null, $range_to = null, $num_points = null)
    {
        // verify the required parameter 'key_id' is set
        if ($key_id === null) {
            throw new \InvalidArgumentException('Missing the required parameter $key_id when calling getSecurityObjectStats');
        }
        // parse inputs
        $resourcePath = "/sys/v1/stats/{key-id}/key";
        $httpBody = '';
        $queryParams = [];
        $headerParams = [];
        $formParams = [];
        $_header_accept = $this->apiClient->selectHeaderAccept(['application/json']);
        if (!is_null($_header_accept)) {
            $headerParams['Accept'] = $_header_accept;
        }
        $headerParams['Content-Type'] = $this->apiClient->selectHeaderContentType([]);

        // query params
        if ($range_from !== null) {
            $queryParams['range_from'] = $this->apiClient->getSerializer()->toQueryValue($range_from);
        }
        // query params
        if ($range_to !== null) {
            $queryParams['range_to'] = $this->apiClient->getSerializer()->toQueryValue($range_to);
        }
        // query params
        if ($num_points !== null) {
            $queryParams['num_points'] = $this->apiClient->getSerializer()->toQueryValue($num_points);
        }
        // path params
        if ($key_id !== null) {
            $resourcePath = str_replace(
                "{" . "key-id" . "}",
                $this->apiClient->getSerializer()->toPathValue($key_id),
                $resourcePath
            );
        }

        // for model (json/xml)
        if (isset($_tempBody)) {
            $httpBody = $_tempBody; // $_tempBody is the method argument, if present
        } elseif (count($formParams) > 0) {
            $httpBody = $formParams; // for HTTP post (form)
        }
        // this endpoint requires API key authentication
        $apiKey = $this->apiClient->getApiKeyWithPrefix('Authorization');
        if (strlen($apiKey) !== 0) {
            $headerParams['Authorization'] = $apiKey;
        }
        // make the API Call
        try {
            list($response, $statusCode, $httpHeader) = $this->apiClient->callApi(
                $resourcePath,
                'GET',
                $queryParams,
                $httpBody,
                $headerParams,
                '\SdkmsClient\Model\StatsResponse',
                '/sys/v1/stats/{key-id}/key'
            );

            return [$this->apiClient->getSerializer()->deserialize($response, '\SdkmsClient\Model\StatsResponse', $httpHeader), $statusCode, $httpHeader];
        } catch (ApiException $e) {
            switch ($e->getCode()) {
                case 200:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\StatsResponse', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
                default:
                    $data = $this->apiClient->getSerializer()->deserialize($e->getResponseBody(), '\SdkmsClient\Model\Error', $e->getResponseHeaders());
                    $e->setResponseObject($data);
                    break;
            }

            throw $e;
        }
    }
}
