<?php
require_once('../lib/autoload.php');

use SdkmsClient\Api\AccountsApi;
use SdkmsClient\Api\ApprovalRequestsApi;
use SdkmsClient\Api\AuthenticationApi;
use SdkmsClient\Api\ChildAccountsApi;
use SdkmsClient\Api\ChildAccountUsersApi;
use SdkmsClient\Api\DigestApi;
use SdkmsClient\Api\EncryptionAndDecryptionApi;
use SdkmsClient\Api\PluginsApi;
use SdkmsClient\Api\SecurityObjectsApi;
use SdkmsClient\Api\SignAndVerifyApi;
use SdkmsClient\Api\UsersApi;
use SdkmsClient\Api\WrappingAndUnwrappingApi;
use SdkmsClient\ApiClient;
use SdkmsClient\ApiException;
use SdkmsClient\Configuration;
use SdkmsClient\Model\Account;
use SdkmsClient\Model\AccountRequest;
use SdkmsClient\Model\App;
use SdkmsClient\Model\AppAuthType;
use SdkmsClient\Model\AppPermissions;
use SdkmsClient\Model\AppRequest;
use SdkmsClient\Model\AppResetSecretRequest;
use SdkmsClient\Model\ApprovalRequest;
use SdkmsClient\Model\ApprovalRequestRequest;
use SdkmsClient\Model\AuthConfig;
use SdkmsClient\Model\AuthConfigPassword;
use SdkmsClient\Model\BatchDecryptRequest;
use SdkmsClient\Model\BatchDecryptRequestInner;
use SdkmsClient\Model\BatchEncryptRequest;
use SdkmsClient\Model\BatchEncryptRequestInner;
use SdkmsClient\Model\ChildAccountUser;
use SdkmsClient\Model\ChildAccountUserRequest;
use SdkmsClient\Model\CryptMode;
use SdkmsClient\Model\DecryptRequest;
use SdkmsClient\Model\DeriveKeyMechanism;
use SdkmsClient\Model\DeriveKeyRequest;
use SdkmsClient\Model\DigestAlgorithm;
use SdkmsClient\Model\DigestRequest;
use SdkmsClient\Model\EncryptRequest;
use SdkmsClient\Model\EncryptRequestEx;
use SdkmsClient\Model\Group;
use SdkmsClient\Model\GroupRequest;
use SdkmsClient\Model\KeyObject;
use SdkmsClient\Model\KeyOperations;
use SdkmsClient\Model\Language;
use SdkmsClient\Model\LoggingConfig;
use SdkmsClient\Model\LoggingConfigRequest;
use SdkmsClient\Model\MacGenerateRequest;
use SdkmsClient\Model\MacVerifyRequest;
use SdkmsClient\Model\ObjectType;
use SdkmsClient\Model\PluginInvokeRequest;
use SdkmsClient\Model\PluginRequest;
use SdkmsClient\Model\PluginSource;
use SdkmsClient\Model\PluginType;
use SdkmsClient\Model\ProcessInviteRequest;
use SdkmsClient\Model\SelectAccountRequest;
use SdkmsClient\Model\SignRequest;
use SdkmsClient\Model\SignupRequest;
use SdkmsClient\Model\SobjectDescriptor;
use SdkmsClient\Model\SobjectRequest;
use SdkmsClient\Model\SplunkLoggingConfig;
use SdkmsClient\Model\SplunkLoggingConfigRequest;
use SdkmsClient\Model\TlsConfig;
use SdkmsClient\Model\TlsMode;
use SdkmsClient\Model\UnwrapKeyRequest;
use SdkmsClient\Model\User;
use SdkmsClient\Model\UserAccountFlags;
use SdkmsClient\Model\UserGroupFlags;
use SdkmsClient\Model\UserGroupMap;
use SdkmsClient\Model\UserRequest;
use SdkmsClient\Model\VerifyRequest;
use SdkmsClient\Model\WrapKeyRequest;

include 'base/ApiExample.php';



class RestApiTest extends ApiExample
{
    private string $email;
    private string $password;

    private string $userAcctId;

    private ?User $user;

    private ApiClient $appClient;

    public function __construct()
    {
        parent::__construct();
    }

    public function connect()
    {
        $config = Configuration::getDefaultConfiguration();
        $config->setDebug(false);
        $config->setHost("https://sdkms.test.fortanix.com");
        $this->client = new ApiClient($config);
    }

    public function miscTest()
    {
        try {
            $cli = new ApiClient();
            $config = $cli->getConfig();
            $config->setHost("https://sdkms.test.fortanix.com");
            $auth = new AuthenticationApi($cli);
            $version = $auth->getServerVersion();

            $auth->checkHealth();
            echo "✅ Health check successfull\n";
        } catch (Exception $e) {
            echo $e->getMessage();
        }
    }

    /* ***************************User Auth Tests*********************** */

    public function createNewUser()
    {
        try {
            $this->email = sprintf("%s@fortanix.com", $this->generateRandomString(12));
            $this->password = sprintf("password-%s", $this->testUniqueString);
            $signupRequest = new SignupRequest();
            $signupRequest->setUserEmail($this->email);
            $signupRequest->setUserPassword($this->password);
            $signupRequest->setRecaptchaResponse("03AOP2lf58wnS5HqYUreAVBIKqGKMFTJJ_ZO5-1qdZkzAu-upL9nvCCGx9AKit4yzZWDoMLnjjHbs71SjKEDfiNeXKggD7K0OiWjABVErMlt0zruF1VlBh3Wa_uWNbBvGKzNh4dYLthra_V7lwOsPPS0mP1EXPhMp9BVLRCZOtHl6wYZKpjWbDHvQtW3YQGl2Y11YqVAKdekSmT6r_Kct3uuESk5Iltmg34j9HsJ8ONuoo4bzn7moy3SOjE060XyGqu5z2VPv3oVPwEhQdqOM2sbAg9ZdMNwUMgw16e4uRKeJsf45xlGyg6WU");
            $this->user = $this->getUsersApi()->createUser($signupRequest);
            // echo "✅ User creation successfull\n";
        } catch (Exception $e) {
            echo $e->getMessage() . '\n';
            echo $e->getTraceAsString() . '\n';
            throw new Exception($e->getMessage());
        }
    }

    public function logInUser()
    {
        try {
            $config = $this->client->getConfig();
            $config->setUsername($this->email);
            $config->setPassword($this->password);

            //Check if it passes configs to parent or not

            $fortanixToken = $this->getAuthApi()->authorize();
            $config->setApiKey("Authorization", $fortanixToken['access_token']);
            $config->setApiKeyPrefix("Authorization", "Bearer");
            // echo sprintf("✅ Login successfull. Bearer Token - %s\n", $fortanixToken['access_token']);
        } catch (ApiException $e) {
            echo $e->getMessage() . '\n';
            echo $e->getTraceAsString() . '\n';
            throw new Exception("Log in Error");
        }
    }

    public function deleteUser()
    {
        try {
            $this->getUsersApi()->deleteUserAccount($this->user->getUserId());
            $this->email = "";
            $this->password = "";
            $this->user = NULL;
            echo "✅ Test user deleted\n";
        } catch (ApiException | Exception $e) {
            echo $e->getMessage() . '\n';
            echo $e->getTraceAsString() . '\n';
            throw new Exception("Deletion Error");
        }
    }

    public function userAuthTests()
    {
        try {
            $this->createNewUser();
            $this->logInUser();
            echo "✅ User Auth tests successfull\n";
        } catch (Exception | ApiException $e) {
            echo $e->getMessage() . '\n';
            echo $e->getTraceAsString() . '\n';
            throw new Exception("User CRUD test failed!\n");
        }
    }

    public function reAuthorize()
    {
        $this->logInUser();
        $selectRequest = new SelectAccountRequest();
        $selectRequest->setAcctId($this->userAcctId);
        $this->getAuthApi()->selectAccount($selectRequest);
    }

    /* ****************************Accounts Tests*********************** */

    public function verifyAccount(?Account $account, $name, $description)
    {
        if ($account->getName() != $name) {
            throw new Exception("New account had wrong name");
        }
        if ($account->getDescription() != $description) {
            throw new Exception("New Account had wrong description");
        }
    }

    public function createUserAccount($name)
    {
        $description = $this->randomDescription();

        $accountRequest = new AccountRequest();
        $accountRequest->setName($name);
        $accountRequest->setDescription($description);
        $account = $this->getAccountsApi()->createAccount($accountRequest);
        $this->verifyAccount($account, $name, $description);

        return $account;
    }

    public function createAndActivateUserAccount()
    {
        $name = $this->randomString();
        $account = $this->createUserAccount($name);
        $this->userAcctId = $account->getAcctId();
        $selectRequest = new SelectAccountRequest();
        $selectRequest->setAcctId($this->userAcctId);
        $this->getAuthApi()->selectAccount($selectRequest);
        return $name;
    }

    public function selectUserAccount()
    {
        $selectRequest = new SelectAccountRequest();
        $selectRequest->setAcctId($this->userAcctId);
        $this->getAuthApi()->selectAccount($selectRequest);
    }

    public function deleteUserAccount()
    {
        try {
            $this->getAccountsApi()->deleteAccount($this->userAcctId);
            echo "✅ Test user accounts deleted\n";
        } catch (Exception $e) {
            echo $e->getMessage() . '\n';
            echo $e->getTraceAsString() . '\n';
            throw new Exception("User Account deletion error");
        }
    }

    public function verifySplunkLoggingConfig(?SplunkLoggingConfig $config, $host, $port, $index, $enabled, ?TlsConfig $tls)
    {
        if ($config->getHost() != $host) {
            throw new Exception("Logging config had wrong host");
        }

        if ($config->getPort() != $port) {
            throw new Exception("Logging config had wrong port");
        }

        if ($config->getIndex() != $index) {
            throw new Exception("Logging config had wrong index");
        }

        if ($config->getEnabled() != $enabled) {
            throw new Exception("Logging config had wrong enabled");
        }

        if ($config->getTls() != $tls) {
            throw new Exception("Logging config had wrong tls");
        }
    }

    public function updateAccount(?Account $account)
    {
        $newName = $account->getName() . '-2';
        $newDescription = $this->randomDescription();
        $newOrganization = $this->randomDescription();
        $newCountry = $this->randomDescription();
        $newPhone = $this->randomDigits(1, 9);
        $newNotificationPref = $this->randomNotificationPref();
        $splunkConfig = new SplunkLoggingConfigRequest();
        $splunkConfig->setHost("localhost");
        $splunkConfig->setPort(443);
        $splunkConfig->setIndex("index");
        $splunkConfig->setToken("token");
        $tlsConfig = new TlsConfig();
        $tlsConfig->setMode(TlsMode::DISABLED);
        $splunkConfig->setTls($tlsConfig);

        $newLoggingConfig = new LoggingConfigRequest();
        $newLoggingConfig->setSplunk($splunkConfig);

        $request = new AccountRequest();
        $request->setName($newName);
        $request->setDescription($newDescription);
        $request->setOrganization($newOrganization);
        $request->setCountry($newCountry);
        $request->setPhone($newPhone);
        $request->setNotificationPref($newNotificationPref);
        $request->setAddLoggingConfigs(array($newLoggingConfig));

        $newAccount = $this->getAccountsApi()->updateAccount($account->getAcctId(), $request);
        $this->verifyAccount($newAccount, $newName, $newDescription);
        if ($newAccount->getOrganization() != $newOrganization) {
            throw new Exception("Updated account had wrong organization");
        }

        if ($newAccount->getCountry() != $newCountry) {
            throw new Exception("Updated account had wrong country");
        }

        if ($newAccount->getPhone() != $newPhone) {
            throw new Exception("Updated account had wrong phone");
        }

        if ($newAccount->getNotificationPref() != $newNotificationPref) {
            throw new Exception("Updated account had wrong notification pref");
        }

        $loggingConfigs = (array)$newAccount->getLoggingConfigs();
        if (sizeof($loggingConfigs) != 1) {
            throw new Exception("Expected one logging config");
        }

        $loggingConfig = array_values($loggingConfigs)[0];
        $configUuid = array_keys($loggingConfigs)[0];

        $tlsConfig = new TlsConfig();
        $tlsConfig->setMode(TlsMode::DISABLED);
        $this->verifySplunkLoggingConfig($loggingConfig->getSplunk(), "localhost", 443, "index", true, $tlsConfig);

        $splunkConfig = new SplunkLoggingConfigRequest();
        $splunkConfig->setEnabled(false);

        $newLoggingConfig = new LoggingConfigRequest();
        $newLoggingConfig->setSplunk($splunkConfig);
        $request = new AccountRequest();
        $loggingConfigMap = array();
        $loggingConfigMap[$configUuid] = $loggingConfig;
        $request->setModLoggingConfigs($loggingConfigMap);

        $newAccount = $this->getAccountsApi()->updateAccount($account->getAcctId(), $request);
        $loggingConfigs = (array)$newAccount->getLoggingConfigs();
        if (sizeof($loggingConfigs) != 1) {
            throw new Exception("Expected one logging config");
        }

        $loggingConfig = array_values($loggingConfigs)[0];
        $newUuid = array_keys($loggingConfigs)[0];
        if ($newUuid != $configUuid) {
            throw new Exception("Logging config had wrong UUID");
        }
        $this->verifySplunkLoggingConfig($loggingConfig->getSplunk(), "localhost", 443, "index", true, $tlsConfig);

        $request = new AccountRequest();
        $request->setDelLoggingConfigs(array($configUuid));
        $newAccount = $this->getAccountsApi()->updateAccount($account->getAcctId(), $request);
        $loggingConfigs = (array)$newAccount->getLoggingConfigs();
        if (sizeof($loggingConfigs) != 0) {
            throw new Exception("Expected zero logging configs");
        }
    }

    public function accountTest($accountName)
    {
        $newAccountName = $this->randomString();
        while ($accountName == $newAccountName) {
            $newAccountName = $this->randomString();
        }

        $account = $this->createUserAccount($newAccountName);

        $account->setAuthConfig(NULL);
        $queryAccount = $this->getAccountsApi()->getAccount($account->getAcctId());
        if ($account != $queryAccount) {
            throw new Exception("Queried account did not match created account.");
        }

        $accounts = $this->getAccountsApi()->getAccounts();
        if (sizeof($accounts) != 2) {
            $msg = sprintf("Expected 2 accounts, fetched %d account(s).", sizeof($accounts));
            throw new Exception($msg);
        }

        $found = false;

        foreach ($accounts as $a) {
            if ($a->getAcctId() == $account->getAcctId()) {
                if ($a != $account) {
                    throw new Exception("Account found by list accounts didn't match created account");
                }
                $found = true;
                break;
            }
        }

        if (!$found) {
            throw new Exception("List accounts didn't find new account");
        }

        $selectRequest = new SelectAccountRequest();
        $selectRequest->setAcctId($account->getAcctId());
        $this->getAuthApi()->selectAccount($selectRequest);

        $this->updateAccount($account);

        $selectRequest = new SelectAccountRequest();
        $selectRequest->setAcctId($account->getAcctId());
        $this->getAuthApi()->selectAccount($selectRequest);
        $this->getAccountsApi()->deleteAccount($account->getAcctId());

        try {
            $this->getAccountsApi()->getAccount($account->getAcctId());
            throw new Exception("Account deletion failed, account still exists");
        } catch (ApiException $e) {
        }
        $selectRequest = new SelectAccountRequest();
        $selectRequest->setAcctId($this->userAcctId);
        $this->getAuthApi()->selectAccount($selectRequest);
    }

    public function userAccountTests()
    {
        try {
            $accountName = $this->createAndActivateUserAccount();
            $this->accountTest($accountName);
            echo "✅ User Account tests successfull\n";
        } catch (Exception | ApiException | Exception $e) {
            echo $e->getMessage() . '\n';
            echo $e->getTraceAsString() . '\n';
            throw new Exception("User Account test failed!\n");
        }
    }

    /*************************Groups API Tests*****************************/

    public function createGroup($name)
    {
        $groupRequest = new GroupRequest();
        $groupRequest->setName($name);
        $groupRequest->setDescription($this->randomDescription());

        $group = $this->getGroupsApi()->createGroup($groupRequest);
        return $group->getGroupId();
    }

    public function checkGroupExists($id)
    {
        $group = $this->getGroupsApi()->getGroup($id);
        if ($group->getGroupId() != $id) {
            throw new Exception(sprintf("Group ID - %s doesn't match requested group ID - %s", $group->getGroupId(), $id));
        }
    }

    public function updateGroup($id)
    {
        $newName = $this->randomString();
        $newDescription = $this->randomDescription();
        $request = new GroupRequest();
        $request->setName($newName);
        $request->setDescription($newDescription);
        $group = $this->getGroupsApi()->updateGroup($id, $request);

        if ($group->getName() != $newName) {
            throw new Exception("Name updation failed");
        }
        if ($group->getDescription() != $newDescription) {
            throw new Exception("Description updation failed");
        }
    }

    public function groupTest()
    {
        $groupName1 = $this->randomString();
        $groupName2 = $this->randomString();
        while ($groupName1 == $groupName2) {
            $groupName2 = $this->randomString();
        }

        $groupId1 = $this->createGroup($groupName1);
        $groupId2 = $this->createGroup($groupName2);

        $this->checkGroupExists($groupId1);
        $this->checkGroupExists($groupId2);

        $groups = $this->getGroupsApi()->getGroups();
        if (sizeof($groups) != 2) {
            throw new Exception(sprintf("Expected no of groups were 2, but received %d.", sizeof($groups)));
        }

        foreach ($groups as $group) {
            if ($group->getGroupId() != $groupId1 && $group->getGroupId() != $groupId2) {
                throw new Exception("Group list includes unknown groups.");
            }
        }

        $this->updateGroup($groupId2);
        $this->getGroupsApi()->deleteGroup($groupId2);

        try {
            $group = $this->getGroupsApi()->getGroup($groupId2);
            throw new Exception(sprintf("Group %s exists even after deletion", $groupId2));
        } catch (ApiException $e) {
        }

        echo "✅ Groups API tests successfull\n";

        return $this->getGroupsApi()->getGroup($groupId1);
    }

    /***************************App Tests************************************/

    public function checkAppProperties(App $app, $name, $description, $appType, $groupId)
    {

        if (!$app->getEnabled()) {
            throw new Exception("Newly created app was not enabled");
        }
        if ($app->getName() != $name) {
            throw new Exception("Newly created app had wrong name");
        }
        if ($app->getDescription() != $description) {
            throw new Exception("Newly created app had wrong description");
        }
        if ($app->getAppType() != $appType) {
            throw new Exception("Newly created app had wrong app_type");
        }
        if (sizeof($app->getGroups()) != 1) {
            throw new Exception("Newly created app had wrong group list len");
        }
        if ($app->getGroups()[0] != $groupId) {
            throw new Exception("Newly created app had wrong group list");
        }
        if ($app->getAuthType() != AppAuthType::SECRET) {
            throw new Exception("Newly created app had wrong auth type");
        }
    }

    public function createApp($groupId)
    {
        $name = $this->randomString();
        $description = $this->randomDescription();
        $appType =  $this->randomDescription();

        $appGroupPermissions = array();

        $appPermissions = [AppPermissions::ENCRYPT, AppPermissions::DECRYPT, AppPermissions::WRAPKEY, AppPermissions::UNWRAPKEY, AppPermissions::DERIVEKEY, AppPermissions::MACGENERATE, AppPermissions::MACVERIFY, AppPermissions::MANAGE, AppPermissions::SIGN, AppPermissions::VERIFY, AppPermissions::AGREEKEY, AppPermissions::EXPORT];
        $appGroupPermissions[$groupId] = $appPermissions;

        $request = new AppRequest();
        $request->setName($name);
        $request->setDescription($description);
        $request->setAddGroups($appGroupPermissions);
        $request->setDefaultGroup($groupId);
        $request->setEnabled(true);
        $request->setAppType($appType);

        $app = $this->getAppsApi()->createApp($request);
        $this->checkAppProperties($app, $name, $description, $appType, $groupId);
        return $app;
    }

    public function updateApp($appId, $oldGroupId, $newGroupId)
    {
        $newName = $this->randomString();
        $newDescription = $this->randomDescription();
        $newAppType =  $this->randomDescription();

        $newAppGroupPermissions = array();

        $appPermissions = [AppPermissions::ENCRYPT, AppPermissions::DECRYPT, AppPermissions::WRAPKEY, AppPermissions::UNWRAPKEY, AppPermissions::DERIVEKEY, AppPermissions::MACGENERATE, AppPermissions::MACVERIFY, AppPermissions::MANAGE, AppPermissions::SIGN, AppPermissions::VERIFY, AppPermissions::AGREEKEY, AppPermissions::EXPORT];
        $newAppGroupPermissions[$newGroupId] = $appPermissions;

        $oldGroups = array();
        array_push($oldGroups, $oldGroupId);

        $request = new AppRequest();
        $request->setName($newName);
        $request->setDescription($newDescription);
        $request->setAddGroups($newAppGroupPermissions);
        $request->setAppType($newAppType);
        $request->setDelGroups($oldGroups);

        $app = $this->getAppsApi()->updateApp($appId, $request);
        $this->checkAppProperties($app, $newName, $newDescription, $newAppType, $newGroupId);
    }

    public function appTest(?Group $group)
    {
        $apps = $this->getAppsApi()->getApps();
        if (sizeof($apps) != 0) {
            throw new Exception(sprintf("Expected 0 apps, got %d", sizeof($apps)));
        }

        $app = $this->createApp($group->getGroupid());
        $foundApp = $this->getAppsApi()->getApp($app->getAppId());
        if ($app != $foundApp) {
            throw new Exception("Look up by ID did not find correct app");
        }

        $apps = $this->getAppsApi()->getApps();
        if (sizeof($apps) != 1) {
            throw new Exception(sprintf("Expected 1 app, got %d", sizeof($apps)));
        }
        if ($app != $apps[0]) {
            throw new Exception("Look up all apps did not find the correct app");
        }

        $newGroupName = $group->getName() . '-2';
        $groupId2 = $this->createGroup($newGroupName);
        $this->updateApp($app->getAppId(), $group->getGroupId(), $groupId2);
        $response = $this->getAppsApi()->getCredential($app->getAppId());
        $secret = $response->getCredential()->getSecret();
        if ($secret == "") {
            throw new Exception("Invalid application credential");
        }

        $resetRequest = new AppResetSecretRequest();
        $this->getAppsApi()->regenerateApiKey($app->getAppId(), $resetRequest);
        $response = $this->getAppsApi()->getCredential($app->getAppId());
        $newSecret = $response->getCredential()->getSecret();
        if ($newSecret == "") {
            throw new Exception("Invalid application credential");
        }

        if ($secret == $newSecret) {
            throw new Exception("Regenerating API key did not change credential");
        }

        $this->getAppsApi()->deleteApp($app->getAppId());
        try {
            $this->getAppsApi()->getApp($app->getAppId());
            throw new Exception("App still existed after being deleted");
        } catch (ApiException $e) {
        }
        $this->getGroupsApi()->deleteGroup($groupId2);
        echo "✅ App tests successfull\n";
    }

    public function createAndLogInApp($groupId)
    {
        $app = $this->createApp($groupId);
        $response = $this->getAppsApi()->getCredential($app->getAppId());
        $apiSecret = $response->getCredential()->getSecret();

        $config = new Configuration();
        $config->setDebug(true);
        $config->setHost("https://sdkms.test.fortanix.com");
        $config->setUsername($app->getAppId());
        $config->setPassword($apiSecret);
        $this->appClient = new ApiClient($config);

        $authApi = new AuthenticationApi($this->appClient);
        $fortanixToken = $authApi->authorize();
        $config->setApiKey("Authorization", $fortanixToken['access_token']);
        $config->setApiKeyPrefix("Authorization", "Bearer");
        $config = $this->client->getConfig();
        $config->setApiKey("Authorization", $fortanixToken['access_token']);
        $config->setApiKeyPrefix("Authorization", "Bearer");
        return $app;
    }

    /*************************Security Object Tests*************************/

    public function checkKeysEqual(KeyObject $key1, KeyObject $key2)
    {
        if ($key1->getKid() != $key2->getKid()) {
            throw new Exception("Keys did not compare correctly");
        }
        if ($key1->getName() != $key2->getName()) {
            throw new Exception("Keys did not compare correctly");
        }
        if ($key1->getDescription() != $key2->getDescription()) {
            throw new Exception("Keys did not compare correctly");
        }
        if ($key1->getKeySize() != $key2->getKeySize()) {
            throw new Exception("Keys did not compare correctly");
        }
        if ($key1->getEllipticCurve() != $key2->getEllipticCurve()) {
            throw new Exception("Keys did not compare correctly");
        }
        if ($key1->getAcctId() != $key2->getAcctId()) {
            throw new Exception("Keys did not compare correctly");
        }
        if ($key1->getGroupId() != $key2->getGroupId()) {
            throw new Exception("Keys did not compare correctly");
        }
        if ($key1->getCreator() != $key2->getCreator()) {
            throw new Exception("Keys did not compare correctly");
        }
        if ($key1->getObjType() != $key2->getObjType()) {
            throw new Exception("Keys did not compare correctly");
        }
        if ($key1->getCustomMetadata() != $key2->getCustomMetadata()) {
            throw new Exception("Keys did not compare correctly");
        }
        if ($key1->getOrigin() != $key2->getOrigin()) {
            throw new Exception("Keys did not compare correctly");
        }
        if ($key1->getPubKey() != $key2->getPubKey()) {
            throw new Exception(sprintf("Keys did not compare correctly,\nPub - 1: %s\nPub - 2: %s", $key1->getPubKey(), $key2->getPubKey()));
        }
        if ($key1->getEnabled() != $key2->getEnabled()) {
            throw new Exception("Keys did not compare correctly");
        }
        if ($key1->getCreatedAt() != $key2->getCreatedAt()) {
            throw new Exception("Keys did not compare correctly");
        }
    }

    public function checkKey(KeyObject $key)
    {
        try {
            $queriedKey = $this->getSecurityObjectsApi()->getSecurityObject($key->getKid(), "json", 'false', 'false');
            $this->checkKeysEqual($queriedKey, $key);

            $keys = $this->getSecurityObjectsApi()->getSecurityObjects();
            if (sizeof($keys) != 1) {
                throw new Exception("Expected 1 key, received %d", sizeof($keys));
            }
            $this->checkKeysEqual($keys[0], $key);
        } catch (ApiException | Exception $e) {
            echo $e->getMessage();
            echo $e->getTraceAsString();
            throw new Exception("Check key error");
        }
    }

    public function checkAndDeleteKey(KeyObject $key)
    {
        $this->checkKey($key);
        $this->deleteKey($key);
        try {
            $queriedKey = $this->getSecurityObjectsApi()->getSecurityObject($key->getKid(), "json", 'false', 'false');
            throw new Exception("Deleted security object still exists");
        } catch (ApiException $e) {
            // We expect a 404 here.
        }
    }

    public function sobjectTest($groupId)
    {
        try {
            $key = $this->createKey(ObjectType::AES, 256, NULL, $groupId);
            $this->checkAndDeleteKey($key);

            $key = $this->createKey(ObjectType::RSA, 2048, NULL, $groupId, false, true);
            $this->checkAnddeleteKey($key);

            $keyMaterial = base64_encode($this->generateRandomString(32));
            $request = new SobjectRequest();
            $request->setName($this->randomString());
            $request->setDescription($this->randomDescription());
            $request->setObjType(ObjectType::AES);
            $request->setKeySize(256);
            $request->setValue($keyMaterial);
            $request->setGroupId($groupId);

            $key = $this->getSecurityObjectsApi()->importSecurityObject($request);
            $this->checkAndDeleteKey($key);
        } catch (Exception | ApiException $e) {
            echo $e->getMessage();
            echo $e->getTraceAsString();
            throw new Exception("S object creation request errors");
        }

        // $key = $this->createKey(ObjectType::RSA, 2048, NULL, $groupId);
        // $this->checkKey($key);
        echo "✅ Security Objects tests successfull\n";
    }

    /***************************Ceyoto Tests********************************/

    public function singleEncryptTest()
    {
        $key = $this->createKey(ObjectType::AES, 256, NULL, NULL);
        $plain = $this->generateRandomString(32);
        $iv = base64_encode($this->generateRandomString(12));
        $ad = base64_encode($this->generateRandomString(16));

        try {
            $request = new EncryptRequest();
            $request->setAlg(ObjectType::AES);
            $request->setMode(CryptMode::GCM);
            $request->setIv($iv);
            $request->setPlain($plain);
            $request->setAd($ad);
            $request->setTagLen(128);
            $response = $this->getCryptoApi()->encrypt($key->getKid(), $request);
        } catch (ApiException $e) {
            print_r($e->getMessage());
            print_r($e->getTraceAsString());
            throw new Exception("Encryption error!");
        }

        $decRequest = new DecryptRequest();
        $decRequest->setAlg(ObjectType::AES);
        $decRequest->setMode(CryptMode::GCM);
        $decRequest->setIv($iv);
        $decRequest->setCipher($response->getCipher());
        $decRequest->setAd($ad);
        $decRequest->setTag($response->getTag());

        try {
            $decResponse = $this->getCryptoApi()->decrypt($key->getKid(), $decRequest);
        } catch (ApiException $e) {
            print_r($e->getMessage());
            print_r($e->getTraceAsString());
            throw new Exception("Decryption error!");
        }

        if ($decResponse->getPlain() != $plain) {
            throw new Exception("Decrypted data did not match original data");
        }
        $this->getSecurityObjectsApi()->deleteSecurityObject($key->getKid());
    }

    public function batchEncryptTest()
    {
        $key1 = $this->createKey(ObjectType::AES, 256, NULL, NULL);
        $plain1 = $this->generateRandomString();
        $request1 = new EncryptRequest();
        $request1->setAlg(ObjectType::AES);
        $request1->setPlain($plain1);
        $request1->setMode(CryptMode::CBC);

        $inner1 = new BatchEncryptRequestInner();
        $inner1->setKid($key1->getKid());
        $inner1->setRequest($request1);

        $key2 = $this->createKey(ObjectType::RSA, 2048, NULL, NULL);
        $plain2 = $this->generateRandomString();
        $request2 = new EncryptRequest();
        $request2->setAlg(ObjectType::RSA);
        $request2->setPlain($plain2);

        $inner2 = new BatchEncryptRequestInner();
        $inner2->setKid($key2->getKid());
        $inner2->setRequest($request2);

        $bRequest = array();
        array_push($bRequest, $inner1);
        array_push($bRequest, $inner2);

        $bResponse = $this->getCryptoApi()->batchEncrypt($bRequest);

        $dRequest1 = new DecryptRequest();
        $dRequest1->setAlg(ObjectType::AES);
        $dRequest1->setCipher($bResponse[0]->getBody()->getCipher());
        $dRequest1->setMode(CryptMode::CBC);
        $dRequest1->setIv($bResponse[0]->getBody()->getIv());

        $dInner1 = new BatchDecryptRequestInner();
        $dInner1->setKid($key1->getKid());
        $dInner1->setRequest($dRequest1);

        $dRequest2 = new DecryptRequest();
        $dRequest2->setAlg(ObjectType::RSA);
        $dRequest2->setCipher($bResponse[1]->getBody()->getCipher());
        $dRequest2->setIv($bResponse[1]->getBody()->getIv());

        $dInner2 = new BatchDecryptRequestInner();
        $dInner2->setKid($key2->getKid());
        $dInner2->setRequest($dRequest2);

        $dRequest = array();
        array_push($dRequest, $dInner1);
        array_push($dRequest, $dInner2);
        $dResponse = $this->getCryptoApi()->batchDecrypt($dRequest);


        if ($dResponse[0]->getBody()->getPlain() != $plain1) {
            throw new Exception("Plaintext 1 did not match");
        }

        if ($dResponse[1]->getBody()->getPlain() != $plain2) {
            throw new Exception("Plaintext 2 did not match");
        }

        $this->getSecurityObjectsApi()->deleteSecurityObject($key1->getKid());
        $this->getSecurityObjectsApi()->deleteSecurityObject($key2->getKid());
    }

    public function signatureTest()
    {
        $key = $this->createKey(ObjectType::RSA, 2048, NULL, NULL);
        try {
            $digest = $this->computeDigest($this->generateRandomString(64), DigestAlgorithm::SHA256);
            print_r($digest);
            $signRequest = new SignRequest();
            $signRequest->setHashAlg(DigestAlgorithm::SHA256);
            $signRequest->setData($digest);

            $signResponse = $this->getSignatureApi()->sign($key->getKid(), $signRequest);

            $verifyRequest = new VerifyRequest();
            $verifyRequest->setHashAlg(DigestAlgorithm::SHA256);
            $verifyRequest->setData($digest);
            $verifyRequest->setSignature($signResponse->getSignature());

            $verifyResponse = $this->getSignatureApi()->verify($key->getKid(), $verifyRequest);
        } catch (ApiException $e) {
            echo sprintf("%s\n", $e->getMessage());
            echo sprintf("%s\n", $e->getResponseBody());
            echo sprintf("%s\n", $e->getTraceAsString());
            throw new Exception("Digest calculation failed");
        }

        if (!$verifyResponse->getResult()) {
            throw new Exception("Signature did not verify");
        }
        $this->getSecurityObjectsApi()->deleteSecurityObject($key->getKid());
    }

    public function digestTest()
    {
        $key = $this->createKey(ObjectType::HMAC, 256, NULL, NULL);
        $plain = $this->generateRandomString(64);
        try {
            $digest = $this->computeDigest($plain, DigestAlgorithm::SHA256);
        } catch (Exception $e) {
            throw new TestException("Digest calculation failed");
        }
        $digestRequest = new DigestRequest();
        $digestRequest->setAlg(DigestAlgorithm::SHA256);
        $digestRequest->setData(base64_encode($plain));

        $digestResponse = $this->getDigestApi()->computeDigest($digestRequest);

        echo sprintf("Plain Text - %s\nOur Digest - %s\nGenerated Digest - %s\n", $plain, $digest, $digestResponse->getDigest());
        if ($digest != $digestResponse->getDigest()) {
            throw new Exception("Computed digest did not match");
        }

        $macRequest = new MacGenerateRequest();
        $macRequest->setAlg(DigestAlgorithm::SHA256);
        $macRequest->setData($plain);

        $macResponse = $this->getDigestApi()->computeMac($key->getKid(), $macRequest);

        $macVerifyRequest = new MacVerifyRequest();
        $macVerifyRequest->setAlg(DigestAlgorithm::SHA256);
        $macVerifyRequest->setData($plain);
        $macVerifyRequest->setDigest($macResponse->getDigest());

        $macVerifyResponse = $this->getDigestApi()->verifyMac($key->getKid(), $macVerifyRequest);
        if (!$macVerifyResponse->getResult()) {
            throw new Exception("MAC verify failed");
        }
        $this->getSecurityObjectsApi()->deleteSecurityObject($key->getKid());
    }

    public function wrapTest()
    {
        $wrappingKey = $this->createKey(ObjectType::AES, 256, NULL, NULL);
        $iv = base64_encode($this->generateRandomString(16));

        $wrappedKey = $this->createKey(ObjectType::AES, 256, NULL, NULL, true);

        $wrapRequest = new WrapKeyRequest();
        $wrapRequest->setAlg(ObjectType::AES);
        $wrapRequest->setMode(CryptMode::CBC);
        $wrapRequest->setIv($iv);
        $wrapRequest->setKid($wrappedKey->getKid());

        $wrapResponse = $this->getWrapApi()->wrapKey($wrappingKey->getKid(), $wrapRequest);

        $unwrapRequest = new UnwrapKeyRequest();
        $unwrapRequest->setAlg(ObjectType::AES);
        $unwrapRequest->setObjType(ObjectType::AES);
        $unwrapRequest->setMode(CryptMode::CBC);
        $unwrapRequest->setIv($iv);
        $unwrapRequest->setWrappedKey($wrapResponse->getWrappedKey());
        $unwrapRequest->setName($wrappedKey->getName() . '-2');
        $unwrapRequest->setDescription($this->randomDescription());

        $newKey = $this->getWrapApi()->unwrapKey($wrappingKey->getKid(), $unwrapRequest);

        $this->getSecurityObjectsApi()->deleteSecurityObject($newKey->getKid());
        $this->getSecurityObjectsApi()->deleteSecurityObject($wrappingKey->getKid());
        $this->getSecurityObjectsApi()->deleteSecurityObject($wrappedKey->getKid());
    }

    public function deriveKeyTest()
    {
        $origKey = $this->createKey(ObjectType::AES, 256, NULL);
        $keyMaterial = $this->makeEncryptRequest($origKey, CryptMode::CBC, 128);

        $metadata = array();
        $metadata[$this->randomString()] = $this->randomString();

        $deriveKeyMechanism = new DeriveKeyMechanism();
        $deriveKeyMechanism->setEncryptData($keyMaterial);

        $request = new DeriveKeyRequest();
        $request->setKeyType(ObjectType::AES);
        $request->setKeySize(128);
        $request->setName($this->randomString());
        $request->setMechanism($deriveKeyMechanism);
        $request->setDescription($this->randomDescription());
        $request->setCustomMetadata($metadata);

        try {
            $newKey = $this->getSecurityObjectsApi()->deriveKey($origKey->getKid(), $request);
            $this->getSecurityObjectsApi()->deleteSecurityObject($newKey->getKid());
        } catch (Exception $e) {
            echo sprintf("%s\n", $e->getMessage());
            echo sprintf("%s\n", $e->getTraceAsString());
        }
        $this->getSecurityObjectsApi()->deleteSecurityObject($origKey->getKid());
    }

    public function cryptoTest($groupId)
    {
        $app = $this->createAndLogInApp($groupId);

        $this->singleEncryptTest();
        $this->batchEncryptTest();
        $this->signatureTest();
        try {
            $this->digestTest();
        } catch (Exception $e) {
            echo sprintf("%s\n", $e->getMessage());
        }
        $this->wrapTest();
        $this->deriveKeyTest();

        $this->reAuthorize();
        $this->getAppsApi()->deleteApp($app->getAppId());
        echo "✅ Crypto API tests successfull\n";
    }

    /***************************Plugin API Tests************************** */

    private function deletePlugin($pluginId)
    {
        $pluginApi = new PluginsApi();
        $pluginApi->deletePlugin($pluginId);
    }

    private function invokePlugin($pluginId)
    {
        $data = ["flag" => true, "key" => "abcdefgh"];
        $request = new PluginInvokeRequest($data);
        $pluginApi = new PluginsApi();
        $pluginInvokeResponse = $pluginApi->invokePlugin($pluginId, $request);
        if ($pluginInvokeResponse == null) {
            throw new Exception("Plugin execution failed");
        }
    }

    private function createPlugin($groupId)
    {
        $pluginSource = new PluginSource();
        $pluginSource->setLanguage(Language::LUA);
        $pluginSource->setCode("function run(input)\n  return input\n end");
        $pluginRequest = new PluginRequest();
        $pluginRequest->setName("sample-plugin");
        $pluginRequest->setDefaultGroup($groupId);
        $pluginRequest->setSource($pluginSource);
        $groups = [];
        array_push($groups, $groupId);
        $pluginRequest->setAddGroups($groups);
        $pluginRequest->setEnabled(true);
        $pluginRequest->setPluginType(PluginType::STANDARD);

        $pluginApi = new PluginsApi();
        $plugin = $pluginApi->createPlugin($pluginRequest);

        return $plugin->getPluginId();
    }

    public function pluginTest($groupId)
    {

        $pluginId = $this->createPlugin($groupId);
        $this->invokePlugin($pluginId);
        $this->deletePlugin($pluginId);

        echo "✅ Plugins API tests successfull\n";
        $this->reAuthorize();
    }

    /**************************Quorum Tests*********************************/


    public function createApprovalRequest($childApi, $tempKey)
    {
        $approvalApi = new ApprovalRequestsApi($childApi);
        $sobjectDesc = new SobjectRequest();
        $sobjectDesc->setName("Updated Name");
        $sobjectDesc->setDescription("Updated description");

        $request = new ApprovalRequestRequest();
        $request->setOperation('/crypto/v1/keys/' . $tempKey->getKid());
        $request->setMethod("PATCH");
        $request->setBody($sobjectDesc);
        $request->setDescription("Test description");


        $result = $approvalApi->createApprovalRequest($request);

        return $result->getRequestId();
    }

    public function quorumTests($groupId)
    {
        try {
            $this->getGroupsApi()->updateGroup($groupId, ["approval_policy" => ["quorum" => ["n" => 1, "members" => [["user" => $this->user->getUserId()]]]]]);

            $group = $this->getGroupsApi()->getGroup($groupId);
            $signupRequest = new SignupRequest();
            $childEmail =  sprintf("%s@test.fortanix.com", $this->generateRandomString(12));
            $childPass = "test@123";
            $signupRequest->setUserEmail($childEmail);
            $signupRequest->setUserPassword($childPass);
            $signupRequest->setRecaptchaResponse("03AOP2lf58wnS5HqYUreAVBIKqGKMFTJJ_ZO5-1qdZkzAu-upL9nvCCGx9AKit4yzZWDoMLnjjHbs71SjKEDfiNeXKggD7K0OiWjABVErMlt0zruF1VlBh3Wa_uWNbBvGKzNh4dYLthra_V7lwOsPPS0mP1EXPhMp9BVLRCZOtHl6wYZKpjWbDHvQtW3YQGl2Y11YqVAKdekSmT6r_Kct3uuESk5Iltmg34j9HsJ8ONuoo4bzn7moy3SOjE060XyGqu5z2VPv3oVPwEhQdqOM2sbAg9ZdMNwUMgw16e4uRKeJsf45xlGyg6WU");

            $childApi = new ApiClient();
            $childUserApi = new UsersApi($childApi);

            $childUser = $childUserApi->createUser($signupRequest);


            $config = $childApi->getConfig();
            $config->setUsername($childEmail);
            $config->setPassword($childPass);

            $childAuthApi = new AuthenticationApi($childApi);
            $fortanixToken = $childAuthApi->authorize();
            $config->setApiKey("Authorization", $fortanixToken['access_token']);
            $config->setApiKeyPrefix("Authorization", "Bearer");

            $userRequest = new UserRequest();
            $userRequest->setUserEmail($childEmail);
            $userRequest->setAccountRole([UserAccountFlags::ACCOUNT_MEMBER]);

            $this->reAuthorize();
            $this->selectUserAccount();

            $this->getUsersApi()->inviteUser($userRequest);
            $approvalApi = new ApprovalRequestsApi($this->client);
            $tempKey1 = $this->createKey(ObjectType::AES, 256, NULL, $groupId);
            $tempKey2 = $this->createKey(ObjectType::AES, 256, NULL, $groupId);

            $inviteReq = new ProcessInviteRequest();
            $inviteReq->setAccepts([$this->userAcctId]);

            $childUserApi->processInvitations($inviteReq);

            $childAccSelReq = new SelectAccountRequest();
            $childAccSelReq->setAcctId($this->userAcctId);
            $childAuthApi->selectAccount($childAccSelReq);

            $requestID1 = $this->createApprovalRequest($childApi, $tempKey1);
            $requestID2 = $this->createApprovalRequest($childApi, $tempKey1);

            $approvalApi->approve($requestID1);
            $approvalApi->deny($requestID2);

            $childUserApi = new UsersApi($childApi);
            $childUserApi->deleteUser($childUser->getUserId());

            $this->getSecurityObjectsApi()->deleteSecurityObject($tempKey1->getKid());
            $this->getSecurityObjectsApi()->deleteSecurityObject($tempKey2->getKid());

            echo "✅ Quorum Policy tests successfull\n";
        } catch (ApiException $e) {
            echo sprintf("%s\n", $e->getMessage());
            echo sprintf("%s\n", $e->getTraceAsString());
            echo $e->getResponseBody() . '\n';
        }
    }

    /* ************************Test Cleaning*******************************/

    public function deleteTestObjects($groupId)
    {
        try {
            $this->getGroupsApi()->deleteGroup($groupId);
            $this->deleteUserAccount();
            $this->deleteUser();
        } catch (ApiException $e) {
            echo $e->getMessage() . '\n';
            echo $e->getTraceAsString() . '\n';
            echo $e->getResponseBody() . '\n';
            throw new Exception($e->getMessage());
        }
    }

    public function runTest()
    {
        echo "Testing API....\n";
        $this->miscTest();
        $this->userAuthTests();
        $this->userAccountTests();
        $group = $this->groupTest();
        $this->appTest($group);
        $this->sobjectTest($group->getGroupId());
        $this->cryptoTest($group->getGroupId());
        $this->pluginTest($group->getGroupId());
        $this->quorumTests($group->getGroupId());

        $this->deleteTestObjects($group->getGroupId());
    }
}

$test = new RestApiTest();
$test->mainHelper();
