<?php

require_once('../lib/autoload.php');

use Exception;
use SdkmsClient\Api\AccountsApi;
use SdkmsClient\Api\AppsApi;
use SdkmsClient\Api\AuthenticationApi;
use SdkmsClient\Api\DigestApi;
use SdkmsClient\Api\EncryptionAndDecryptionApi;
use SdkmsClient\Api\GroupsApi;
use SdkmsClient\Api\SecurityObjectsApi;
use SdkmsClient\Api\SignAndVerifyApi;
use SdkmsClient\Api\UsersApi;
use SdkmsClient\Api\WrappingAndUnwrappingApi;
use SdkmsClient\ApiClient;
use SdkmsClient\ApiException;
use SdkmsClient\Configuration;
use SdkmsClient\Model\BatchDecryptRequest;
use SdkmsClient\Model\BatchDecryptRequestInner;
use SdkmsClient\Model\BatchEncryptRequest;
use SdkmsClient\Model\BatchEncryptRequestInner;
use SdkmsClient\Model\CryptMode;
use SdkmsClient\Model\DecryptRequest;
use SdkmsClient\Model\DigestAlgorithm;
use SdkmsClient\Model\EllipticCurve;
use SdkmsClient\Model\EncryptRequest;
use SdkmsClient\Model\KeyObject;
use SdkmsClient\Model\KeyOperations;
use SdkmsClient\Model\NotificationPref;
use SdkmsClient\Model\ObjectType;
use SdkmsClient\Model\RsaEncryptionPadding;
use SdkmsClient\Model\RsaEncryptionPaddingOAEP;
use SdkmsClient\Model\RsaEncryptionPolicy;
use SdkmsClient\Model\RsaEncryptionPolicyPaddingOAEP;
use SdkmsClient\Model\RsaOptions;
use SdkmsClient\Model\RsaSignaturePolicyPadding;
use SdkmsClient\Model\SobjectRequest;
use SdkmsClient\Model\UnwrapKeyParams;
use SdkmsClient\Model\UnwrapKeyRequest;
use SdkmsClient\Model\WrapKeyRequest;

class KeyClass
{
    private string $keyType;
    private int $size;
    private ?EllipticCurve $curve;

    public function __construct(string $keyType = NULL, ?EllipticCurve $curve = NULL, int $size = NULL)
    {
        if ($keyType !== NULL && $size !== NULL) {
            $this->keyType = $keyType;
            $this->size = $size;
            $this->curve = null;
        } else if ($curve !== NULL) {
            $this->keyType = ObjectType::EC;
            $this->size = null;
            $this->curve = $curve;
        } else {
            throw new Exception('Keyclass constructor parameters not sufficient');
        }
    }

    // public function equals(){}

    // public function hashCode() {
    //     int hash = 
    // }
}

class ApiExample
{
    public $debug = false;

    protected ApiClient $client;

    private ?AccountsApi $accountsApi;
    private ?AppsApi $appsApi;
    private ?AuthenticationApi $authApi;
    private ?DigestApi $digestApi;
    private ?EncryptionAndDecryptionApi $cryptoApi;
    private ?GroupsApi $groupsApi;
    private ?SecurityObjectsApi $securityObjectsApi;
    private ?SignAndVerifyApi $signatureApi;
    private ?UsersApi $usersApi;
    private ?WrappingAndUnwrappingApi $wrapApi;

    private $keys;
    private int $nextKey;

    protected string $testUniqueString;

    protected int $minDescLen = 0;
    protected int $maxDescLen = 256;

    protected int $minPlaintextLen = 1;
    protected int $maxPlaintextLen = 10000;

    private string $baseName = "java-swagger-test-%s-%d";
    private string $baseDescription = "java-swagger-test-description-%s-%d";

    public static string $API_ENDPOINT_ENV_VAR = "FORTANIX_API_ENDPOINT";
    public static string $DEFAULT_API_ENDPOINT = "https://sdkms.test.fortanix.com";
    public static string $API_KEY_ENV_VAR = "FORTANIX_API_KEY";
    public static string $TRUST_STORE_ENV_VAR = "FORTANIX_SSL_TRUST_STORE";
    public static string $CLIENT_CERT_ENV_VAR = "FORTANIX_CLIENT_CERT";
    public static string $CLIENT_CERT_APP_ID_ENV_VAR = "FORTANIX_CLIENT_CERT_APP_ID";

    protected $digests = array(DigestAlgorithm::SHA1, DigestAlgorithm::SHA256, DigestAlgorithm::SHA384, DigestAlgorithm::SHA512);

    protected int $MAX_REQUEST_SIZE = 100000;

    protected int $BITS_PER_BYTE = 8;

    public function randomBytes(int $size)
    {
        return random_bytes($size);
    }

    public function randomRange(int $min, int $max)
    {
        return mt_rand(0, $max - $min) + $min;
    }

    public function randomString(int $min = 1, int $max = 16)
    {
        $len = $this->randomrange($min, $max);
        if ($len == 0)
            return "";
        else {
            $bytes = $this->randomBytes($len);
            $encodedData = base64_encode($bytes);
            return substr($encodedData, $len);
        }
    }

    public function randomDescription()
    {
        return $this->randomString($this->minDescLen, $this->maxDescLen);
    }

    public function randomDigits(int $min, int $max)
    {
        $len = $this->randomRange($min, $max);
        $digits = "";
        for ($i = 0; $i < $len; $i++) {
            $digits = $digits . strval($this->randomRange(0, 9));
        }
        return $digits;
    }

    public function randomPlaintext()
    {
        return $this->randomBytes($this->randomRange($this->minPlaintextLen, $this->maxPlaintextLen));
    }

    public function randomNotificationPref()
    {
        $values = NotificationPref::getAllowableEnumValues();
        $which = $this->randomRange(0, sizeof($values, 0));
        return $values[$which];
    }

    public function generateRandomString($length = 32)
    {
        $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }

    // public static function configureTrustStore() {

    // }

    public function __construct()
    {
        $this->nextKey = 0;
        $unique = $this->randomBytes(16);
        $this->testUniqueString = base64_encode($unique);
        $this->keys = array();
        $this->usersApi = NULL;
        $this->authApi = NULL;
        $this->accountsApi = NULL;
        $this->appsApi = NULL;
        $this->cryptoApi = NULL;
        $this->digestApi = NULL;
        $this->groupsApi = NULL;
        $this->securityObjectsApi = NULL;
        $this->signatureApi = NULL;
        $this->usersApi = NULL;
        $this->wrapApi = NULL;
    }

    protected function getAccountsApi()
    {
        if ($this->accountsApi == NULL) {
            $this->accountsApi = new AccountsApi($this->client);
        }
        return $this->accountsApi;
    }

    protected function getAppsApi()
    {
        if ($this->appsApi == NULL) {
            $this->appsApi = new AppsApi($this->client);
        }
        return $this->appsApi;
    }

    protected function getAuthApi()
    {
        if ($this->authApi == NULL) {
            $this->authApi = new AuthenticationApi($this->client);
        }
        return $this->authApi;
    }

    protected function getCryptoApi()
    {
        if ($this->cryptoApi == NULL) {
            $this->cryptoApi = new EncryptionAndDecryptionApi($this->client);
        }
        return $this->cryptoApi;
    }

    protected function getDigestApi()
    {
        if ($this->digestApi == NULL) {
            $this->digestApi = new DigestApi($this->client);
        }
        return $this->digestApi;
    }

    protected function getGroupsApi()
    {
        if ($this->groupsApi == NULL) {
            $this->groupsApi = new GroupsApi($this->client);
        }
        return $this->groupsApi;
    }

    protected function getSecurityObjectsApi()
    {
        if ($this->securityObjectsApi == NULL) {
            $this->securityObjectsApi = new SecurityObjectsApi($this->client);
        }
        return $this->securityObjectsApi;
    }

    protected function getSignatureApi()
    {
        if ($this->signatureApi == NULL) {
            $this->signatureApi = new SignAndVerifyApi($this->client);
        }
        return $this->signatureApi;
    }

    protected function getUsersApi()
    {
        if ($this->usersApi == NULL) {
            $this->usersApi = new UsersApi($this->client);
        }
        return $this->usersApi;
    }

    protected function getWrapApi()
    {
        if ($this->wrapApi == NULL) {
            $this->wrapApi = new WrappingAndUnwrappingApi($this->client);
        }
        return $this->wrapApi;
    }

    protected function resetApis()
    {
        $this->accountsApi = NULL;
        $this->appsApi = NULL;
        $this->authApi = NULL;
        $this->digestApi = NULL;
        $this->cryptoApi = NULL;
        $this->groupsApi = NULL;
        $this->securityObjectApi = NULL;
        $this->signatureApi = NULL;
        $this->usersApi = NULL;
        $this->wrapApi = NULL;
    }

    protected function getApiEndpoint()
    {
        if (!getenv($this->API_ENDPOINT_ENV_VAR)) {
            return $this->DEFAULT_API_ENDPOINT;
        } else {
            return getenv($this->API_ENDPOINT_ENV_VAR);
        }
    }

    public function createApiClient()
    {
        $cli = new StatsTrackingApiClient();
        $cli->connect($this->getApiEndpoint(), $this->debug);
        return $cli;
    }

    public function connect()
    {
        $this->resetApis();
        $this->client = $this->createApiClient();
    }

    public function listSobjects()
    {
        $sobjects = $this->getSecurityObjectsApi()->getSecurityObjects();
        foreach ($sobjects as $sobject) {
            echo sprintf("%s\n", $sobject->getKid());
        }
    }

    public function getKeyClass($objType, $keySize, ?EllipticCurve $curve)
    {
        if ($objType == ObjectType::EC) {
            return new KeyClass(NULL, $curve, NULL);
        } else {
            return new KeyClass($objType, NULL, $keySize);
        }
    }

    public function getKey($objType = NULL, $keySize = NULL, ?EllipticCurve $curve = NULL)
    {
        $lookup = $this->getKeyClass($objType, $keySize, $curve);
        $keyList = NULL;
        if (array_key_exists(print_r($lookup, true), $this->keys)) {
            $keyList = $this->keys[print_r($lookup, true)];
        }
        if ($keyList == NULL || sizeof($keyList) == 0) {
            return $this->createKey($objType, $keySize, $curve, NULL);
        } else {
            return $keyList[0];
        }
    }

    public function saveNewKey(KeyObject $key)
    {
        $lookup = $this->getKeyClass($key->getObjType(), $key->getKeySize(), $key->getEllipticCurve());
        $keyList = NULL;
        if (array_key_exists(print_r($lookup, true), $this->keys)) {
            $keyList = $this->keys[print_r($lookup, true)];
        }
        if ($keyList == NULL) {
            $keyList = array();
            $this->keys[print_r($lookup, true)] = $keyList;
        }
        array_push($keyList, $key);
        $this->keys[print_r($lookup, true)] = $keyList;
    }

    public function createKey($objType, $keySize, ?EllipticCurve $curve, $groupId = NULL, $exportable = false, $addRsaEncryptionPolicy = false)
    {
        $request = new SobjectRequest();
        $request->setName(sprintf($this->baseName, $this->testUniqueString, $this->nextKey));
        $request->setDescription(sprintf($this->baseDescription, $this->testUniqueString, $this->nextKey));
        $request->setObjType($objType);
        $request->setKeySize($keySize);
        $request->setEllipticCurve($curve);

        if ($groupId != NULL) {
            $request->setGroupId($groupId);
        }

        if ($exportable) {
            if ($objType != ObjectType::AES) {
                throw new Exception("Exportable only implemented for AES keys");
            }
            $keyOps = array(KeyOperations::ENCRYPT, KeyOperations::DECRYPT, KeyOperations::WRAPKEY, KeyOperations::UNWRAPKEY, KeyOperations::DERIVEKEY, KeyOperations::EXPORT, KeyOperations::APPMANAGEABLE);
            $request->setKeyOps($keyOps);
        } else {
            $request->setKeyOps(NULL);
        }

        if ($addRsaEncryptionPolicy && $objType == ObjectType::RSA) {
            $options = new RsaOptions();
            $policy = new RsaEncryptionPolicy();
            $policyPadding = new RsaEncryptionPadding();
            $policyPaddingOEAP = new RsaEncryptionPaddingOAEP();
            $policy->setPadding($policyPadding->setOaep($policyPaddingOEAP));
            $policies = array();
            array_push($policies, $policy);
            $options->setEncryptionPolicy($policies);
            $request->setRsa($options);
        }

        $this->nextKey++;
        $result = $this->getSecurityObjectsApi()->generateSecurityObject($request);
        $this->saveNewKey($result);
        return $result;
    }

    public function deleteKey(KeyObject $key)
    {
        $this->getSecurityObjectsApi()->deleteSecurityObject($key->getKid());
        $lookup = $this->getKeyClass($key->getObjType(), $key->getKeySize(), $key->getEllipticCurve());
        $keyList = NULL;
        if (array_key_exists(print_r($lookup, true), $this->keys)) {
            $keyList = $this->keys[print_r($lookup, true)];
        }
        for ($i = 0; $i < sizeof($keyList); $i++) {
            if ($keyList[$i]->getKid() == $key->getKid()) {
                unset($keyList[$i]);
                break;
            }
        }
        $this->keys[print_r($lookup, true)] = $keyList;
    }

    public function wrapKey($wrappingKey, $wrappedKey, $alg, $mode)
    {
        $request = new WrapKeyRequest();
        $request->setAlg($alg);
        $request->setKid($wrappedKey);
        $request->setMode($mode);
        return $this->getWrapApi()->wrapKey($wrappingKey, $request);
    }

    public function unwrapKey($wrappingKey, $alg, $mode, $key, $wrappedKeyType, $iv)
    {
        $request = new UnwrapKeyRequest();
        $request->setAlg($alg);
        $request->setIv($iv);
        $request->setMode($mode);
        $request->setObjType($wrappedKeyType);
        $request->setWrappedKey($key);
        $request->setName(sprintf($this->baseName, $this->testUniqueString, $this->nextKey));

        $this->nextKey++;
        $newKey = $this->getWrapApi()->unwrapKey($wrappingKey, $request);
        $this->saveNewKey($newKey);
        return $newKey;
    }

    public function makeEncryptRequest(KeyObject $key, $mode, $size)
    {
        $iv = base64_encode($this->generateRandomString(16));
        $plain = $this->generateRandomString($size);

        $encRequest = new EncryptRequest();
        $encRequest->setAlg($key->getObjType());
        $encRequest->setMode($mode);
        $encRequest->setIv($iv);
        $encRequest->setPlain($plain);

        return $encRequest;
    }

    public function makeBatchEncryptRequest(KeyObject $key, $mode, $size, $batchSize)
    {
        $request = array();
        for ($i = 0; $i < $batchSize; $i++) {
            $inner = new BatchEncryptRequestInner();
            $inner->setKid($key->getKid());
            $inner->setRequest($this->makeEncryptRequest($key, $mode, $size));
            array_push($request, $inner);
        }
        return $request;
    }

    public function makeDecryptRequest(KeyObject $key, $mode, $iv, $cipher)
    {
        $decryptRequest = new DecryptRequest();
        $decryptRequest->setAlg($key->getObjType());
        $decryptRequest->setMode($mode);
        $decryptRequest->setIv($iv);
        $decryptRequest->setCipher($cipher);
        return $decryptRequest;
    }

    public function encryptDecryptOne(KeyObject $key)
    {
        $encResponse = NULL;
        $mode = NULL;
        if ($key->getObjType() != ObjectType::RSA && $key->getObjType() != ObjectType::EC) {
            $mode = CryptMode::CBC;
        }

        $encRequest = $this->makeEncryptRequest($key, $mode, 16);
        $encResponse = $this->getCryptoApi()->encrypt($key->getKid(), $encRequest);
        echo sprintf("Ciphertext (base64-encoded) %s\n", base64_encode($encResponse->getCipher()));

        $decRequest = $this->makeDecryptRequest($key, $mode, $encRequest->getIv(), $encResponse->getCipher());
        $decResponse = $this->getCryptoApi()->decrypt($key->getKid(), $decRequest);
        echo sprintf("Plaintext (base64-encoded): %s\n", base64_encode($decResponse->getPlain()));

        $decryptedPlain = $decResponse->getPlain();
        if ($encRequest->getPlain() != $decryptedPlain) {
            throw new Exception("Original plaintext and decrypted, plain text did not match");
        }
    }

    public function encryptDecryptBatch(KeyObject $key, $batchSize)
    {
        $mode = NULL;
        if ($key->getObjType() != ObjectType::RSA && $key->getObjType() != ObjectType::EC) {
            $mode = CryptMode::CBC;
        }

        $encRequest = array();
        for ($i = 0; $i < $batchSize; $i++) {
            $inner = new BatchEncryptRequestInner();
            $inner->setKid($key->getKid());
            $inner->setRequest($this->makeEncryptRequest($key, $mode, 16));
            array_push($encRequest, $inner);
        }

        $encResponse = $this->getCryptoApi()->batchEncrypt($encRequest);

        foreach ($encResponse as $inner) {
            echo sprintf("Cipher text (base64-encoded): %s\n", base64_encode($inner->getBody()->getCipher()));
        }

        $decRequest = array();
        for ($i = 0; $i < $batchSize; $i++) {
            $inner = new BatchDecryptRequestInner();
            $inner->setKid($key->getKid());
            $inner->setRequest($this->makeDecryptRequest($key, $mode, $encRequest[$i]->getRequest()->getIv(), $encResponse[$i]->getBody()->getCipher()));
            array_push($decRequest, $inner);
        }

        $decResponse = $this->getCryptoApi()->batchDecrypt($decRequest);
        for ($i = 0; $i < $batchSize; $i++) {
            if ($encRequest[$i]->getRequest()->getPlain() != $decResponse[$i]->getBody()->getPlain()) {
                throw new Exception("Original plaintext and decrypted plaintext did not match");
            }
        }
    }

    public function computeDigest($data, $alg)
    {
        return base64_encode(hash($alg, $data, true));
    }

    public function cleanUp()
    {
        foreach (array_values($this->keys) as $keyList) {
            foreach ($keyList as $sobject) {
                try {
                    $this->getSecurityObjectsApi()->deleteSecurityObject($sobject->getKid());
                } catch (ApiException $e) {
                }
            }
        }
    }

    public function runAuthTests()
    {
        if (getenv($this->CLIENT_CERT_ENV_VAR)) {
            $config = new Configuration();
            $config->setDebug($this->debug);
            $config->setHost($this->getApiEndpoint());
            $config->setUsername(getenv($this->CLIENT_CERT_APP_ID_ENV_VAR));
            $config->setPassword("password");
            $cli = new StatsTrackingApiClient($config);
            $auth = new AuthenticationApi($cli);
            try {
                $auth->authorize();
                throw new Exception("Client cert auth succeeded with non-empty password");
            } catch (ApiException $e) {
                //Accepted
            }
        }
    }

    public function runTest()
    {
        $this->runAuthTests();
    }

    public function mainHelper()
    {
        try {
            $this->connect();
            $this->runTest();
        } catch (Exception $e) {
            echo "Exception when running test";
            echo $e->getTraceAsString();
        }
    }
}
