<?php


use SdkmsClient\Api\AuthenticationApi;
use SdkmsClient\ApiClient;
use SdkmsClient\Configuration;

class StatsTrackingApiClient extends ApiClient
{
    // private static $latencyTracker
    public function __construct(Configuration $config = NULL)
    {
        parent::__construct($config);
    }

    public function connect(string $server, bool $debug)
    {
        $this->config->setDebug($debug);
        $this->config->setHost($server);

        if (getenv(ApiExample::$CLIENT_CERT_ENV_VAR)) {
            $this->config->setUsername(getenv(ApiExample::$CLIENT_CERT_APP_ID_ENV_VAR));
            $this->config->setPassword("");
        } else if (getenv(ApiExample::$API_KEY_ENV_VAR)) {
            $appApiKey = getenv(ApiExample::$API_KEY_ENV_VAR);
            $parts = explode(":", base64_decode($appApiKey));
            $this->config->setUsername($parts[0]);
            $this->config->setPassword($parts[1]);
        } else {
            $message = sprintf("Environment variable %s not set", ApiExample::$API_KEY_ENV_VAR);
            throw new TestException($message);
        }

        $auth = new AuthenticationApi($this);
        $fortanixToken = $auth->authorize();

        if ($debug) {
            echo sprintf("Fortanix Access Token : %s\n", $fortanixToken->getAccessToken());
        }

        $this->config->setApiKey("Authorization", $auth['access_token']);
        $this->config->setApiKeyPrefix("Authorization", "Bearer");
    }
}
